/******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ([
/* 0 */,
/* 1 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Renderer": () => (/* binding */ Renderer),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var snabbdom_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2);
/* harmony import */ var snabbdom_h__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6);
/* harmony import */ var snabbdom_modules_class__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(7);
/* harmony import */ var snabbdom_modules_dataset__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(8);
/* harmony import */ var snabbdom_modules_eventlisteners__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9);
/* harmony import */ var snabbdom_modules_style__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(10);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(11);
/** @module @hat-open/renderer
 */











// patched version of snabbdom's es/modules/attributes.js
const snabbdomAttributes = (() => {
    function updateAttrs(oldVnode, vnode) {
        var key, elm = vnode.elm, oldAttrs = oldVnode.data.attrs, attrs = vnode.data.attrs;
        if (!oldAttrs && !attrs)
            return;
        if (oldAttrs === attrs)
            return;
        oldAttrs = oldAttrs || {};
        attrs = attrs || {};
        for (key in attrs) {
            var cur = attrs[key];
            var old = oldAttrs[key];
            if (old !== cur) {
                if (cur === true) {
                    elm.setAttribute(key, "");
                }
                else if (cur === false) {
                    elm.removeAttribute(key);
                }
                else {
                    elm.setAttribute(key, cur);
                }
            }
        }
        for (key in oldAttrs) {
            if (!(key in attrs)) {
                elm.removeAttribute(key);
            }
        }
    }
    return { create: updateAttrs, update: updateAttrs };
})();


// patched version of snabbdom's es/modules/props.js
const snabbdomProps = (() => {
    function updateProps(oldVnode, vnode) {
        var key, cur, old, elm = vnode.elm, oldProps = oldVnode.data.props, props = vnode.data.props;
        if (!oldProps && !props)
            return;
        if (oldProps === props)
            return;
        oldProps = oldProps || {};
        props = props || {};
        for (key in oldProps) {
            if (!props[key]) {
                if (key === 'style') {
                    elm[key] = '';
                } else {
                    delete elm[key];
                }
            }
        }
        for (key in props) {
            cur = props[key];
            old = oldProps[key];
            if (old !== cur && (key !== 'value' || elm[key] !== cur)) {
                elm[key] = cur;
            }
        }
    }
    return { create: updateProps, update: updateProps };
})();


const patch = (0,snabbdom_init__WEBPACK_IMPORTED_MODULE_0__.init)([
    snabbdomAttributes,
    snabbdom_modules_class__WEBPACK_IMPORTED_MODULE_2__.classModule,
    snabbdom_modules_dataset__WEBPACK_IMPORTED_MODULE_3__.datasetModule,
    snabbdom_modules_eventlisteners__WEBPACK_IMPORTED_MODULE_4__.eventListenersModule,
    snabbdomProps,
    snabbdom_modules_style__WEBPACK_IMPORTED_MODULE_5__.styleModule
]);


function vhFromArray(node) {
    if (!node)
        return [];
    if (_hat_open_util__WEBPACK_IMPORTED_MODULE_6__.isString(node))
        return node;
    if (!_hat_open_util__WEBPACK_IMPORTED_MODULE_6__.isArray(node))
        throw 'Invalid node structure';
    if (node.length < 1)
        return [];
    if (typeof node[0] != 'string')
        return node.map(vhFromArray);
    const hasData = node.length > 1 && _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.isObject(node[1]);
    const children = _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.map(vhFromArray),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.flatten,
        Array.from
    )(node.slice(hasData ? 2 : 1));
    const result = hasData ?
        (0,snabbdom_h__WEBPACK_IMPORTED_MODULE_1__.h)(node[0], node[1], children) :
        (0,snabbdom_h__WEBPACK_IMPORTED_MODULE_1__.h)(node[0], children);
    return result;
}

/**
 * Virtual DOM renderer
 */
class Renderer extends EventTarget {

    /**
     * Calls `init` method
     * @param {HTMLElement} [el=document.body]
     * @param {Any} [initState=null]
     * @param {Function} [vtCb=null]
     * @param {Number} [maxFps=30]
     */
    constructor(el, initState, vtCb, maxFps) {
        super();
        this.init(el, initState, vtCb, maxFps);
    }

    /**
     * Initialize renderer
     * @param {HTMLElement} [el=document.body]
     * @param {Any} [initState=null]
     * @param {Function} [vtCb=null]
     * @param {Number} [maxFps=30]
     * @return {Promise}
     */
    init(el, initState, vtCb, maxFps) {
        this._state = null;
        this._changes = [];
        this._promise = null;
        this._timeout = null;
        this._lastRender = null;
        this._vtCb = vtCb;
        this._maxFps = _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.isNumber(maxFps) ? maxFps : 30;
        this._vNode = el || document.querySelector('body');
        if (initState)
            return this.change(_ => initState);
        return new Promise(resolve => { resolve(); });
    }

    /**
      * Render
      */
    render() {
        if (!this._vtCb)
            return;
        this._lastRender = performance.now();
        const vNode = vhFromArray(this._vtCb(this));
        patch(this._vNode, vNode);
        this._vNode = vNode;
        this.dispatchEvent(new CustomEvent('render', {detail: this._state}));
    }

    /**
     * Get current state value referenced by `paths`
     * @param {...Path} paths
     * @return {Any}
     */
    get(...paths) {
        return _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.get(paths, this._state);
    }

    /**
     * Change current state value referenced by `path`
     * @param {Path} path
     * @param {Any} value
     * @return {Promise}
     */
    set(path, value) {
        if (arguments.length < 2) {
            value = path;
            path = [];
        }
        return this.change(path, _ => value);
    }

    /**
     * Change current state value referenced by `path`
     * @param {Path} path
     * @param {Function} cb
     * @return {Promise}
     */
    change(path, cb) {
        if (arguments.length < 2) {
            cb = path;
            path = [];
        }
        this._changes.push([path, cb]);
        if (this._promise)
            return this._promise;
        this._promise = new Promise((resolve, reject) => {
            setTimeout(() => {
                try {
                    this._change();
                } catch(e) {
                    this._promise = null;
                    reject(e);
                    throw e;
                }
                this._promise = null;
                resolve();
            }, 0);
        });
        return this._promise;
    }

    _change() {
        let change = false;
        while (this._changes.length > 0) {
            const [path, cb] = this._changes.shift();
            const view = _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.get(path);
            const oldState = this._state;
            this._state = _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.change(path, cb, this._state);
            if (this._state && _hat_open_util__WEBPACK_IMPORTED_MODULE_6__.equals(view(oldState),
                                        view(this._state)))
                continue;
            change = true;
            if (!this._vtCb || this._timeout)
                continue;
            const delay = (!this._lastRender || !this._maxFps ?
                0 :
                (1000 / this._maxFps) -
                (performance.now() - this._lastRender));
            this._timeout = setTimeout(() => {
                this._timeout = null;
                this.render();
            }, (delay > 0 ? delay : 0));
        }
        if (change)
            this.dispatchEvent(
                new CustomEvent('change', {detail: this._state}));
    }
}
// Renderer.prototype.set = u.curry(Renderer.prototype.set);
// Renderer.prototype.change = u.curry(Renderer.prototype.change);


/**
 * Default renderer
 * @static
 * @type {Renderer}
 */
const defaultRenderer = (() => {
    const r = (window && window.__hat_default_renderer) || new Renderer();
    if (window)
        window.__hat_default_renderer = r;
    return r;
})();
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (defaultRenderer);


/***/ }),
/* 2 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "init": () => (/* binding */ init)
/* harmony export */ });
/* harmony import */ var _vnode_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(3);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);
/* harmony import */ var _htmldomapi_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(5);



function isUndef(s) {
    return s === undefined;
}
function isDef(s) {
    return s !== undefined;
}
const emptyNode = (0,_vnode_js__WEBPACK_IMPORTED_MODULE_0__.vnode)('', {}, [], undefined, undefined);
function sameVnode(vnode1, vnode2) {
    return vnode1.key === vnode2.key && vnode1.sel === vnode2.sel;
}
function isVnode(vnode) {
    return vnode.sel !== undefined;
}
function createKeyToOldIdx(children, beginIdx, endIdx) {
    var _a;
    const map = {};
    for (let i = beginIdx; i <= endIdx; ++i) {
        const key = (_a = children[i]) === null || _a === void 0 ? void 0 : _a.key;
        if (key !== undefined) {
            map[key] = i;
        }
    }
    return map;
}
const hooks = ['create', 'update', 'remove', 'destroy', 'pre', 'post'];
function init(modules, domApi) {
    let i;
    let j;
    const cbs = {
        create: [],
        update: [],
        remove: [],
        destroy: [],
        pre: [],
        post: []
    };
    const api = domApi !== undefined ? domApi : _htmldomapi_js__WEBPACK_IMPORTED_MODULE_2__.htmlDomApi;
    for (i = 0; i < hooks.length; ++i) {
        cbs[hooks[i]] = [];
        for (j = 0; j < modules.length; ++j) {
            const hook = modules[j][hooks[i]];
            if (hook !== undefined) {
                cbs[hooks[i]].push(hook);
            }
        }
    }
    function emptyNodeAt(elm) {
        const id = elm.id ? '#' + elm.id : '';
        const c = elm.className ? '.' + elm.className.split(' ').join('.') : '';
        return (0,_vnode_js__WEBPACK_IMPORTED_MODULE_0__.vnode)(api.tagName(elm).toLowerCase() + id + c, {}, [], undefined, elm);
    }
    function createRmCb(childElm, listeners) {
        return function rmCb() {
            if (--listeners === 0) {
                const parent = api.parentNode(childElm);
                api.removeChild(parent, childElm);
            }
        };
    }
    function createElm(vnode, insertedVnodeQueue) {
        var _a, _b;
        let i;
        let data = vnode.data;
        if (data !== undefined) {
            const init = (_a = data.hook) === null || _a === void 0 ? void 0 : _a.init;
            if (isDef(init)) {
                init(vnode);
                data = vnode.data;
            }
        }
        const children = vnode.children;
        const sel = vnode.sel;
        if (sel === '!') {
            if (isUndef(vnode.text)) {
                vnode.text = '';
            }
            vnode.elm = api.createComment(vnode.text);
        }
        else if (sel !== undefined) {
            // Parse selector
            const hashIdx = sel.indexOf('#');
            const dotIdx = sel.indexOf('.', hashIdx);
            const hash = hashIdx > 0 ? hashIdx : sel.length;
            const dot = dotIdx > 0 ? dotIdx : sel.length;
            const tag = hashIdx !== -1 || dotIdx !== -1 ? sel.slice(0, Math.min(hash, dot)) : sel;
            const elm = vnode.elm = isDef(data) && isDef(i = data.ns)
                ? api.createElementNS(i, tag)
                : api.createElement(tag);
            if (hash < dot)
                elm.setAttribute('id', sel.slice(hash + 1, dot));
            if (dotIdx > 0)
                elm.setAttribute('class', sel.slice(dot + 1).replace(/\./g, ' '));
            for (i = 0; i < cbs.create.length; ++i)
                cbs.create[i](emptyNode, vnode);
            if (_is_js__WEBPACK_IMPORTED_MODULE_1__.array(children)) {
                for (i = 0; i < children.length; ++i) {
                    const ch = children[i];
                    if (ch != null) {
                        api.appendChild(elm, createElm(ch, insertedVnodeQueue));
                    }
                }
            }
            else if (_is_js__WEBPACK_IMPORTED_MODULE_1__.primitive(vnode.text)) {
                api.appendChild(elm, api.createTextNode(vnode.text));
            }
            const hook = vnode.data.hook;
            if (isDef(hook)) {
                (_b = hook.create) === null || _b === void 0 ? void 0 : _b.call(hook, emptyNode, vnode);
                if (hook.insert) {
                    insertedVnodeQueue.push(vnode);
                }
            }
        }
        else {
            vnode.elm = api.createTextNode(vnode.text);
        }
        return vnode.elm;
    }
    function addVnodes(parentElm, before, vnodes, startIdx, endIdx, insertedVnodeQueue) {
        for (; startIdx <= endIdx; ++startIdx) {
            const ch = vnodes[startIdx];
            if (ch != null) {
                api.insertBefore(parentElm, createElm(ch, insertedVnodeQueue), before);
            }
        }
    }
    function invokeDestroyHook(vnode) {
        var _a, _b;
        const data = vnode.data;
        if (data !== undefined) {
            (_b = (_a = data === null || data === void 0 ? void 0 : data.hook) === null || _a === void 0 ? void 0 : _a.destroy) === null || _b === void 0 ? void 0 : _b.call(_a, vnode);
            for (let i = 0; i < cbs.destroy.length; ++i)
                cbs.destroy[i](vnode);
            if (vnode.children !== undefined) {
                for (let j = 0; j < vnode.children.length; ++j) {
                    const child = vnode.children[j];
                    if (child != null && typeof child !== 'string') {
                        invokeDestroyHook(child);
                    }
                }
            }
        }
    }
    function removeVnodes(parentElm, vnodes, startIdx, endIdx) {
        var _a, _b;
        for (; startIdx <= endIdx; ++startIdx) {
            let listeners;
            let rm;
            const ch = vnodes[startIdx];
            if (ch != null) {
                if (isDef(ch.sel)) {
                    invokeDestroyHook(ch);
                    listeners = cbs.remove.length + 1;
                    rm = createRmCb(ch.elm, listeners);
                    for (let i = 0; i < cbs.remove.length; ++i)
                        cbs.remove[i](ch, rm);
                    const removeHook = (_b = (_a = ch === null || ch === void 0 ? void 0 : ch.data) === null || _a === void 0 ? void 0 : _a.hook) === null || _b === void 0 ? void 0 : _b.remove;
                    if (isDef(removeHook)) {
                        removeHook(ch, rm);
                    }
                    else {
                        rm();
                    }
                }
                else { // Text node
                    api.removeChild(parentElm, ch.elm);
                }
            }
        }
    }
    function updateChildren(parentElm, oldCh, newCh, insertedVnodeQueue) {
        let oldStartIdx = 0;
        let newStartIdx = 0;
        let oldEndIdx = oldCh.length - 1;
        let oldStartVnode = oldCh[0];
        let oldEndVnode = oldCh[oldEndIdx];
        let newEndIdx = newCh.length - 1;
        let newStartVnode = newCh[0];
        let newEndVnode = newCh[newEndIdx];
        let oldKeyToIdx;
        let idxInOld;
        let elmToMove;
        let before;
        while (oldStartIdx <= oldEndIdx && newStartIdx <= newEndIdx) {
            if (oldStartVnode == null) {
                oldStartVnode = oldCh[++oldStartIdx]; // Vnode might have been moved left
            }
            else if (oldEndVnode == null) {
                oldEndVnode = oldCh[--oldEndIdx];
            }
            else if (newStartVnode == null) {
                newStartVnode = newCh[++newStartIdx];
            }
            else if (newEndVnode == null) {
                newEndVnode = newCh[--newEndIdx];
            }
            else if (sameVnode(oldStartVnode, newStartVnode)) {
                patchVnode(oldStartVnode, newStartVnode, insertedVnodeQueue);
                oldStartVnode = oldCh[++oldStartIdx];
                newStartVnode = newCh[++newStartIdx];
            }
            else if (sameVnode(oldEndVnode, newEndVnode)) {
                patchVnode(oldEndVnode, newEndVnode, insertedVnodeQueue);
                oldEndVnode = oldCh[--oldEndIdx];
                newEndVnode = newCh[--newEndIdx];
            }
            else if (sameVnode(oldStartVnode, newEndVnode)) { // Vnode moved right
                patchVnode(oldStartVnode, newEndVnode, insertedVnodeQueue);
                api.insertBefore(parentElm, oldStartVnode.elm, api.nextSibling(oldEndVnode.elm));
                oldStartVnode = oldCh[++oldStartIdx];
                newEndVnode = newCh[--newEndIdx];
            }
            else if (sameVnode(oldEndVnode, newStartVnode)) { // Vnode moved left
                patchVnode(oldEndVnode, newStartVnode, insertedVnodeQueue);
                api.insertBefore(parentElm, oldEndVnode.elm, oldStartVnode.elm);
                oldEndVnode = oldCh[--oldEndIdx];
                newStartVnode = newCh[++newStartIdx];
            }
            else {
                if (oldKeyToIdx === undefined) {
                    oldKeyToIdx = createKeyToOldIdx(oldCh, oldStartIdx, oldEndIdx);
                }
                idxInOld = oldKeyToIdx[newStartVnode.key];
                if (isUndef(idxInOld)) { // New element
                    api.insertBefore(parentElm, createElm(newStartVnode, insertedVnodeQueue), oldStartVnode.elm);
                }
                else {
                    elmToMove = oldCh[idxInOld];
                    if (elmToMove.sel !== newStartVnode.sel) {
                        api.insertBefore(parentElm, createElm(newStartVnode, insertedVnodeQueue), oldStartVnode.elm);
                    }
                    else {
                        patchVnode(elmToMove, newStartVnode, insertedVnodeQueue);
                        oldCh[idxInOld] = undefined;
                        api.insertBefore(parentElm, elmToMove.elm, oldStartVnode.elm);
                    }
                }
                newStartVnode = newCh[++newStartIdx];
            }
        }
        if (oldStartIdx <= oldEndIdx || newStartIdx <= newEndIdx) {
            if (oldStartIdx > oldEndIdx) {
                before = newCh[newEndIdx + 1] == null ? null : newCh[newEndIdx + 1].elm;
                addVnodes(parentElm, before, newCh, newStartIdx, newEndIdx, insertedVnodeQueue);
            }
            else {
                removeVnodes(parentElm, oldCh, oldStartIdx, oldEndIdx);
            }
        }
    }
    function patchVnode(oldVnode, vnode, insertedVnodeQueue) {
        var _a, _b, _c, _d, _e;
        const hook = (_a = vnode.data) === null || _a === void 0 ? void 0 : _a.hook;
        (_b = hook === null || hook === void 0 ? void 0 : hook.prepatch) === null || _b === void 0 ? void 0 : _b.call(hook, oldVnode, vnode);
        const elm = vnode.elm = oldVnode.elm;
        const oldCh = oldVnode.children;
        const ch = vnode.children;
        if (oldVnode === vnode)
            return;
        if (vnode.data !== undefined) {
            for (let i = 0; i < cbs.update.length; ++i)
                cbs.update[i](oldVnode, vnode);
            (_d = (_c = vnode.data.hook) === null || _c === void 0 ? void 0 : _c.update) === null || _d === void 0 ? void 0 : _d.call(_c, oldVnode, vnode);
        }
        if (isUndef(vnode.text)) {
            if (isDef(oldCh) && isDef(ch)) {
                if (oldCh !== ch)
                    updateChildren(elm, oldCh, ch, insertedVnodeQueue);
            }
            else if (isDef(ch)) {
                if (isDef(oldVnode.text))
                    api.setTextContent(elm, '');
                addVnodes(elm, null, ch, 0, ch.length - 1, insertedVnodeQueue);
            }
            else if (isDef(oldCh)) {
                removeVnodes(elm, oldCh, 0, oldCh.length - 1);
            }
            else if (isDef(oldVnode.text)) {
                api.setTextContent(elm, '');
            }
        }
        else if (oldVnode.text !== vnode.text) {
            if (isDef(oldCh)) {
                removeVnodes(elm, oldCh, 0, oldCh.length - 1);
            }
            api.setTextContent(elm, vnode.text);
        }
        (_e = hook === null || hook === void 0 ? void 0 : hook.postpatch) === null || _e === void 0 ? void 0 : _e.call(hook, oldVnode, vnode);
    }
    return function patch(oldVnode, vnode) {
        let i, elm, parent;
        const insertedVnodeQueue = [];
        for (i = 0; i < cbs.pre.length; ++i)
            cbs.pre[i]();
        if (!isVnode(oldVnode)) {
            oldVnode = emptyNodeAt(oldVnode);
        }
        if (sameVnode(oldVnode, vnode)) {
            patchVnode(oldVnode, vnode, insertedVnodeQueue);
        }
        else {
            elm = oldVnode.elm;
            parent = api.parentNode(elm);
            createElm(vnode, insertedVnodeQueue);
            if (parent !== null) {
                api.insertBefore(parent, vnode.elm, api.nextSibling(elm));
                removeVnodes(parent, [oldVnode], 0, 0);
            }
        }
        for (i = 0; i < insertedVnodeQueue.length; ++i) {
            insertedVnodeQueue[i].data.hook.insert(insertedVnodeQueue[i]);
        }
        for (i = 0; i < cbs.post.length; ++i)
            cbs.post[i]();
        return vnode;
    };
}
//# sourceMappingURL=init.js.map

/***/ }),
/* 3 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "vnode": () => (/* binding */ vnode)
/* harmony export */ });
function vnode(sel, data, children, text, elm) {
    const key = data === undefined ? undefined : data.key;
    return { sel, data, children, text, elm, key };
}
//# sourceMappingURL=vnode.js.map

/***/ }),
/* 4 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "array": () => (/* binding */ array),
/* harmony export */   "primitive": () => (/* binding */ primitive)
/* harmony export */ });
const array = Array.isArray;
function primitive(s) {
    return typeof s === 'string' || typeof s === 'number';
}
//# sourceMappingURL=is.js.map

/***/ }),
/* 5 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "htmlDomApi": () => (/* binding */ htmlDomApi)
/* harmony export */ });
function createElement(tagName) {
    return document.createElement(tagName);
}
function createElementNS(namespaceURI, qualifiedName) {
    return document.createElementNS(namespaceURI, qualifiedName);
}
function createTextNode(text) {
    return document.createTextNode(text);
}
function createComment(text) {
    return document.createComment(text);
}
function insertBefore(parentNode, newNode, referenceNode) {
    parentNode.insertBefore(newNode, referenceNode);
}
function removeChild(node, child) {
    node.removeChild(child);
}
function appendChild(node, child) {
    node.appendChild(child);
}
function parentNode(node) {
    return node.parentNode;
}
function nextSibling(node) {
    return node.nextSibling;
}
function tagName(elm) {
    return elm.tagName;
}
function setTextContent(node, text) {
    node.textContent = text;
}
function getTextContent(node) {
    return node.textContent;
}
function isElement(node) {
    return node.nodeType === 1;
}
function isText(node) {
    return node.nodeType === 3;
}
function isComment(node) {
    return node.nodeType === 8;
}
const htmlDomApi = {
    createElement,
    createElementNS,
    createTextNode,
    createComment,
    insertBefore,
    removeChild,
    appendChild,
    parentNode,
    nextSibling,
    tagName,
    setTextContent,
    getTextContent,
    isElement,
    isText,
    isComment,
};
//# sourceMappingURL=htmldomapi.js.map

/***/ }),
/* 6 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "h": () => (/* binding */ h)
/* harmony export */ });
/* harmony import */ var _vnode_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(3);
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4);


function addNS(data, children, sel) {
    data.ns = 'http://www.w3.org/2000/svg';
    if (sel !== 'foreignObject' && children !== undefined) {
        for (let i = 0; i < children.length; ++i) {
            const childData = children[i].data;
            if (childData !== undefined) {
                addNS(childData, children[i].children, children[i].sel);
            }
        }
    }
}
function h(sel, b, c) {
    var data = {};
    var children;
    var text;
    var i;
    if (c !== undefined) {
        if (b !== null) {
            data = b;
        }
        if (_is_js__WEBPACK_IMPORTED_MODULE_1__.array(c)) {
            children = c;
        }
        else if (_is_js__WEBPACK_IMPORTED_MODULE_1__.primitive(c)) {
            text = c;
        }
        else if (c && c.sel) {
            children = [c];
        }
    }
    else if (b !== undefined && b !== null) {
        if (_is_js__WEBPACK_IMPORTED_MODULE_1__.array(b)) {
            children = b;
        }
        else if (_is_js__WEBPACK_IMPORTED_MODULE_1__.primitive(b)) {
            text = b;
        }
        else if (b && b.sel) {
            children = [b];
        }
        else {
            data = b;
        }
    }
    if (children !== undefined) {
        for (i = 0; i < children.length; ++i) {
            if (_is_js__WEBPACK_IMPORTED_MODULE_1__.primitive(children[i]))
                children[i] = (0,_vnode_js__WEBPACK_IMPORTED_MODULE_0__.vnode)(undefined, undefined, undefined, children[i], undefined);
        }
    }
    if (sel[0] === 's' && sel[1] === 'v' && sel[2] === 'g' &&
        (sel.length === 3 || sel[3] === '.' || sel[3] === '#')) {
        addNS(data, children, sel);
    }
    return (0,_vnode_js__WEBPACK_IMPORTED_MODULE_0__.vnode)(sel, data, children, text, undefined);
}
;
//# sourceMappingURL=h.js.map

/***/ }),
/* 7 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "classModule": () => (/* binding */ classModule)
/* harmony export */ });
function updateClass(oldVnode, vnode) {
    var cur;
    var name;
    var elm = vnode.elm;
    var oldClass = oldVnode.data.class;
    var klass = vnode.data.class;
    if (!oldClass && !klass)
        return;
    if (oldClass === klass)
        return;
    oldClass = oldClass || {};
    klass = klass || {};
    for (name in oldClass) {
        if (oldClass[name] &&
            !Object.prototype.hasOwnProperty.call(klass, name)) {
            // was `true` and now not provided
            elm.classList.remove(name);
        }
    }
    for (name in klass) {
        cur = klass[name];
        if (cur !== oldClass[name]) {
            elm.classList[cur ? 'add' : 'remove'](name);
        }
    }
}
const classModule = { create: updateClass, update: updateClass };
//# sourceMappingURL=class.js.map

/***/ }),
/* 8 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "datasetModule": () => (/* binding */ datasetModule)
/* harmony export */ });
const CAPS_REGEX = /[A-Z]/g;
function updateDataset(oldVnode, vnode) {
    const elm = vnode.elm;
    let oldDataset = oldVnode.data.dataset;
    let dataset = vnode.data.dataset;
    let key;
    if (!oldDataset && !dataset)
        return;
    if (oldDataset === dataset)
        return;
    oldDataset = oldDataset || {};
    dataset = dataset || {};
    const d = elm.dataset;
    for (key in oldDataset) {
        if (!dataset[key]) {
            if (d) {
                if (key in d) {
                    delete d[key];
                }
            }
            else {
                elm.removeAttribute('data-' + key.replace(CAPS_REGEX, '-$&').toLowerCase());
            }
        }
    }
    for (key in dataset) {
        if (oldDataset[key] !== dataset[key]) {
            if (d) {
                d[key] = dataset[key];
            }
            else {
                elm.setAttribute('data-' + key.replace(CAPS_REGEX, '-$&').toLowerCase(), dataset[key]);
            }
        }
    }
}
const datasetModule = { create: updateDataset, update: updateDataset };
//# sourceMappingURL=dataset.js.map

/***/ }),
/* 9 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "eventListenersModule": () => (/* binding */ eventListenersModule)
/* harmony export */ });
function invokeHandler(handler, vnode, event) {
    if (typeof handler === 'function') {
        // call function handler
        handler.call(vnode, event, vnode);
    }
    else if (typeof handler === 'object') {
        // call multiple handlers
        for (var i = 0; i < handler.length; i++) {
            invokeHandler(handler[i], vnode, event);
        }
    }
}
function handleEvent(event, vnode) {
    var name = event.type;
    var on = vnode.data.on;
    // call event handler(s) if exists
    if (on && on[name]) {
        invokeHandler(on[name], vnode, event);
    }
}
function createListener() {
    return function handler(event) {
        handleEvent(event, handler.vnode);
    };
}
function updateEventListeners(oldVnode, vnode) {
    var oldOn = oldVnode.data.on;
    var oldListener = oldVnode.listener;
    var oldElm = oldVnode.elm;
    var on = vnode && vnode.data.on;
    var elm = (vnode && vnode.elm);
    var name;
    // optimization for reused immutable handlers
    if (oldOn === on) {
        return;
    }
    // remove existing listeners which no longer used
    if (oldOn && oldListener) {
        // if element changed or deleted we remove all existing listeners unconditionally
        if (!on) {
            for (name in oldOn) {
                // remove listener if element was changed or existing listeners removed
                oldElm.removeEventListener(name, oldListener, false);
            }
        }
        else {
            for (name in oldOn) {
                // remove listener if existing listener removed
                if (!on[name]) {
                    oldElm.removeEventListener(name, oldListener, false);
                }
            }
        }
    }
    // add new listeners which has not already attached
    if (on) {
        // reuse existing listener or create new
        var listener = vnode.listener = oldVnode.listener || createListener();
        // update vnode for listener
        listener.vnode = vnode;
        // if element changed or added we add all needed listeners unconditionally
        if (!oldOn) {
            for (name in on) {
                // add listener if element was changed or new listeners added
                elm.addEventListener(name, listener, false);
            }
        }
        else {
            for (name in on) {
                // add listener if new listener added
                if (!oldOn[name]) {
                    elm.addEventListener(name, listener, false);
                }
            }
        }
    }
}
const eventListenersModule = {
    create: updateEventListeners,
    update: updateEventListeners,
    destroy: updateEventListeners
};
//# sourceMappingURL=eventlisteners.js.map

/***/ }),
/* 10 */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "styleModule": () => (/* binding */ styleModule)
/* harmony export */ });
// Bindig `requestAnimationFrame` like this fixes a bug in IE/Edge. See #360 and #409.
var raf = (typeof window !== 'undefined' && (window.requestAnimationFrame).bind(window)) || setTimeout;
var nextFrame = function (fn) {
    raf(function () {
        raf(fn);
    });
};
var reflowForced = false;
function setNextFrame(obj, prop, val) {
    nextFrame(function () {
        obj[prop] = val;
    });
}
function updateStyle(oldVnode, vnode) {
    var cur;
    var name;
    var elm = vnode.elm;
    var oldStyle = oldVnode.data.style;
    var style = vnode.data.style;
    if (!oldStyle && !style)
        return;
    if (oldStyle === style)
        return;
    oldStyle = oldStyle || {};
    style = style || {};
    var oldHasDel = 'delayed' in oldStyle;
    for (name in oldStyle) {
        if (!style[name]) {
            if (name[0] === '-' && name[1] === '-') {
                elm.style.removeProperty(name);
            }
            else {
                elm.style[name] = '';
            }
        }
    }
    for (name in style) {
        cur = style[name];
        if (name === 'delayed' && style.delayed) {
            for (const name2 in style.delayed) {
                cur = style.delayed[name2];
                if (!oldHasDel || cur !== oldStyle.delayed[name2]) {
                    setNextFrame(elm.style, name2, cur);
                }
            }
        }
        else if (name !== 'remove' && cur !== oldStyle[name]) {
            if (name[0] === '-' && name[1] === '-') {
                elm.style.setProperty(name, cur);
            }
            else {
                elm.style[name] = cur;
            }
        }
    }
}
function applyDestroyStyle(vnode) {
    var style;
    var name;
    var elm = vnode.elm;
    var s = vnode.data.style;
    if (!s || !(style = s.destroy))
        return;
    for (name in style) {
        elm.style[name] = style[name];
    }
}
function applyRemoveStyle(vnode, rm) {
    var s = vnode.data.style;
    if (!s || !s.remove) {
        rm();
        return;
    }
    if (!reflowForced) {
        // eslint-disable-next-line @typescript-eslint/no-unused-expressions
        vnode.elm.offsetLeft;
        reflowForced = true;
    }
    var name;
    var elm = vnode.elm;
    var i = 0;
    var compStyle;
    var style = s.remove;
    var amount = 0;
    var applied = [];
    for (name in style) {
        applied.push(name);
        elm.style[name] = style[name];
    }
    compStyle = getComputedStyle(elm);
    var props = compStyle['transition-property'].split(', ');
    for (; i < props.length; ++i) {
        if (applied.indexOf(props[i]) !== -1)
            amount++;
    }
    elm.addEventListener('transitionend', function (ev) {
        if (ev.target === elm)
            --amount;
        if (amount === 0)
            rm();
    });
}
function forceReflow() {
    reflowForced = false;
}
const styleModule = {
    pre: forceReflow,
    create: updateStyle,
    update: updateStyle,
    destroy: applyDestroyStyle,
    remove: applyRemoveStyle
};
//# sourceMappingURL=style.js.map

/***/ }),
/* 11 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "identity": () => (/* binding */ identity),
/* harmony export */   "isNil": () => (/* binding */ isNil),
/* harmony export */   "isBoolean": () => (/* binding */ isBoolean),
/* harmony export */   "isInteger": () => (/* binding */ isInteger),
/* harmony export */   "isNumber": () => (/* binding */ isNumber),
/* harmony export */   "isString": () => (/* binding */ isString),
/* harmony export */   "isArray": () => (/* binding */ isArray),
/* harmony export */   "isObject": () => (/* binding */ isObject),
/* harmony export */   "strictParseInt": () => (/* binding */ strictParseInt),
/* harmony export */   "strictParseFloat": () => (/* binding */ strictParseFloat),
/* harmony export */   "clone": () => (/* binding */ clone),
/* harmony export */   "zip": () => (/* binding */ zip),
/* harmony export */   "toPairs": () => (/* binding */ toPairs),
/* harmony export */   "fromPairs": () => (/* binding */ fromPairs),
/* harmony export */   "flatten": () => (/* binding */ flatten),
/* harmony export */   "pipe": () => (/* binding */ pipe),
/* harmony export */   "flap": () => (/* binding */ flap),
/* harmony export */   "curry": () => (/* binding */ curry),
/* harmony export */   "equals": () => (/* binding */ equals),
/* harmony export */   "repeat": () => (/* binding */ repeat),
/* harmony export */   "get": () => (/* binding */ get),
/* harmony export */   "change": () => (/* binding */ change),
/* harmony export */   "set": () => (/* binding */ set),
/* harmony export */   "omit": () => (/* binding */ omit),
/* harmony export */   "move": () => (/* binding */ move),
/* harmony export */   "sort": () => (/* binding */ sort),
/* harmony export */   "sortBy": () => (/* binding */ sortBy),
/* harmony export */   "pick": () => (/* binding */ pick),
/* harmony export */   "map": () => (/* binding */ map),
/* harmony export */   "filter": () => (/* binding */ filter),
/* harmony export */   "append": () => (/* binding */ append),
/* harmony export */   "reduce": () => (/* binding */ reduce),
/* harmony export */   "merge": () => (/* binding */ merge),
/* harmony export */   "mergeAll": () => (/* binding */ mergeAll),
/* harmony export */   "find": () => (/* binding */ find),
/* harmony export */   "findIndex": () => (/* binding */ findIndex),
/* harmony export */   "concat": () => (/* binding */ concat),
/* harmony export */   "union": () => (/* binding */ union),
/* harmony export */   "contains": () => (/* binding */ contains),
/* harmony export */   "insert": () => (/* binding */ insert),
/* harmony export */   "slice": () => (/* binding */ slice),
/* harmony export */   "reverse": () => (/* binding */ reverse),
/* harmony export */   "length": () => (/* binding */ length),
/* harmony export */   "inc": () => (/* binding */ inc),
/* harmony export */   "dec": () => (/* binding */ dec),
/* harmony export */   "not": () => (/* binding */ not),
/* harmony export */   "sleep": () => (/* binding */ sleep),
/* harmony export */   "delay": () => (/* binding */ delay)
/* harmony export */ });
/**
 * Utility library for manipulation of JSON data.
 *
 * Main characteristics:
 *   - input/output data types are limited to JSON data, functions and
 *     `undefined` (sparse arrays and complex objects with prototype chain are
 *     not supported)
 *   - functional API with curried functions (similar to ramdajs)
 *   - implementation based on natively supported browser JS API
 *   - scope limited to most used functions in hat projects
 *   - usage of `paths` instead of `lenses`
 *
 * TODO: define convetion for naming arguments based on their type and
 *       semantics
 *
 * @module @hat-open/util
 */

/**
 * Path can be an object property name, array index, or array of Paths
 *
 * TODO: explain paths and path compositions (include examples)
 *
 * @typedef {(String|Number|Path[])} module:@hat-open/util.Path
 */

/**
 * Identity function returning same value provided as argument.
 *
 * @function
 * @sig a -> a
 * @param {*} x input value
 * @return {*} same value as input
 */
const identity = x => x;

/**
 * Check if value is `null` or `undefined`.
 *
 * For same argument, if this function returns `true`, functions `isBoolean`,
 * `isInteger`, `isNumber`, `isString`, `isArray` and `isObject` will return
 * `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @return {Boolean}
 */
const isNil = x => x == null;

/**
 * Check if value is Boolean.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isInteger`, `isNumber`, `isString`, `isArray` and `isObject` will return
 * `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @return {Boolean}
 */
const isBoolean = x => typeof(x) == 'boolean';

/**
 * Check if value is Integer.
 *
 * For same argument, if this function returns `true`, function `isNumber` will
 * also return `true`.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isBoolean`, `isString`, `isArray` and `isObject` will return `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @type {Boolean}
 */
const isInteger = Number.isInteger;

/**
 * Check if value is Number.
 *
 * For same argument, if this function returns `true`, function `isInteger` may
 * also return `true` if argument is integer number.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isBoolean`, `isString`, `isArray` and `isObject` will return `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @return {Boolean}
 */
const isNumber = x => typeof(x) == 'number';

/**
 * Check if value is String.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isBoolean`, `isInteger`, `isNumber`, `isArray`, and `isObject` will return
 * `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {Any} x input value
 * @type {Boolean}
 */
const isString = x => typeof(x) == 'string';

/**
 * Check if value is Array.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isBoolean`, `isInteger`, `isNumber`, `isString`, and `isObject` will return
 * `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @return {Boolean}
 */
const isArray = Array.isArray;

/**
 * Check if value is Object.
 *
 * For same argument, if this function returns `true`, functions `isNil`,
 * `isBoolean`, `isInteger`, `isNumber`, `isString`, and `isArray` will return
 * `false`.
 *
 * @function
 * @sig * -> Boolean
 * @param {*} x input value
 * @return {Boolean}
 */
const isObject = x => typeof(x) == 'object' &&
                             !isArray(x) &&
                             !isNil(x);

/**
 * Strictly parse integer from string
 *
 * If provided string doesn't represent integer value, `NaN` is returned.
 *
 * @function
 * @sig String -> Number
 * @param {String} value
 * @return {Number}
 */
function strictParseInt(value) {
    if (/^(-|\+)?([0-9]+)$/.test(value))
        return Number(value);
    return NaN;
}

/**
 * Strictly parse floating point number from string
 *
 * If provided string doesn't represent valid number, `NaN` is returned.
 *
 * @function
 * @sig String -> Number
 * @param {String} value
 * @return {Number}
 */
function strictParseFloat(value) {
    if (/^(-|\+)?([0-9]+(\.[0-9]+)?)$/.test(value))
        return Number(value);
    return NaN;
}

/**
 * Create new deep copy of input value.
 *
 * In case of Objects or Arrays, new instances are created with elements
 * obtained by recursivly calling `clone` in input argument values.
 *
 * @function
 * @sig * -> *
 * @param {*} x value
 * @return {*} copy of value
 */
function clone(x) {
    if (isArray(x))
        return Array.from(x, clone);
    if (isObject(x)) {
        let ret = {};
        for (let i in x)
            ret[i] = clone(x[i]);
        return ret;
    }
    return x;
}

/**
 * Combine two arrays in single array of pairs
 *
 * The returned array is truncated to the length of the shorter of the two
 * input arrays.
 *
 * @function
 * @sig [a] -> [b] -> [[a,b]]
 * @param {Array} arr1
 * @param {Array} arr2
 * @return {Array}
 */
function zip(arr1, arr2) {
    return Array.from((function*() {
        for (let i = 0; i < arr1.length || i < arr2.length; ++i)
            yield [arr1[i], arr2[i]];
    })());
}

/**
 * Convert object to array of key, value pairs
 *
 * @function
 * @sig Object -> [[String,*]]
 * @param {Object} obj
 * @return {Array}
 */
function toPairs(obj) {
    return Object.entries(obj);
}

/**
 * Convert array of key, value pairs to object
 *
 * @function
 * @sig [[String,*]] -> Object
 * @param {Array} arr
 * @return {Object}
 */
function fromPairs(arr) {
    let ret = {};
    for (let [k, v] of arr)
        ret[k] = v;
    return ret;
}

/**
 * Flatten nested arrays.
 *
 * Create array with same elements as in input array where all elements which
 * are also arrays are replaced with elements of resulting recursive
 * application of flatten function.
 *
 * If argument is not an array, function returns the argument encapsulated in
 * an array.
 *
 * @function
 * @sig [a] -> [b]
 * @param {*} arr
 * @return {Array}
 */
function flatten(arr) {
    return isArray(arr) ? arr.flat(Infinity) : [arr];
}

/**
 * Pipe function calls
 *
 * Pipe provides functional composition with reversed order. First function
 * may have any arity and all other functions are called with only single
 * argument (result from previous function application).
 *
 * In case when no function is provided, pipe returns identity function.
 *
 * @function
 * @sig (((a1, a2, ..., an) -> b1), (b1 -> b2), ..., (bm1 -> bm)) -> ((a1, a2, ..., an) -> bm)
 * @param {...Function} fns functions
 * @return {Function}
 */
function pipe(...fns) {
    if (fns.length < 1)
        return identity;
    return function (...args) {
        let ret = fns[0].apply(this, args);
        for (let fn of fns.slice(1))
            ret = fn(ret);
        return ret;
    };
}

/**
 * Apply list of functions to same arguments and return list of results
 *
 * @function
 * @sig ((a1 -> ... -> an -> b1), ..., (a1 -> ... -> an -> bm)) -> (a1 -> ... -> an -> [b1,...,bm])
 * @param {...Function} fns functions
 * @return {Function}
 */
function flap(...fns) {
    return (...args) => fns.map(fn => fn.apply(this, args));
}

/**
 * Curry function with fixed arguments lenth
 *
 * Function arity is determined based on function's length property.
 *
 * @function
 * @sig (* -> a) -> (* -> a)
 * @param {Function} fn
 * @return {Function}
 */
function curry(fn) {
    let wrapper = function(oldArgs) {
        return function(...args) {
            args = oldArgs.concat(args);
            if (args.length >= fn.length)
                return fn(...args);
            return wrapper(args);
        };
    };
    return wrapper([]);
}

/**
 * Deep object equality
 * (curried function)
 *
 * @function
 * @sig a -> b -> Boolean
 * @param {*} x
 * @param {*} y
 * @return {Boolean}
 */
const equals = curry((x, y) => {
    if (x === y)
        return true;
    if (typeof(x) != 'object' ||
        typeof(y) != 'object' ||
        x === null ||
        y === null)
        return false;
    if (Array.isArray(x) && Array.isArray(y)) {
        if (x.length != y.length)
            return false;
        for (let [a, b] of zip(x, y)) {
            if (!equals(a, b))
                return false;
        }
        return true;
    } else if (!Array.isArray(x) && !Array.isArray(y)) {
        if (Object.keys(x).length != Object.keys(y).length)
            return false;
        for (let key in x) {
            if (!(key in y))
                return false;
        }
        for (let key in x) {
            if (!equals(x[key], y[key]))
                return false;
        }
        return true;
    }
    return false;
});


/**
 * Create array by repeating same value
 * (curried function)
 *
 * @function
 * @sig a -> Number -> [a]
 * @param {*} x
 * @param {Number} n
 * @return {Array}
 */
const repeat = curry((x, n) => Array.from({length: n}, _ => x));

/**
 * Get value referenced by path
 * (curried function)
 *
 * If input value doesn't contain provided path value, `undefined` is returned.
 *
 * @function
 * @sig Path -> a -> b
 * @param {Path} path
 * @param {*} x
 * @return {*}
 */
const get = curry((path, x) => {
    let ret = x;
    for (let i of flatten(path)) {
        if (ret === null || typeof(ret) != 'object')
            return undefined;
        ret = ret[i];
    }
    return ret;
});

/**
 * Change value referenced with path by appling function
 * (curried function)
 *
 * @function
 * @sig Path -> (a -> b) -> c -> c
 * @param {Path} path
 * @param {Function} fn
 * @param {*} x
 * @return {*}
 */
const change = curry((path, fn, x) => {
    return (function change(path, x) {
        if (path.length < 1)
            return fn(x);
        const [first, ...rest] = path;
        if (isInteger(first)) {
            x = (isArray(x) ? Array.from(x) : repeat(undefined, first));
        } else if (isString(first)) {
            x = (isObject(x) ? Object.assign({}, x) : {});
        } else {
            throw 'invalid path';
        }
        x[first] = change(rest, x[first]);
        return x;
    })(flatten(path), x);
});

/**
 * Replace value referenced with path with another value
 * (curried function)
 *
 * @function
 * @sig Path -> (a -> b) -> c -> c
 * @param {Path} path
 * @param {*} val
 * @param {*} x
 * @return {*}
 */
const set = curry((path, val, x) => change(path, _ => val, x));

/**
 * Omitting value referenced by path
 * (curried function)
 *
 * @function
 * @sig Path -> a -> a
 * @param {Path} path
 * @param {*} x
 * @return {*}
 */
const omit = curry((path, x) => {
    function _omit(path, x) {
        if (isInteger(path[0])) {
            x = (isArray(x) ? Array.from(x) : []);
        } else if (isString(path[0])) {
            x = (isObject(x) ? Object.assign({}, x) : {});
        } else {
            throw 'invalid path';
        }
        if (path.length > 1) {
            x[path[0]] = _omit(path.slice(1), x[path[0]]);
        } else if (isInteger(path[0])) {
            x.splice(path[0], 1);
        } else {
            delete x[path[0]];
        }
        return x;
    }
    path = flatten(path);
    if (path.length < 1)
        return undefined;
    return _omit(path, x);
});

/**
 * Change by moving value from source path to destination path
 * (curried function)
 *
 * @function
 * @sig Path -> Path -> a -> a
 * @param {Path} srcPath
 * @param {Path} dstPath
 * @param {*} x
 * @return {*}
 */
const move = curry((srcPath, dstPath, x) => pipe(
    set(dstPath, get(srcPath, x)),
    omit(srcPath)
)(x));

/**
 * Sort array
 * (curried function)
 *
 * Comparison function receives two arguments representing array elements and
 * should return:
 *   - negative number in case first argument is more significant then second
 *   - zero in case first argument is equaly significant as second
 *   - positive number in case first argument is less significant then second
 *
 * @function
 * @sig ((a, a) -> Number) -> [a] -> [a]
 * @param {Function} fn
 * @param {Array} arr
 * @return {Array}
 */
const sort = curry((fn, arr) => Array.from(arr).sort(fn));

/**
 * Sort array based on results of appling function to it's elements
 * (curried function)
 *
 * Resulting order is determined by comparring function application results
 * with greater then and lesser then operators.
 *
 * @function
 * @sig (a -> b) -> [a] -> [a]
 * @param {Function} fn
 * @param {Array} arr
 * @return {Array}
 */
const sortBy = curry((fn, arr) => sort((x, y) => {
    const xVal = fn(x);
    const yVal = fn(y);
    if (xVal < yVal)
        return -1;
    if (xVal > yVal)
        return 1;
    return 0;
}, arr));

/**
 * Create object containing only subset of selected properties
 * (curried function)
 *
 * @function
 * @sig [String] -> a -> a
 * @param {Array} arr
 * @param {Object} obj
 * @return {Object}
 */
const pick = curry((arr, obj) => {
    const ret = {};
    for (let i of arr)
        if (i in obj)
            ret[i] = obj[i];
    return ret;
});

/**
 * Change array or object by appling function to it's elements
 * (curried function)
 *
 * For each element, provided function is called with element value,
 * index/key and original container.
 *
 * @function
 * @sig ((a, Number, [a]) -> b) -> [a] -> [b]
 * @sig ((a, String, {String: a}) -> b) -> {String: a} -> {String: b}
 * @param {Function} fn
 * @param {Array|Object} x
 * @return {Array|Object}
 */
const map = curry((fn, x) => {
    if (isArray(x))
        return x.map(fn);
    const res = {};
    for (let k in x)
        res[k] = fn(x[k], k, x);
    return res;
});

/**
 * Change array to contain only elements for which function returns `true`
 * (curried function)
 *
 * @function
 * @sig (a -> Boolean) -> [a] -> [a]
 * @param {Function} fn
 * @param {Array} arr
 * @return {Array}
 */
const filter = curry((fn, arr) => arr.filter(fn));

/**
 * Append value to end of array
 * (curried function)
 *
 * @function
 * @sig a -> [a] -> [a]
 * @param {*} val
 * @param {Array} arr
 * @return {Array}
 */
const append = curry((val, arr) => arr.concat([val]));

/**
 * Reduce array or object by appling function
 * (curried function)
 *
 * For each element, provided function is called with accumulator,
 * elements value, element index/key and original container.
 *
 * @function
 * @sig ((b, a, Number, [a]) -> b) -> b -> [a] -> b
 * @sig ((b, a, String, {String: a}) -> b) -> b -> {String: a} -> b
 * @param {Function} fn
 * @param {*} val initial accumulator value
 * @param {Array|Object} x
 * @return {*} reduced value
 */
const reduce = curry((fn, val, x) => {
    if (isArray(x))
        return x.reduce(fn, val);
    let acc = val;
    for (let k in x)
        acc = fn(acc, x[k], k, x);
    return acc;
});

/**
 * Merge two objects
 * (curried function)
 *
 * If same property exist in both arguments, second argument's value is used
 * as resulting value
 *
 * @function
 * @sig a -> a -> a
 * @param {Object} x
 * @param {Object} y
 * @return {Object}
 */
const merge = curry((x, y) => Object.assign({}, x, y));

/**
 * Merge multiple objects
 * (curried function)
 *
 * If same property exist in multiple arguments, value from the last argument
 * containing that property is used
 *
 * @function
 * @sig [a] -> a
 * @param {Object[]}
 * @return {Object}
 */
const mergeAll = reduce(merge, {});

/**
 * Find element in array or object for which provided function returns `true`
 * (curried function)
 *
 * Until element is found, provided function is called for each element with
 * arguments: current element, current index/key and initial container.
 *
 * If searched element is not found, `undefined` is returned.
 *
 * @function
 * @sig ((a, Number, [a]) -> Boolean) -> [a] -> a
 * @sig ((a, String, {String: a}) -> Boolean) -> {String: a} -> a
 * @param {Function} fn
 * @param {Array|Object} x
 * @return {*}
 */
const find = curry((fn, x) => {
    if (isArray(x))
        return x.find(fn);
    for (let k in x)
        if (fn(x[k], k, x))
            return x[k];
});

/**
 * Find element's index/key in array or object for which provided function
 * returns `true`
 * (curried function)
 *
 * Until element is found, provided function is called for each element with
 * arguments: current element, current index/key and initial container.
 *
 * If searched element is not found, `undefined` is returned.
 *
 * @function
 * @sig ((a, Number, [a]) -> Boolean) -> [a] -> a
 * @sig ((a, String, {String: a}) -> Boolean) -> {String: a} -> a
 * @param {Function} fn
 * @param {Array|Object} x
 * @return {*}
 */
const findIndex = curry((fn, x) => {
    if (isArray(x))
        return x.findIndex(fn);
    for (let k in x)
        if (fn(x[k], k, x))
            return k;
});

/**
 * Concatenate two arrays
 * (curried function)
 *
 * @function
 * @sig [a] -> [a] -> [a]
 * @param {Array} x
 * @param {Array} y
 * @return {Array}
 */
const concat = curry((x, y) => x.concat(y));

/**
 * Create union of two arrays using `equals` to check equality
 * (curried function)
 *
 * @function
 * @sig [a] -> [a] -> [a]
 * @param {Array} x
 * @param {Array} y
 * @return {Array}
 */
const union = curry((x, y) => {
    return reduce((acc, val) => {
        if (!find(equals(val), x))
            acc = append(val, acc);
        return acc;
    }, x, y);
});

/**
 * Check if array contains value
 * (curried function)
 *
 * TODO: add support for objects (should we check for keys or values?)
 *
 * @function
 * @sig a -> [a] -> Boolean
 * @param {*} val
 * @param {Array|Object} x
 * @return {Boolean}
 */
const contains = curry((val, arr) => arr.includes(val));

/**
 * Insert value into array on specified index
 * (curried function)
 *
 * @function
 * @sig Number -> a -> [a] -> [a]
 * @param {Number} idx
 * @param {*} val
 * @param {Array} arr
 * @return {Array}
 */
const insert = curry((idx, val, arr) =>
    arr.slice(0, idx).concat([val], arr.slice(idx)));

/**
 * Get array slice
 * (curried function)
 *
 * @function
 * @sig Number -> Number -> [a] -> [a]
 * @param {Number} begin
 * @param {Number} end
 * @param {Array} arr
 * @return {Array}
 */
const slice = curry((begin, end, arr) => arr.slice(begin, end));

/**
 * Reverse array
 *
 * @function
 * @sig [a] -> [a]
 * @param  {Array} arr
 * @return {Array}
 */
function reverse(arr) {
    return Array.from(arr).reverse();
}

/**
 * Array length
 *
 * @function
 * @sig [a] -> Number
 * @param  {Array} arr
 * @return {Number}
 */
function length(arr) {
    return arr.length;
}

/**
 * Increment value
 * @param  {Number} val
 * @return {Number}
 */
function inc(val) {
    return val + 1;
}

/**
 * Decrement value
 * @param  {Number} val
 * @return {Number}
 */
function dec(val) {
    return val - 1;
}

/**
 * Logical not
 * @param  {Any} val
 * @return {Boolean}
 */
function not(val) {
    return !val;
}

/**
 * Create promise that resolves in `t` milliseconds
 *
 * TODO: move to other module
 *
 * @function
 * @sig Number -> Promise
 * @param {Number} t
 * @return {Promise}
 */
function sleep(t) {
    return new Promise(resolve => {
        setTimeout(() => { resolve(); }, t);
    });
}

/**
 * Delay function call `fn(...args)` for `t` milliseconds
 *
 * TODO: move to other module
 *
 * @function
 * @sig (((a1, a2, ..., an) -> _), Number, a1, a2, ..., an) -> Promise
 * @param {Function} fn
 * @param {Number} [t=0]
 * @param {*} args
 * @return {Promise}
 */
function delay(fn, t, ...args) {
    return new Promise(resolve => {
        setTimeout(() => { resolve(fn(...args)); }, t || 0);
    });
}


/***/ }),
/* 12 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Connection": () => (/* binding */ Connection),
/* harmony export */   "Application": () => (/* binding */ Application)
/* harmony export */ });
/* harmony import */ var jiff__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(13);
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(11);
/* harmony import */ var _hat_open_future__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(27);
/** @module @hat-open/juggler
 */








function getDefaultAddress() {
    const protocol = window.location.protocol == 'https:' ? 'wss' : 'ws';
    const hostname = window.location.hostname || 'localhost';
    const port = window.location.port;
    return `${protocol}://${hostname}` + (port ? `:${port}` : '') + '/ws';
}


/**
 * Juggler client connection
 *
 * Available events:
 *  - open - connection is opened (detail is undefined)
 *  - close - connection is closed (detail is undefined)
 *  - message - received new message (detail is received message)
 *  - change - remote data changed (detail is new remote data)
 */
class Connection extends EventTarget {

    /**
     * Create connection
     * @param {string} address Juggler server address, formatted as
     *     ``ws[s]://<host>[:<port>][/<path>]``. If not provided, hostname
     *     and port obtained from ``widow.location`` are used instead, with
     *     ``ws`` as a path.
     * @param {number} syncDelay sync delay in ms
     */
    constructor(address=getDefaultAddress(), syncDelay=100) {
        super();
        this._syncDelay = syncDelay;
        this._localData = null;
        this._remoteData = null;
        this._delayedSyncID = null;
        this._syncedLocalData = null;
        this._ws = new WebSocket(address);
        this._ws.addEventListener('open', () => this._onOpen());
        this._ws.addEventListener('close', () => this._onClose());
        this._ws.addEventListener('message', evt => this._onMessage(evt.data));
    }

    /**
     * Local data
     * @type {*}
     */
    get localData() {
        return this._localData;
    }

    /**
     * Remote data
     * @type {*}
     */
    get remoteData() {
        return this._remoteData;
    }

    /**
     * WebSocket ready state
     * @type {number}
     */
    get readyState() {
        return this._ws.readyState;
    }

    /**
     * Close connection
     */
    close() {
        this._ws.close(1000);
    }

    /**
     * Send message
     * @param {*} msg
     */
    send(msg) {
        if (this.readyState != WebSocket.OPEN) {
            throw new Error("connection not open");
        }
        this._ws.send(JSON.stringify({
            type: 'MESSAGE',
            payload: msg
        }));
    }

    /**
     * Set local data
     * @param {*} data
     */
    setLocalData(data) {
        if (this.readyState != WebSocket.OPEN) {
            throw new Error("connection not open");
        }
        this._localData = data;
        if (this._delayedSyncID != null)
            return;
        this._delayedSyncID = setTimeout(
            () => { this._onSync(); },
            this._syncDelay);
    }

    _onOpen() {
        this.dispatchEvent(new CustomEvent('open'));
    }

    _onClose() {
        if (this._delayedSyncID != null) {
            clearTimeout(this._delayedSyncID);
            this._delayedSyncID = null;
        }
        this.dispatchEvent(new CustomEvent('close'));
    }

    _onMessage(data) {
        try {
            const msg = JSON.parse(data);
            if (msg.type == 'DATA') {
                this._remoteData = jiff__WEBPACK_IMPORTED_MODULE_0__.patch(msg.payload, this._remoteData);
                this.dispatchEvent(new CustomEvent('change', {detail: this._remoteData}));
            } else if (msg.type == 'MESSAGE') {
                this.dispatchEvent(new CustomEvent('message', {detail: msg.payload}));
            } else {
                throw new Error('unsupported message type');
            }
        } catch (e) {
            this._ws.close();
            throw e;
        }
    }

    _onSync() {
        const patch = jiff__WEBPACK_IMPORTED_MODULE_0__.diff(this._syncedLocalData, this._localData);
        if (patch.length > 0) {
            this._ws.send(JSON.stringify({
                type: 'DATA',
                payload: patch
            }));
            this._syncedLocalData = this._localData;
        }
        this._delayedSyncID = null;
    }

}


/**
 * Juggler based application
 *
 * Available events:
 *  - connected - connected to server (detail is undefined)
 *  - disconnected - disconnected from server (detail is undefined)
 *  - message - received new message (detail is received message)
 */
class Application extends EventTarget {

    /**
     * Create application
     * @param {?module:@hat-open/util.Path} localPath local data state path
     * @param {?module:@hat-open/util.Path} remotePath remote data state path
     * @param {object} localRpcCbs local RPC function callbacs
     * @param {module:@hat-open/renderer.Renderer} renderer renderer
     * @param {string} address juggler server address, see
     *     {@link module:@hat-open/juggler.Connection}
     */
    constructor(
        localPath=null,
        remotePath=null,
        localRpcCbs={},
        renderer=_hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default,
        address=getDefaultAddress(),
        syncDelay=100,
        retryDelay=5000) {

        super();
        this._localPath = localPath;
        this._remotePath = remotePath;
        this._localRpcCbs = localRpcCbs;
        this._renderer = renderer;
        this._address = address;
        this._syncDelay = syncDelay;
        this._retryDelay = retryDelay;
        this._conn = null;
        this._lastRpcId = 0;
        this._rpcFutures = new Map();
        this._rpc = new Proxy({}, {
            get: (_, action) => (...args) => this._rpcCall(action, args)
        });

        if (localPath != null)
            renderer.addEventListener('change', () => this._onRendererChange());

        _hat_open_util__WEBPACK_IMPORTED_MODULE_2__.delay(() => this._connectLoop());
    }

    /**
     * RPC proxy
     * @type {*}
     */
    get rpc() {
        return this._rpc;
    }

    /**
     * Send message
     * @param {*} msg
     */
    send(msg) {
        if (!this._conn)
            throw new Error("connection closed");
        this._conn.send(msg);
    }

    _onOpen() {
        if (this._localPath)
            this._conn.setLocalData(this._renderer.get(this._localPath));
        this.dispatchEvent(new CustomEvent('connected'));
    }

    _onClose() {
        if (this._remotePath)
            this._renderer.set(this._remotePath, null);
        this.dispatchEvent(new CustomEvent('disconnected'));
    }

    _onMessage(msg) {
        if (_hat_open_util__WEBPACK_IMPORTED_MODULE_2__.isObject(msg) && msg.type == 'rpc') {
            this._onRpcMessage(msg);
        } else {
            this.dispatchEvent(new CustomEvent('message', {detail: msg}));
        }
    }

    _onRpcMessage(msg) {
        if (msg.direction == 'request') {
            this._onRpcReqMessage(msg);
        } else if (msg.direction == 'response') {
            this._onRpcResMessage(msg);
        }
    }

    _onRpcReqMessage(msg) {
        let success;
        let result;
        try {
            result = this._localRpcCbs[msg.action](...msg.args);
            success = true;
        } catch (e) {
            result = String(e);
            success = false;
        }
        this.send({
            type: 'rpc',
            id: msg.id,
            direction: 'response',
            success: success,
            result: result
        });
    }

    _onRpcResMessage(msg) {
        const f = this._rpcFutures.get(msg.id);
        this._rpcFutures.delete(msg.id);
        if (msg.success) {
            f.setResult(msg.result);
        } else {
            f.setError(msg.result);
        }
    }

    _onConnectionChange(data) {
        if (this._remotePath == null)
            return;
        this._renderer.set(this._remotePath, data);
    }

    _onRendererChange() {
        if (!this._conn || this._conn.readyState != WebSocket.OPEN)
            return;
        this._conn.setLocalData(this._renderer.get(this._localPath));
    }

    _rpcCall(action, args) {
        this._lastRpcId += 1;
        this.send({
            type: 'rpc',
            id: this._lastRpcId,
            direction: 'request',
            action: action,
            args: args});
        const f = _hat_open_future__WEBPACK_IMPORTED_MODULE_3__.create();
        this._rpcFutures.set(this._lastRpcId, f);
        return f;
    }

    async _connectLoop() {
        while (true) {
            this._conn = new Connection(this._address, this._syncDelay);
            this._conn.addEventListener('open', () => this._onOpen());
            this._conn.addEventListener('close', () => this._onClose());
            this._conn.addEventListener('message', evt => this._onMessage(evt.detail));
            this._conn.addEventListener('change', evt => this._onConnectionChange(evt.detail));

            const closeFuture = _hat_open_future__WEBPACK_IMPORTED_MODULE_3__.create();
            this._conn.addEventListener('close', () => closeFuture.setResult());
            await closeFuture;
            this._conn = null;
            await _hat_open_util__WEBPACK_IMPORTED_MODULE_2__.sleep(this._retryDelay);
        }
    }

}


/***/ }),
/* 13 */
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

var lcs = __webpack_require__(14);
var array = __webpack_require__(15);
var patch = __webpack_require__(16);
var inverse = __webpack_require__(26);
var jsonPointer = __webpack_require__(18);
var encodeSegment = jsonPointer.encodeSegment;

exports.diff = diff;
exports.patch = patch.apply;
exports.patchInPlace = patch.applyInPlace;
exports.inverse = inverse;
exports.clone = patch.clone;

// Errors
exports.InvalidPatchOperationError = __webpack_require__(24);
exports.TestFailedError = __webpack_require__(23);
exports.PatchNotInvertibleError = __webpack_require__(25);

var isValidObject = patch.isValidObject;
var defaultHash = patch.defaultHash;

/**
 * Compute a JSON Patch representing the differences between a and b.
 * @param {object|array|string|number|null} a
 * @param {object|array|string|number|null} b
 * @param {?function|?object} options if a function, see options.hash
 * @param {?function(x:*):String|Number} options.hash used to hash array items
 *  in order to recognize identical objects, defaults to JSON.stringify
 * @param {?function(index:Number, array:Array):object} options.makeContext
 *  used to generate patch context. If not provided, context will not be generated
 * @returns {array} JSON Patch such that patch(diff(a, b), a) ~ b
 */
function diff(a, b, options) {
	return appendChanges(a, b, '', initState(options, [])).patch;
}

/**
 * Create initial diff state from the provided options
 * @param {?function|?object} options @see diff options above
 * @param {array} patch an empty or existing JSON Patch array into which
 *  the diff should generate new patch operations
 * @returns {object} initialized diff state
 */
function initState(options, patch) {
	if(typeof options === 'object') {
		return {
			patch: patch,
			hash: orElse(isFunction, options.hash, defaultHash),
			makeContext: orElse(isFunction, options.makeContext, defaultContext),
			invertible: !(options.invertible === false)
		};
	} else {
		return {
			patch: patch,
			hash: orElse(isFunction, options, defaultHash),
			makeContext: defaultContext,
			invertible: true
		};
	}
}

/**
 * Given two JSON values (object, array, number, string, etc.), find their
 * differences and append them to the diff state
 * @param {object|array|string|number|null} a
 * @param {object|array|string|number|null} b
 * @param {string} path
 * @param {object} state
 * @returns {Object} updated diff state
 */
function appendChanges(a, b, path, state) {
	if(Array.isArray(a) && Array.isArray(b)) {
		return appendArrayChanges(a, b, path, state);
	}

	if(isValidObject(a) && isValidObject(b)) {
		return appendObjectChanges(a, b, path, state);
	}

	return appendValueChanges(a, b, path, state);
}

/**
 * Given two objects, find their differences and append them to the diff state
 * @param {object} o1
 * @param {object} o2
 * @param {string} path
 * @param {object} state
 * @returns {Object} updated diff state
 */
function appendObjectChanges(o1, o2, path, state) {
	var keys = Object.keys(o2);
	var patch = state.patch;
	var i, key;

	for(i=keys.length-1; i>=0; --i) {
		key = keys[i];
		var keyPath = path + '/' + encodeSegment(key);
		if(o1[key] !== void 0) {
			appendChanges(o1[key], o2[key], keyPath, state);
		} else {
			patch.push({ op: 'add', path: keyPath, value: o2[key] });
		}
	}

	keys = Object.keys(o1);
	for(i=keys.length-1; i>=0; --i) {
		key = keys[i];
		if(o2[key] === void 0) {
			var p = path + '/' + encodeSegment(key);
			if(state.invertible) {
				patch.push({ op: 'test', path: p, value: o1[key] });
			}
			patch.push({ op: 'remove', path: p });
		}
	}

	return state;
}

/**
 * Given two arrays, find their differences and append them to the diff state
 * @param {array} a1
 * @param {array} a2
 * @param {string} path
 * @param {object} state
 * @returns {Object} updated diff state
 */
function appendArrayChanges(a1, a2, path, state) {
	var a1hash = array.map(state.hash, a1);
	var a2hash = array.map(state.hash, a2);

	var lcsMatrix = lcs.compare(a1hash, a2hash);

	return lcsToJsonPatch(a1, a2, path, state, lcsMatrix);
}

/**
 * Transform an lcsMatrix into JSON Patch operations and append
 * them to state.patch, recursing into array elements as necessary
 * @param {array} a1
 * @param {array} a2
 * @param {string} path
 * @param {object} state
 * @param {object} lcsMatrix
 * @returns {object} new state with JSON Patch operations added based
 *  on the provided lcsMatrix
 */
function lcsToJsonPatch(a1, a2, path, state, lcsMatrix) {
	var offset = 0;
	return lcs.reduce(function(state, op, i, j) {
		var last, context;
		var patch = state.patch;
		var p = path + '/' + (j + offset);

		if (op === lcs.REMOVE) {
			// Coalesce adjacent remove + add into replace
			last = patch[patch.length-1];
			context = state.makeContext(j, a1);

			if(state.invertible) {
				patch.push({ op: 'test', path: p, value: a1[j], context: context });
			}

			if(last !== void 0 && last.op === 'add' && last.path === p) {
				last.op = 'replace';
				last.context = context;
			} else {
				patch.push({ op: 'remove', path: p, context: context });
			}

			offset -= 1;

		} else if (op === lcs.ADD) {
			// See https://tools.ietf.org/html/rfc6902#section-4.1
			// May use either index===length *or* '-' to indicate appending to array
			patch.push({ op: 'add', path: p, value: a2[i],
				context: state.makeContext(j, a1)
			});

			offset += 1;

		} else {
			appendChanges(a1[j], a2[i], p, state);
		}

		return state;

	}, state, lcsMatrix);
}

/**
 * Given two number|string|null values, if they differ, append to diff state
 * @param {string|number|null} a
 * @param {string|number|null} b
 * @param {string} path
 * @param {object} state
 * @returns {object} updated diff state
 */
function appendValueChanges(a, b, path, state) {
	if(a !== b) {
		if(state.invertible) {
			state.patch.push({ op: 'test', path: path, value: a });
		}

		state.patch.push({ op: 'replace', path: path, value: b });
	}

	return state;
}

/**
 * @param {function} predicate
 * @param {*} x
 * @param {*} y
 * @returns {*} x if predicate(x) is truthy, otherwise y
 */
function orElse(predicate, x, y) {
	return predicate(x) ? x : y;
}

/**
 * Default patch context generator
 * @returns {undefined} undefined context
 */
function defaultContext() {
	return void 0;
}

/**
 * @param {*} x
 * @returns {boolean} true if x is a function, false otherwise
 */
function isFunction(x) {
	return typeof x === 'function';
}


/***/ }),
/* 14 */
/***/ ((__unused_webpack_module, exports) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

exports.compare = compare;
exports.reduce = reduce;

var REMOVE, RIGHT, ADD, DOWN, SKIP;

exports.REMOVE = REMOVE = RIGHT = -1;
exports.ADD    = ADD    = DOWN  =  1;
exports.EQUAL  = SKIP   = 0;

/**
 * Create an lcs comparison matrix describing the differences
 * between two array-like sequences
 * @param {array} a array-like
 * @param {array} b array-like
 * @returns {object} lcs descriptor, suitable for passing to reduce()
 */
function compare(a, b) {
	var cols = a.length;
	var rows = b.length;

	var prefix = findPrefix(a, b);
	var suffix = prefix < cols && prefix < rows
		? findSuffix(a, b, prefix)
		: 0;

	var remove = suffix + prefix - 1;
	cols -= remove;
	rows -= remove;
	var matrix = createMatrix(cols, rows);

	for (var j = cols - 1; j >= 0; --j) {
		for (var i = rows - 1; i >= 0; --i) {
			matrix[i][j] = backtrack(matrix, a, b, prefix, j, i);
		}
	}

	return {
		prefix: prefix,
		matrix: matrix,
		suffix: suffix
	};
}

/**
 * Reduce a set of lcs changes previously created using compare
 * @param {function(result:*, type:number, i:number, j:number)} f
 *  reducer function, where:
 *  - result is the current reduce value,
 *  - type is the type of change: ADD, REMOVE, or SKIP
 *  - i is the index of the change location in b
 *  - j is the index of the change location in a
 * @param {*} r initial value
 * @param {object} lcs results returned by compare()
 * @returns {*} the final reduced value
 */
function reduce(f, r, lcs) {
	var i, j, k, op;

	var m = lcs.matrix;

	// Reduce shared prefix
	var l = lcs.prefix;
	for(i = 0;i < l; ++i) {
		r = f(r, SKIP, i, i);
	}

	// Reduce longest change span
	k = i;
	l = m.length;
	i = 0;
	j = 0;
	while(i < l) {
		op = m[i][j].type;
		r = f(r, op, i+k, j+k);

		switch(op) {
			case SKIP:  ++i; ++j; break;
			case RIGHT: ++j; break;
			case DOWN:  ++i; break;
		}
	}

	// Reduce shared suffix
	i += k;
	j += k;
	l = lcs.suffix;
	for(k = 0;k < l; ++k) {
		r = f(r, SKIP, i+k, j+k);
	}

	return r;
}

function findPrefix(a, b) {
	var i = 0;
	var l = Math.min(a.length, b.length);
	while(i < l && a[i] === b[i]) {
		++i;
	}
	return i;
}

function findSuffix(a, b) {
	var al = a.length - 1;
	var bl = b.length - 1;
	var l = Math.min(al, bl);
	var i = 0;
	while(i < l && a[al-i] === b[bl-i]) {
		++i;
	}
	return i;
}

function backtrack(matrix, a, b, start, j, i) {
	if (a[j+start] === b[i+start]) {
		return { value: matrix[i + 1][j + 1].value, type: SKIP };
	}
	if (matrix[i][j + 1].value < matrix[i + 1][j].value) {
		return { value: matrix[i][j + 1].value + 1, type: RIGHT };
	}

	return { value: matrix[i + 1][j].value + 1, type: DOWN };
}

function createMatrix (cols, rows) {
	var m = [], i, j, lastrow;

	// Fill the last row
	lastrow = m[rows] = [];
	for (j = 0; j<cols; ++j) {
		lastrow[j] = { value: cols - j, type: RIGHT };
	}

	// Fill the last col
	for (i = 0; i<rows; ++i) {
		m[i] = [];
		m[i][cols] = { value: rows - i, type: DOWN };
	}

	// Fill the last cell
	m[rows][cols] = { value: 0, type: SKIP };

	return m;
}


/***/ }),
/* 15 */
/***/ ((__unused_webpack_module, exports) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

exports.cons = cons;
exports.tail = tail;
exports.map = map;

/**
 * Prepend x to a, without mutating a. Faster than a.unshift(x)
 * @param {*} x
 * @param {Array} a array-like
 * @returns {Array} new Array with x prepended
 */
function cons(x, a) {
	var l = a.length;
	var b = new Array(l+1);
	b[0] = x;
	for(var i=0; i<l; ++i) {
		b[i+1] = a[i];
	}

	return b;
}

/**
 * Create a new Array containing all elements in a, except the first.
 *  Faster than a.slice(1)
 * @param {Array} a array-like
 * @returns {Array} new Array, the equivalent of a.slice(1)
 */
function tail(a) {
	var l = a.length-1;
	var b = new Array(l);
	for(var i=0; i<l; ++i) {
		b[i] = a[i+1];
	}

	return b;
}

/**
 * Map any array-like. Faster than Array.prototype.map
 * @param {function} f
 * @param {Array} a array-like
 * @returns {Array} new Array mapped by f
 */
function map(f, a) {
	var b = new Array(a.length);
	for(var i=0; i< a.length; ++i) {
		b[i] = f(a[i]);
	}
	return b;
}

/***/ }),
/* 16 */
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

var patches = __webpack_require__(17);
var clone = __webpack_require__(20);
var InvalidPatchOperationError = __webpack_require__(24);

exports.apply = patch;
exports.applyInPlace = patchInPlace;
exports.clone = clone;
exports.isValidObject = isValidObject;
exports.defaultHash = defaultHash;

var defaultOptions = {};

/**
 * Apply the supplied JSON Patch to x
 * @param {array} changes JSON Patch
 * @param {object|array|string|number} x object/array/value to patch
 * @param {object} options
 * @param {function(index:Number, array:Array, context:object):Number} options.findContext
 *  function used adjust array indexes for smarty/fuzzy patching, for
 *  patches containing context
 * @returns {object|array|string|number} patched version of x. If x is
 *  an array or object, it will be mutated and returned. Otherwise, if
 *  x is a value, the new value will be returned.
 */
function patch(changes, x, options) {
	return patchInPlace(changes, clone(x), options);
}

function patchInPlace(changes, x, options) {
	if(!options) {
		options = defaultOptions;
	}

	// TODO: Consider throwing if changes is not an array
	if(!Array.isArray(changes)) {
		return x;
	}

	var patch, p;
	for(var i=0; i<changes.length; ++i) {
		p = changes[i];
		patch = patches[p.op];

		if(patch === void 0) {
			throw new InvalidPatchOperationError('invalid op ' + JSON.stringify(p));
		}

		x = patch.apply(x, p, options);
	}

	return x;
}

function defaultHash(x) {
	return isValidObject(x) || isArray(x) ? JSON.stringify(x) : x;
}

function isValidObject (x) {
	return x !== null && Object.prototype.toString.call(x) === '[object Object]';
}

function isArray (x) {
	return Object.prototype.toString.call(x) === '[object Array]';
}


/***/ }),
/* 17 */
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

var jsonPointer = __webpack_require__(18);
var clone = __webpack_require__(20);
var deepEquals = __webpack_require__(21);
var commutePaths = __webpack_require__(22);

var array = __webpack_require__(15);

var TestFailedError = __webpack_require__(23);
var InvalidPatchOperationError = __webpack_require__(24);
var PatchNotInvertibleError = __webpack_require__(25);

var find = jsonPointer.find;
var parseArrayIndex = jsonPointer.parseArrayIndex;

exports.test = {
	apply: applyTest,
	inverse: invertTest,
	commute: commuteTest
};

exports.add = {
	apply: applyAdd,
	inverse: invertAdd,
	commute: commuteAddOrCopy
};

exports.remove = {
	apply: applyRemove,
	inverse: invertRemove,
	commute: commuteRemove
};

exports.replace = {
	apply: applyReplace,
	inverse: invertReplace,
	commute: commuteReplace
};

exports.move = {
	apply: applyMove,
	inverse: invertMove,
	commute: commuteMove
};

exports.copy = {
	apply: applyCopy,
	inverse: notInvertible,
	commute: commuteAddOrCopy
};

/**
 * Apply a test operation to x
 * @param {object|array} x
 * @param {object} test test operation
 * @throws {TestFailedError} if the test operation fails
 */

function applyTest(x, test, options) {
	var pointer = find(x, test.path, options.findContext, test.context);
	var target = pointer.target;
	var index, value;

	if(Array.isArray(target)) {
		index = parseArrayIndex(pointer.key);
		//index = findIndex(options.findContext, index, target, test.context);
		value = target[index];
	} else {
		value = pointer.key === void 0 ? pointer.target : pointer.target[pointer.key];
	}

	if(!deepEquals(value, test.value)) {
		throw new TestFailedError('test failed ' + JSON.stringify(test));
	}

	return x;
}

/**
 * Invert the provided test and add it to the inverted patch sequence
 * @param pr
 * @param test
 * @returns {number}
 */
function invertTest(pr, test) {
	pr.push(test);
	return 1;
}

function commuteTest(test, b) {
	if(test.path === b.path && b.op === 'remove') {
		throw new TypeError('Can\'t commute test,remove -> remove,test for same path');
	}

	if(b.op === 'test' || b.op === 'replace') {
		return [b, test];
	}

	return commutePaths(test, b);
}

/**
 * Apply an add operation to x
 * @param {object|array} x
 * @param {object} change add operation
 */
function applyAdd(x, change, options) {
	var pointer = find(x, change.path, options.findContext, change.context);

	if(notFound(pointer)) {
		throw new InvalidPatchOperationError('path does not exist ' + change.path);
	}

	if(change.value === void 0) {
		throw new InvalidPatchOperationError('missing value');
	}

	var val = clone(change.value);

	// If pointer refers to whole document, replace whole document
	if(pointer.key === void 0) {
		return val;
	}

	_add(pointer, val);
	return x;
}

function _add(pointer, value) {
	var target = pointer.target;

	if(Array.isArray(target)) {
		// '-' indicates 'append' to array
		if(pointer.key === '-') {
			target.push(value);
		} else if (pointer.key > target.length) {
			throw new InvalidPatchOperationError('target of add outside of array bounds')
		} else {
			target.splice(pointer.key, 0, value);
		}
	} else if(isValidObject(target)) {
		target[pointer.key] = value;
	} else {
		throw new InvalidPatchOperationError('target of add must be an object or array ' + pointer.key);
	}
}

function invertAdd(pr, add) {
	var context = add.context;
	if(context !== void 0) {
		context = {
			before: context.before,
			after: array.cons(add.value, context.after)
		}
	}
	pr.push({ op: 'test', path: add.path, value: add.value, context: context });
	pr.push({ op: 'remove', path: add.path, context: context });
	return 1;
}

function commuteAddOrCopy(add, b) {
	if(add.path === b.path && b.op === 'remove') {
		throw new TypeError('Can\'t commute add,remove -> remove,add for same path');
	}

	return commutePaths(add, b);
}

/**
 * Apply a replace operation to x
 * @param {object|array} x
 * @param {object} change replace operation
 */
function applyReplace(x, change, options) {
	var pointer = find(x, change.path, options.findContext, change.context);

	if(notFound(pointer) || missingValue(pointer)) {
		throw new InvalidPatchOperationError('path does not exist ' + change.path);
	}

	if(change.value === void 0) {
		throw new InvalidPatchOperationError('missing value');
	}

	var value = clone(change.value);

	// If pointer refers to whole document, replace whole document
	if(pointer.key === void 0) {
		return value;
	}

	var target = pointer.target;

	if(Array.isArray(target)) {
		target[parseArrayIndex(pointer.key)] = value;
	} else {
		target[pointer.key] = value;
	}

	return x;
}

function invertReplace(pr, c, i, patch) {
	var prev = patch[i-1];
	if(prev === void 0 || prev.op !== 'test' || prev.path !== c.path) {
		throw new PatchNotInvertibleError('cannot invert replace w/o test');
	}

	var context = prev.context;
	if(context !== void 0) {
		context = {
			before: context.before,
			after: array.cons(prev.value, array.tail(context.after))
		}
	}

	pr.push({ op: 'test', path: prev.path, value: c.value });
	pr.push({ op: 'replace', path: prev.path, value: prev.value });
	return 2;
}

function commuteReplace(replace, b) {
	if(replace.path === b.path && b.op === 'remove') {
		throw new TypeError('Can\'t commute replace,remove -> remove,replace for same path');
	}

	if(b.op === 'test' || b.op === 'replace') {
		return [b, replace];
	}

	return commutePaths(replace, b);
}

/**
 * Apply a remove operation to x
 * @param {object|array} x
 * @param {object} change remove operation
 */
function applyRemove(x, change, options) {
	var pointer = find(x, change.path, options.findContext, change.context);

	// key must exist for remove
	if(notFound(pointer) || pointer.target[pointer.key] === void 0) {
		throw new InvalidPatchOperationError('path does not exist ' + change.path);
	}

	_remove(pointer);
	return x;
}

function _remove (pointer) {
	var target = pointer.target;

	var removed;
	if (Array.isArray(target)) {
		removed = target.splice(parseArrayIndex(pointer.key), 1);
		return removed[0];

	} else if (isValidObject(target)) {
		removed = target[pointer.key];
		delete target[pointer.key];
		return removed;

	} else {
		throw new InvalidPatchOperationError('target of remove must be an object or array');
	}
}

function invertRemove(pr, c, i, patch) {
	var prev = patch[i-1];
	if(prev === void 0 || prev.op !== 'test' || prev.path !== c.path) {
		throw new PatchNotInvertibleError('cannot invert remove w/o test');
	}

	var context = prev.context;
	if(context !== void 0) {
		context = {
			before: context.before,
			after: array.tail(context.after)
		}
	}

	pr.push({ op: 'add', path: prev.path, value: prev.value, context: context });
	return 2;
}

function commuteRemove(remove, b) {
	if(remove.path === b.path && b.op === 'remove') {
		return [b, remove];
	}

	return commutePaths(remove, b);
}

/**
 * Apply a move operation to x
 * @param {object|array} x
 * @param {object} change move operation
 */
function applyMove(x, change, options) {
	if(jsonPointer.contains(change.path, change.from)) {
		throw new InvalidPatchOperationError('move.from cannot be ancestor of move.path');
	}

	var pto = find(x, change.path, options.findContext, change.context);
	var pfrom = find(x, change.from, options.findContext, change.fromContext);

	_add(pto, _remove(pfrom));
	return x;
}

function invertMove(pr, c) {
	pr.push({ op: 'move',
		path: c.from, context: c.fromContext,
		from: c.path, fromContext: c.context });
	return 1;
}

function commuteMove(move, b) {
	if(move.path === b.path && b.op === 'remove') {
		throw new TypeError('Can\'t commute move,remove -> move,replace for same path');
	}

	return commutePaths(move, b);
}

/**
 * Apply a copy operation to x
 * @param {object|array} x
 * @param {object} change copy operation
 */
function applyCopy(x, change, options) {
	var pto = find(x, change.path, options.findContext, change.context);
	var pfrom = find(x, change.from, options.findContext, change.fromContext);

	if(notFound(pfrom) || missingValue(pfrom)) {
		throw new InvalidPatchOperationError('copy.from must exist');
	}

	var target = pfrom.target;
	var value;

	if(Array.isArray(target)) {
		value = target[parseArrayIndex(pfrom.key)];
	} else {
		value = target[pfrom.key];
	}

	_add(pto, clone(value));
	return x;
}

// NOTE: Copy is not invertible
// See https://github.com/cujojs/jiff/issues/9
// This needs more thought. We may have to extend/amend JSON Patch.
// At first glance, this seems like it should just be a remove.
// However, that's not correct.  It violates the involution:
// invert(invert(p)) ~= p.  For example:
// invert(copy) -> remove
// invert(remove) -> add
// thus: invert(invert(copy)) -> add (DOH! this should be copy!)

function notInvertible(_, c) {
	throw new PatchNotInvertibleError('cannot invert ' + c.op);
}

function notFound (pointer) {
	return pointer === void 0 || (pointer.target == null && pointer.key !== void 0);
}

function missingValue(pointer) {
	return pointer.key !== void 0 && pointer.target[pointer.key] === void 0;
}

/**
 * Return true if x is a non-null object
 * @param {*} x
 * @returns {boolean}
 */
function isValidObject (x) {
	return x !== null && typeof x === 'object';
}


/***/ }),
/* 18 */
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

var _parse = __webpack_require__(19);

exports.find = find;
exports.join = join;
exports.absolute = absolute;
exports.parse = parse;
exports.contains = contains;
exports.encodeSegment = encodeSegment;
exports.decodeSegment = decodeSegment;
exports.parseArrayIndex = parseArrayIndex;
exports.isValidArrayIndex = isValidArrayIndex;

// http://tools.ietf.org/html/rfc6901#page-2
var separator = '/';
var separatorRx = /\//g;
var encodedSeparator = '~1';
var encodedSeparatorRx = /~1/g;

var escapeChar = '~';
var escapeRx = /~/g;
var encodedEscape = '~0';
var encodedEscapeRx = /~0/g;

/**
 * Find the parent of the specified path in x and return a descriptor
 * containing the parent and a key.  If the parent does not exist in x,
 * return undefined, instead.
 * @param {object|array} x object or array in which to search
 * @param {string} path JSON Pointer string (encoded)
 * @param {?function(index:Number, array:Array, context:object):Number} findContext
 *  optional function used adjust array indexes for smarty/fuzzy patching, for
 *  patches containing context.  If provided, context MUST also be provided.
 * @param {?{before:Array, after:Array}} context optional patch context for
 *  findContext to use to adjust array indices.  If provided, findContext MUST
 *  also be provided.
 * @returns {{target:object|array|number|string, key:string}|undefined}
 */
function find(x, path, findContext, context) {
	if(typeof path !== 'string') {
		return;
	}

	if(path === '') {
		// whole document
		return { target: x, key: void 0 };
	}

	if(path === separator) {
		return { target: x, key: '' };
	}

	var parent = x, key;
	var hasContext = context !== void 0;

	_parse(path, function(segment) {
		// hm... this seems like it should be if(typeof x === 'undefined')
		if(x == null) {
			// Signal that we prematurely hit the end of the path hierarchy.
			parent = null;
			return false;
		}

		if(Array.isArray(x)) {
			key = hasContext
				? findIndex(findContext, parseArrayIndex(segment), x, context)
				: segment === '-' ? segment : parseArrayIndex(segment);
		} else {
			key = segment;
		}

		parent = x;
		x = x[key];
	});

	return parent === null
		? void 0
		: { target: parent, key: key };
}

function absolute(path) {
	return path[0] === separator ? path : separator + path;
}

function join(segments) {
	return segments.join(separator);
}

function parse(path) {
	var segments = [];
	_parse(path, segments.push.bind(segments));
	return segments;
}

function contains(a, b) {
	return b.indexOf(a) === 0 && b[a.length] === separator;
}

/**
 * Decode a JSON Pointer path segment
 * @see http://tools.ietf.org/html/rfc6901#page-3
 * @param {string} s encoded segment
 * @returns {string} decoded segment
 */
function decodeSegment(s) {
	// See: http://tools.ietf.org/html/rfc6901#page-3
	return s.replace(encodedSeparatorRx, separator).replace(encodedEscapeRx, escapeChar);
}

/**
 * Encode a JSON Pointer path segment
 * @see http://tools.ietf.org/html/rfc6901#page-3
 * @param {string} s decoded segment
 * @returns {string} encoded segment
 */
function encodeSegment(s) {
	return s.replace(escapeRx, encodedEscape).replace(separatorRx, encodedSeparator);
}

var arrayIndexRx = /^(0|[1-9]\d*)$/;

/**
 * Return true if s is a valid JSON Pointer array index
 * @param {String} s
 * @returns {boolean}
 */
function isValidArrayIndex(s) {
	return arrayIndexRx.test(s);
}

/**
 * Safely parse a string into a number >= 0. Does not check for decimal numbers
 * @param {string} s numeric string
 * @returns {number} number >= 0
 */
function parseArrayIndex (s) {
	if(isValidArrayIndex(s)) {
		return +s;
	}

	throw new SyntaxError('invalid array index ' + s);
}

function findIndex (findContext, start, array, context) {
	var index = start;

	if(index < 0) {
		throw new Error('array index out of bounds ' + index);
	}

	if(context !== void 0 && typeof findContext === 'function') {
		index = findContext(start, array, context);
		if(index < 0) {
			throw new Error('could not find patch context ' + context);
		}
	}

	return index;
}

/***/ }),
/* 19 */
/***/ ((module) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

module.exports = jsonPointerParse;

var parseRx = /\/|~1|~0/g;
var separator = '/';
var escapeChar = '~';
var encodedSeparator = '~1';

/**
 * Parse through an encoded JSON Pointer string, decoding each path segment
 * and passing it to an onSegment callback function.
 * @see https://tools.ietf.org/html/rfc6901#section-4
 * @param {string} path encoded JSON Pointer string
 * @param {{function(segment:string):boolean}} onSegment callback function
 * @returns {string} original path
 */
function jsonPointerParse(path, onSegment) {
	var pos, accum, matches, match;

	pos = path.charAt(0) === separator ? 1 : 0;
	accum = '';
	parseRx.lastIndex = pos;

	while(matches = parseRx.exec(path)) {

		match = matches[0];
		accum += path.slice(pos, parseRx.lastIndex - match.length);
		pos = parseRx.lastIndex;

		if(match === separator) {
			if (onSegment(accum) === false) return path;
			accum = '';
		} else {
			accum += match === encodedSeparator ? separator : escapeChar;
		}
	}

	accum += path.slice(pos);
	onSegment(accum);

	return path;
}


/***/ }),
/* 20 */
/***/ ((module) => {

/** @license MIT License (c) copyright 2010-2014 original author or authors */
/** @author Brian Cavalier */
/** @author John Hann */

/**
 * Create a deep copy of x which must be a legal JSON object/array/value
 * @param {object|array|string|number|null} x object/array/value to clone
 * @returns {object|array|string|number|null} clone of x
 */
module.exports = clone;

function clone(x) {
	if(x == null || typeof x !== 'object') {
		return x;
	}

	if(Array.isArray(x)) {
		return cloneArray(x);
	}

	return cloneObject(x);
}

function cloneArray (x) {
	var l = x.length;
	var y = new Array(l);

	for (var i = 0; i < l; ++i) {
		y[i] = clone(x[i]);
	}

	return y;
}

function cloneObject (x) {
	var keys = Object.keys(x);
	var y = {};

	for (var k, i = 0, l = keys.length; i < l; ++i) {
		k = keys[i];
		y[k] = clone(x[k]);
	}

	return y;
}


/***/ }),
/* 21 */
/***/ ((module) => {

module.exports = deepEquals;

/**
 * Compare 2 JSON values, or recursively compare 2 JSON objects or arrays
 * @param {object|array|string|number|boolean|null} a
 * @param {object|array|string|number|boolean|null} b
 * @returns {boolean} true iff a and b are recursively equal
 */
function deepEquals(a, b) {
	if(a === b) {
		return true;
	}

	if(Array.isArray(a) && Array.isArray(b)) {
		return compareArrays(a, b);
	}

	if(typeof a === 'object' && typeof b === 'object') {
		return compareObjects(a, b);
	}

	return false;
}

function compareArrays(a, b) {
	if(a.length !== b.length) {
		return false;
	}

	for(var i = 0; i<a.length; ++i) {
		if(!deepEquals(a[i], b[i])) {
			return false;
		}
	}

	return true;
}

function compareObjects(a, b) {
	if((a === null && b !== null) || (a !== null && b === null)) {
		return false;
	}

	var akeys = Object.keys(a);
	var bkeys = Object.keys(b);

	if(akeys.length !== bkeys.length) {
		return false;
	}

	for(var i = 0, k; i<akeys.length; ++i) {
		k = akeys[i];
		if(!(k in b && deepEquals(a[k], b[k]))) {
			return false;
		}
	}

	return true;
}

/***/ }),
/* 22 */
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var jsonPointer = __webpack_require__(18);

/**
 * commute the patch sequence a,b to b,a
 * @param {object} a patch operation
 * @param {object} b patch operation
 */
module.exports = function commutePaths(a, b) {
	// TODO: cases for special paths: '' and '/'
	var left = jsonPointer.parse(a.path);
	var right = jsonPointer.parse(b.path);
	var prefix = getCommonPathPrefix(left, right);
	var isArray = isArrayPath(left, right, prefix.length);

	// Never mutate the originals
	var ac = copyPatch(a);
	var bc = copyPatch(b);

	if(prefix.length === 0 && !isArray) {
		// Paths share no common ancestor, simple swap
		return [bc, ac];
	}

	if(isArray) {
		return commuteArrayPaths(ac, left, bc, right);
	} else {
		return commuteTreePaths(ac, left, bc, right);
	}
};

function commuteTreePaths(a, left, b, right) {
	if(a.path === b.path) {
		throw new TypeError('cannot commute ' + a.op + ',' + b.op + ' with identical object paths');
	}
	// FIXME: Implement tree path commutation
	return [b, a];
}

/**
 * Commute two patches whose common ancestor (which may be the immediate parent)
 * is an array
 * @param a
 * @param left
 * @param b
 * @param right
 * @returns {*}
 */
function commuteArrayPaths(a, left, b, right) {
	if(left.length === right.length) {
		return commuteArraySiblings(a, left, b, right);
	}

	if (left.length > right.length) {
		// left is longer, commute by "moving" it to the right
		left = commuteArrayAncestor(b, right, a, left, -1);
		a.path = jsonPointer.absolute(jsonPointer.join(left));
	} else {
		// right is longer, commute by "moving" it to the left
		right = commuteArrayAncestor(a, left, b, right, 1);
		b.path = jsonPointer.absolute(jsonPointer.join(right));
	}

	return [b, a];
}

function isArrayPath(left, right, index) {
	return jsonPointer.isValidArrayIndex(left[index])
		&& jsonPointer.isValidArrayIndex(right[index]);
}

/**
 * Commute two patches referring to items in the same array
 * @param l
 * @param lpath
 * @param r
 * @param rpath
 * @returns {*[]}
 */
function commuteArraySiblings(l, lpath, r, rpath) {

	var target = lpath.length-1;
	var lindex = +lpath[target];
	var rindex = +rpath[target];

	var commuted;

	if(lindex < rindex) {
		// Adjust right path
		if(l.op === 'add' || l.op === 'copy') {
			commuted = rpath.slice();
			commuted[target] = Math.max(0, rindex - 1);
			r.path = jsonPointer.absolute(jsonPointer.join(commuted));
		} else if(l.op === 'remove') {
			commuted = rpath.slice();
			commuted[target] = rindex + 1;
			r.path = jsonPointer.absolute(jsonPointer.join(commuted));
		}
	} else if(r.op === 'add' || r.op === 'copy') {
		// Adjust left path
		commuted = lpath.slice();
		commuted[target] = lindex + 1;
		l.path = jsonPointer.absolute(jsonPointer.join(commuted));
	} else if (lindex > rindex && r.op === 'remove') {
		// Adjust left path only if remove was at a (strictly) lower index
		commuted = lpath.slice();
		commuted[target] = Math.max(0, lindex - 1);
		l.path = jsonPointer.absolute(jsonPointer.join(commuted));
	}

	return [r, l];
}

/**
 * Commute two patches with a common array ancestor
 * @param l
 * @param lpath
 * @param r
 * @param rpath
 * @param direction
 * @returns {*}
 */
function commuteArrayAncestor(l, lpath, r, rpath, direction) {
	// rpath is longer or same length

	var target = lpath.length-1;
	var lindex = +lpath[target];
	var rindex = +rpath[target];

	// Copy rpath, then adjust its array index
	var rc = rpath.slice();

	if(lindex > rindex) {
		return rc;
	}

	if(l.op === 'add' || l.op === 'copy') {
		rc[target] = Math.max(0, rindex - direction);
	} else if(l.op === 'remove') {
		rc[target] = Math.max(0, rindex + direction);
	}

	return rc;
}

function getCommonPathPrefix(p1, p2) {
	var p1l = p1.length;
	var p2l = p2.length;
	if(p1l === 0 || p2l === 0 || (p1l < 2 && p2l < 2)) {
		return [];
	}

	// If paths are same length, the last segment cannot be part
	// of a common prefix.  If not the same length, the prefix cannot
	// be longer than the shorter path.
	var l = p1l === p2l
		? p1l - 1
		: Math.min(p1l, p2l);

	var i = 0;
	while(i < l && p1[i] === p2[i]) {
		++i
	}

	return p1.slice(0, i);
}

function copyPatch(p) {
	if(p.op === 'remove') {
		return { op: p.op, path: p.path };
	}

	if(p.op === 'copy' || p.op === 'move') {
		return { op: p.op, path: p.path, from: p.from };
	}

	// test, add, replace
	return { op: p.op, path: p.path, value: p.value };
}

/***/ }),
/* 23 */
/***/ ((module) => {

module.exports = TestFailedError;

function TestFailedError(message) {
	Error.call(this);
	this.name = this.constructor.name;
	this.message = message;
	if(typeof Error.captureStackTrace === 'function') {
		Error.captureStackTrace(this, this.constructor);
	}
}

TestFailedError.prototype = Object.create(Error.prototype);
TestFailedError.prototype.constructor = TestFailedError;

/***/ }),
/* 24 */
/***/ ((module) => {

module.exports = InvalidPatchOperationError;

function InvalidPatchOperationError(message) {
	Error.call(this);
	this.name = this.constructor.name;
	this.message = message;
	if(typeof Error.captureStackTrace === 'function') {
		Error.captureStackTrace(this, this.constructor);
	}
}

InvalidPatchOperationError.prototype = Object.create(Error.prototype);
InvalidPatchOperationError.prototype.constructor = InvalidPatchOperationError;

/***/ }),
/* 25 */
/***/ ((module) => {

module.exports = PatchNotInvertibleError;

function PatchNotInvertibleError(message) {
	Error.call(this);
	this.name = this.constructor.name;
	this.message = message;
	if(typeof Error.captureStackTrace === 'function') {
		Error.captureStackTrace(this, this.constructor);
	}
}

PatchNotInvertibleError.prototype = Object.create(Error.prototype);
PatchNotInvertibleError.prototype.constructor = PatchNotInvertibleError;

/***/ }),
/* 26 */
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var patches = __webpack_require__(17);

module.exports = function inverse(p) {
	var pr = [];
	var i, skip;
	for(i = p.length-1; i>= 0; i -= skip) {
		skip = invertOp(pr, p[i], i, p);
	}

	return pr;
};

function invertOp(patch, c, i, context) {
	var op = patches[c.op];
	return op !== void 0 && typeof op.inverse === 'function'
		? op.inverse(patch, c, i, context)
		: 1;
}


/***/ }),
/* 27 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "create": () => (/* binding */ create)
/* harmony export */ });
/** @module @hat-open/future
 */


function create() {
    const data = {
        done: false,
        error: false,
        result: undefined,
        resolve: null,
        reject: null
    };

    const future = new Promise((resolve, reject) => {
        data.resolve = resolve;
        data.reject = reject;
        if (data.error) {
            reject(data.result);
        } else if (data.done) {
            resolve(data.resolve);
        }
    });

    future.done = () => data.done;

    future.result = () => {
        if (!data.done)
            throw new Error('future is not done');
        if (data.error)
            throw data.error;
        return data.result;
    };

    future.setResult = result => {
        if (data.done)
            throw new Error('result already set');
        data.result = result;
        data.done = true;
        if (data.resolve)
            data.resolve(data.result);
    };

    future.setError = error => {
        if (data.done)
            throw new Error('result already set');
        data.error = true;
        data.result = error;
        data.done = true;
        if (data.reject)
            data.reject(error);
    };

    return future;
}


/***/ }),
/* 28 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "main": () => (/* binding */ main)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29);
/* harmony import */ var _state__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(31);
/* harmony import */ var _common_table__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(32);
/* harmony import */ var _common_menu__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(33);
/* harmony import */ var _common_details__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(35);
/* harmony import */ var _common_filter__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(34);











function main() {
    if (!_hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote')) {
        return ['div#main'];
    }
    return ['div#main',
        columnResizeOverlay(),
        menuResizeOverlay(),
        entryDetailsResizeOverlay(),
        _common_menu__WEBPACK_IMPORTED_MODULE_5__.isCollapsed() ? [] : menuVt(),
        tableVt(),
        header(),
        _common_details__WEBPACK_IMPORTED_MODULE_6__.getSelectedEntry() ? detailsVt() : [],
        _common_details__WEBPACK_IMPORTED_MODULE_6__.snackbarsExist() ? snackbarVt() : []
    ];
}


function header() {
    return ['div.header', {
        class: {
            frozen: _common_filter__WEBPACK_IMPORTED_MODULE_7__.frozen()
        }},
        _common_menu__WEBPACK_IMPORTED_MODULE_5__.isCollapsed() ? ['div.control-button', {
            class: {
                frozen: _common_filter__WEBPACK_IMPORTED_MODULE_7__.frozen()
            },
            on: {
                click: () => _common_menu__WEBPACK_IMPORTED_MODULE_5__.setCollapsed(false)
            }},
            ['span.fa.fa-cog']
        ] : [],
        ['div.datetime-pickers',
            ['div.title', 'Timestamp filters'],
            ['div.timestamps',
                ['label', 'From: '],
                _datetime__WEBPACK_IMPORTED_MODULE_2__.pickerVt(
                    ['local', 'misc', 'datetimePickers', 'from'],
                    ['local', 'filter', 'entry_timestamp_from'],
                    timestamp => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setTimestampFrom(timestamp),
                    ''
                ),
                ['label', 'To: '],
                _datetime__WEBPACK_IMPORTED_MODULE_2__.pickerVt(
                    ['local', 'misc', 'datetimePickers', 'to'],
                    ['local', 'filter', 'entry_timestamp_to'],
                    timestamp => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setTimestampTo(timestamp),
                    ''
                ),
            ]
        ],
        (_common_filter__WEBPACK_IMPORTED_MODULE_7__.getActive().length > 0 ? ['div.filters',
            ['div.title', 'Active filters:'],
            _common_filter__WEBPACK_IMPORTED_MODULE_7__.getActive().map(({key, label, value}) => ['div.chip.filter-item',
                ['label.value', {
                    props: {
                        title: `${label}: ${value}`,
                    }},
                    `${label}`],
                ['div.icon', {
                    on: {
                        click: () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setValue(key, null)
                    }},
                    closeSvg(8)
                ]
            ]),
            (_common_filter__WEBPACK_IMPORTED_MODULE_7__.getActive().length > 1 ? ['div.chip.clear-all', {
                on: {
                    click: () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.clearAllActive(),
                }},
                'Clear all'
            ] : [])
        ] : []),
        ['div.stretch'],
        (['div.navigation',
            ['div.labeled-controls',
                ['div.freeze-toggle',
                    ['input', {
                        props: {
                            type: 'checkbox',
                            checked: !_common_filter__WEBPACK_IMPORTED_MODULE_7__.frozen()
                        },
                        on: {
                            change: ev => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setFreeze(!ev.target.checked)
                        }
                    }],
                    ['label', {
                        on: {
                            click: () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setFreeze(!_common_filter__WEBPACK_IMPORTED_MODULE_7__.frozen())
                        }},
                        'Live update'],
                ],
                ['div.size-select',
                    ['label', 'Page size'],
                    ['select', {
                        on: {
                            change: ev => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setPageSize(ev.target.value)
                        }},
                        ['20', '50', '100', '200'].map(value => ['option', {
                            props: {
                                value: value,
                                label: value,
                                selected: value == `${_common_filter__WEBPACK_IMPORTED_MODULE_7__.getPageSize()}`
                            },
                        }])
                    ]
                ],
                ['div.page-counter', {
                    class: {
                        frozen: _common_filter__WEBPACK_IMPORTED_MODULE_7__.frozen()
                    }},
                    ['label', `Page ${_common_filter__WEBPACK_IMPORTED_MODULE_7__.getPageIndex() + 1}`]
                ],
            ],
            ((_common_filter__WEBPACK_IMPORTED_MODULE_7__.getGlobalLast() === null && _common_filter__WEBPACK_IMPORTED_MODULE_7__.getGlobalFirst() === null) ?  [] : ['div.buttons',
                ['div.navigation-button', {
                    class: {
                        disabled: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePreviousDisabled(),
                    },
                    on: {
                        click: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePreviousDisabled() ? ev => ev : () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigateFirst()
                    }},
                    ['span.fa.fa-angle-double-left']
                ],
                ['div.navigation-button', {
                    class: {
                        disabled: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePreviousDisabled()
                    },
                    on: {
                        click: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePreviousDisabled() ? ev => ev : () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePrevious()
                    }},
                    ['span.fa.fa-angle-left'],
                ],
                ['div.navigation-button', {
                    class: {
                        disabled: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigateNextDisabled()
                    },
                    on: {
                        click: _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigateNextDisabled() ? ev => ev : () => _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigateNext()
                    }},
                    ['span.fa.fa-angle-right'],
                ],
            ])
        ]),
    ];
}


function menuVt() {
    return [
        ['div.menu-header',
            ['div.title',
                'Settings'
            ],
            ['div.control-button', {
                on: {
                    click: () => _common_menu__WEBPACK_IMPORTED_MODULE_5__.setCollapsed(true)
                }},
                closeSvg(15)
            ],
        ],
        ['div.menu', {
            props: {
                style: `width: ${_common_menu__WEBPACK_IMPORTED_MODULE_5__.getWidth()}px;`
            }},
            ['div.group',
                ['div.title', 'Columns'],
                ['div.column-options',
                    _common_table__WEBPACK_IMPORTED_MODULE_4__.columnsSorted().map(({name, label, filterKey}) => ['div.item', {
                        props: {
                            draggable: true,
                            title: (_common_menu__WEBPACK_IMPORTED_MODULE_5__.invisibleColumnHasFilter(name, filterKey) ?
                                'Column not visible but is used as filter' : '')
                        },
                        class: {
                            dropzone: _common_table__WEBPACK_IMPORTED_MODULE_4__.getDraggedColumnName() && !_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_common_table__WEBPACK_IMPORTED_MODULE_4__.getDraggedColumnName(), name),
                            'not-visible-has-filter': _common_menu__WEBPACK_IMPORTED_MODULE_5__.invisibleColumnHasFilter(name, filterKey)
                        },
                        on: {
                            click: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.setColumnVisible(name, !_common_table__WEBPACK_IMPORTED_MODULE_4__.isColumnVisible(name)),
                            dragstart: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.columnDragstart(name),
                            dragend: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.stopColumnDrag(),
                            dragover: (ev) => ev.preventDefault(),
                            drop: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.columnDrop(name)
                        }},
                        ['input', {
                            props: {
                                type: 'checkbox',
                                checked: _common_table__WEBPACK_IMPORTED_MODULE_4__.isColumnVisible(name)
                            },
                        }],
                        ['label', label]
                    ])
                ],
                ['button.reset-button', {
                    on: {
                        click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                            _common_menu__WEBPACK_IMPORTED_MODULE_5__.changeDefaultLayout,
                            _common_table__WEBPACK_IMPORTED_MODULE_4__.changeDefaultLayout,
                            _common_details__WEBPACK_IMPORTED_MODULE_6__.changeDefaultLayout
                        ))
                    }},
                    ['span.fa.fa-undo'],
                    ['label', ' Reset layout']
                ],
            ],
        ]
    ];
}


function tableVt() {
    const columns = _common_table__WEBPACK_IMPORTED_MODULE_4__.columnsVisibleSorted();
    const entries = _common_table__WEBPACK_IMPORTED_MODULE_4__.getEntries();
    const tableWidth = (window.innerWidth
        - (_common_menu__WEBPACK_IMPORTED_MODULE_5__.isCollapsed() ? 0 : _common_menu__WEBPACK_IMPORTED_MODULE_5__.getWidth())
        - (_common_details__WEBPACK_IMPORTED_MODULE_6__.getSelectedEntry() && !_common_details__WEBPACK_IMPORTED_MODULE_6__.isCollapsed() ? _common_details__WEBPACK_IMPORTED_MODULE_6__.getWidth() : 0));
    return ['div.table', {
        props: {
            style: `width: ${tableWidth}px;`,
        }},
        // TABLE APPROACH
        ['table',
            ['thead', ['tr',
                columns.map((column, columnIndex) => [
                    ['th', {
                        props: {
                            style: (columnIndex != columns.length - 1 ?
                                `width: ${column.width}px` :
                                _common_table__WEBPACK_IMPORTED_MODULE_4__.lastColumnExpanded() ? null : `width: ${column.minWidth}px`)
                        }},
                        ['div.column-header', {
                            class: {
                                dropzone: (_common_table__WEBPACK_IMPORTED_MODULE_4__.getDraggedColumnName()
                                    && !_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_common_table__WEBPACK_IMPORTED_MODULE_4__.getDraggedColumnName(), column.name))
                            },
                            on: {
                                dragend: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.stopColumnDrag(),
                                dragover: (ev) => ev.preventDefault(),
                                drop: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.columnDrop(column.name)
                            }},
                            ['div.label-container', {
                                props: {
                                    draggable: true
                                },
                                on: {
                                    dragstart: ev => {
                                        ev.dataTransfer.setDragImage(ev.target.parentElement, 0, 0);
                                        _common_table__WEBPACK_IMPORTED_MODULE_4__.columnDragstart(column.name);
                                    },
                                }},
                                ['label', column.label]
                            ],
                            (column.filterKey ?
                                (column.filterOptions ? ['select', {
                                    on: {
                                        change: ev => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setValue(
                                            column.filterKey, JSON.parse(ev.target.value))
                                    }},
                                    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.concat([null], column.filterOptions).map(value => ['option', {
                                        props: {
                                            value: JSON.stringify(value),
                                            label: value || '',
                                            selected: value == `${_common_filter__WEBPACK_IMPORTED_MODULE_7__.getValue(column.filterKey)}`
                                        },
                                    }])
                                ] : ['input', {
                                    props: {
                                        value: _common_filter__WEBPACK_IMPORTED_MODULE_7__.getValue(column.filterKey) || '',
                                    },
                                    on: {
                                        change: ev => _common_filter__WEBPACK_IMPORTED_MODULE_7__.setValue(column.filterKey, ev.target.value),
                                        mousedown: ev => {
                                            ev.stopPropagation();
                                            ev.target.blur();
                                            ev.target.focus();
                                        }
                                    }
                                }]) : []
                            )
                        ]
                    ],
                    tableBorderVt('th', column.name)
                ])
            ]],
            ['tbody', {
                props: {
                    tabIndex: '0',
                },
                on: {
                    keydown: ev => {
                        const currentSelected = _common_details__WEBPACK_IMPORTED_MODULE_6__.getSelectedEntry();
                        const tableRows = ev.target.children;
                        const selectedRowIndex = _common_table__WEBPACK_IMPORTED_MODULE_4__.getEntries().findIndex(e => e == currentSelected);
                        if (currentSelected !== null) {
                            if (ev.key == 'ArrowDown') {
                                const rowElement = tableRows[selectedRowIndex + 1];
                                if (rowElement)
                                    rowElement.scrollIntoView({block: 'nearest'});
                                _common_details__WEBPACK_IMPORTED_MODULE_6__.selectPreviousEntry();
                                ev.preventDefault();
                            } else if (ev.key == 'ArrowUp') {
                                const rowElement = tableRows[selectedRowIndex - 3];
                                if (rowElement)
                                    rowElement.scrollIntoView({block: 'nearest'});

                                // hack for first two rows and sticky table header
                                if (selectedRowIndex < 3) 
                                    ev.target.parentElement.parentElement.scroll(0, 0);
                                _common_details__WEBPACK_IMPORTED_MODULE_6__.selectNextEntry();
                                ev.preventDefault();
                            } else if (ev.key == 'Enter') {
                                _common_details__WEBPACK_IMPORTED_MODULE_6__.setCollapsed(false);
                            } else if (ev.key == 'Escape') {
                                if (!_common_details__WEBPACK_IMPORTED_MODULE_6__.isCollapsed())
                                    _common_details__WEBPACK_IMPORTED_MODULE_6__.setCollapsed(true);
                            }
                        }
                        if (ev.key == 'ArrowLeft') {
                            _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigatePrevious();
                        } else if (ev.key == 'ArrowRight') {
                            _common_filter__WEBPACK_IMPORTED_MODULE_7__.navigateNext();
                        }
                    }
                }},
                entries.map((entry, index) => ['tr', {
                    props: {
                        style: `background-color: ${_common_table__WEBPACK_IMPORTED_MODULE_4__.getRowColors(entry, index).background};
                                filter: brightness(${_common_table__WEBPACK_IMPORTED_MODULE_4__.getRowColors(entry, index).brightness}%);`
                    },
                    on: {
                        click: () => _common_details__WEBPACK_IMPORTED_MODULE_6__.selectEntry(entry.id),
                        dblclick: () => _common_details__WEBPACK_IMPORTED_MODULE_6__.setCollapsed(false)
                    }},
                    columns.map(column => [cellVt(entry, column), tableBorderVt('td', column.name)])
                ])
            ]
        ],
    ];
}


function detailsVt() {
    const selectedEntry = _common_details__WEBPACK_IMPORTED_MODULE_6__.getSelectedEntry();
    let exception = null;
    let callLocation = null;
    let parsedData = null;
    if (selectedEntry) {
        try {
            parsedData = JSON.parse(selectedEntry.msg.data);
            const entryData = parsedData[Object.keys(parsedData)[0]];
            exception = entryData.exc_info;
            callLocation = {
                name: entryData.name,
                funcName: entryData.funcName,
                lineno: entryData.lineno
            };
        } catch(_) {
            // Don't set exception and call location
        }
    }
    return (_common_details__WEBPACK_IMPORTED_MODULE_6__.isCollapsed() ? [] : ['div.details', {
        props: {
            style: `width: ${_common_details__WEBPACK_IMPORTED_MODULE_6__.getWidth()}px;`
        }},
        ['div.border', {
            on: {
                mousedown: ev => _common_details__WEBPACK_IMPORTED_MODULE_6__.startResize(ev.x)
            }
        }],
        ['div.entry-data',
            ['div.header',
                ['div.title',
                    `Entry ${selectedEntry.id}`
                ],
                ['div.stretch'],
                ['div.control-button', {
                    on: {
                        click: _common_details__WEBPACK_IMPORTED_MODULE_6__.copy
                    },
                    props: {
                        title: 'Copy JSON entry',
                    }},
                    ['span.fa.fa-copy']
                ],
                ['div.control-button', {
                    props: {
                        title: 'Download JSON entry',
                    }},
                    ['a.fa.fa-download', {
                        props: {
                            href: `data:text/json;charset=utf-8,${_common_details__WEBPACK_IMPORTED_MODULE_6__.selectedEntryStringified()}`,
                            download: `syslogEntry${selectedEntry.id}.json`
                        }
                    }]
                ],
                ['div.control-button', {
                    props: {
                        title: 'Close',
                    },
                    on: {
                        click: () => _common_details__WEBPACK_IMPORTED_MODULE_6__.setCollapsed(true)
                    }},
                    closeSvg(15)
                ],
            ],
            ['div.content',
                ['div.label-row', 'Message:'],
                ['div.text', selectedEntry.msg.msg],
                (exception  ? [
                    ['div.label-row', 'Exception:'],
                    ['pre.text', exception],
                ] : []),
                ['div.key-value-pairs',
                    [
                        ['Timestamp:', _datetime__WEBPACK_IMPORTED_MODULE_2__.utcTimestampToLocalString(selectedEntry.timestamp)],
                        ['Severity:', selectedEntry.msg.severity],
                        ['Location:', (callLocation ?
                            `${callLocation.name}.${callLocation.funcName}:${callLocation.lineno}` : null)],
                        ['Message timestamp:', _datetime__WEBPACK_IMPORTED_MODULE_2__.utcTimestampToLocalString(selectedEntry.msg.timestamp)],
                        ['Hostname:', selectedEntry.msg.hostname],
                        ['App name:', selectedEntry.msg.app_name],
                        ['Proc ID:', selectedEntry.msg.procid],
                        ['Message ID:', selectedEntry.msg.msgid],
                        ['Facility:', selectedEntry.msg.facility],
                        ['Version:', selectedEntry.msg.version],
                    ].map(([label, value]) => (value !== null ? [
                        ['div.key', label],
                        ['div.value', {
                            props: {
                                title: value
                            }},
                            `${value}`
                        ]
                    ] : []))
                ],

                ['div.collapsible', {
                    on: {
                        click: () => _common_details__WEBPACK_IMPORTED_MODULE_6__.toggleRawDataCollapsed()
                    }},
                    ['span.icon',
                        (_common_details__WEBPACK_IMPORTED_MODULE_6__.isRawDataCollapsed() ? ['span.fa.fa-angle-right'] : ['span.fa.fa-angle-down'])
                    ],
                    ['span.title', 'Raw data']
                ],
                (_common_details__WEBPACK_IMPORTED_MODULE_6__.isRawDataCollapsed() ? [] : ['pre.text',
                    JSON.stringify(parsedData, null, 2).replace(/\\n/g, '\n')
                ])
            ]
        ]
    ]);
}


function snackbarVt() {
    return ['div.snackbars',
        _common_details__WEBPACK_IMPORTED_MODULE_6__.getSnackbars().map(text => ['div.snackbar', ['label', text]])
    ];
}


function tableBorderVt(tag, name) {
    return [`${tag}.border`, {
        class: {
            hover: [_common_table__WEBPACK_IMPORTED_MODULE_4__.getBorderHover(), _common_table__WEBPACK_IMPORTED_MODULE_4__.getColumnResize().columnName].includes(name)
        },
        on: {
            mousedown: (ev) => _common_table__WEBPACK_IMPORTED_MODULE_4__.startColumnResize(name, ev.x),
            mouseenter: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.borderHoverStart(name),
            mouseleave: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.borderHoverStop(),
        }},
        ['div.line']
    ];
}


function columnResizeOverlay() {
    return (!_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_common_table__WEBPACK_IMPORTED_MODULE_4__.getColumnResize(), _state__WEBPACK_IMPORTED_MODULE_3__.defaultColumnResize) ? ['div.mouseevent-overlay', {
        on: {
            mousemove: ev => _common_table__WEBPACK_IMPORTED_MODULE_4__.updateColumnWidth(ev.x),
            mouseup: () => _common_table__WEBPACK_IMPORTED_MODULE_4__.stopColumnResize()
        },
        props: {
            style: 'cursor: ew-resize'
        }}] : []);
}


function menuResizeOverlay() {
    return (!_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_common_menu__WEBPACK_IMPORTED_MODULE_5__.getResize(), _state__WEBPACK_IMPORTED_MODULE_3__.defaultMenuResize) ? ['div.mouseevent-overlay', {
        on: {
            mousemove: ev => _common_menu__WEBPACK_IMPORTED_MODULE_5__.updateWidth(ev.x),
            mouseup: () => _common_menu__WEBPACK_IMPORTED_MODULE_5__.stopResize()
        },
        props: {
            style: 'cursor: ew-resize'
        }}] : []);
}


function entryDetailsResizeOverlay() {
    return (!_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_common_details__WEBPACK_IMPORTED_MODULE_6__.getResize(), _state__WEBPACK_IMPORTED_MODULE_3__.defaultDetailsResize) ? ['div.mouseevent-overlay', {
        on: {
            mousemove: ev => _common_details__WEBPACK_IMPORTED_MODULE_6__.updateWidth(ev.x),
            mouseup: () => _common_details__WEBPACK_IMPORTED_MODULE_6__.stopResize()
        },
        props: {
            style: 'cursor: ew-resize'
        }}] : []);
}


function cellVt(entry, column) {
    const value = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.get(column.path, entry);
    
    let vt = [];

    if (column.name == 'timestamp') {
        vt = ['td.timestamp',
            _datetime__WEBPACK_IMPORTED_MODULE_2__.utcTimestampToLocalString(value),
            ['div.cell-icons',
                ['span.icon', {
                    props: {
                        title: 'Set as timestamp from'
                    },
                    on: {
                        click: ev => {
                            ev.stopPropagation();
                            _common_filter__WEBPACK_IMPORTED_MODULE_7__.setTimestampFrom(value);
                        }
                    }},
                    arrowSvg()
                ],
                ['span.icon', {
                    props: {
                        title: 'Set as timestamp to'
                    },
                    on: {
                        click: ev => {
                            ev.stopPropagation();
                            _common_filter__WEBPACK_IMPORTED_MODULE_7__.setTimestampTo(value);
                        }
                    }},
                    arrowSvg(180)
                ],
            ]
        ];
    } else if (column.name == 'msg_timestamp') {
        vt = ['td', _datetime__WEBPACK_IMPORTED_MODULE_2__.utcTimestampToLocalString(value)];
    } else if (column.name == 'data'){
        vt = ['td.json', `${value}`];
    } else if (['msg', 'app_name'].includes(column.name)) {
        vt = ['td.text-noncentered', `${value}`];
    } else {
        vt = ['td', `${value}`];
    }

    return vt;
}


function arrowSvg(angle) {
    return ['svg', {
        attrs: { width: 10, height: 12 }},
        ['g', {
            attrs: {
                transform: `rotate(${angle || 0} 5 6)`
            }},
            ['line', { attrs: { x1: 0, y1: 11, x2: 10, y2: 11, } }],
            ['line', { attrs: { x1: 5, y1: 0, x2: 5, y2: 10, } }],
            ['line', { attrs: { x1: 0, y1: 4, x2: 5, y2: 9, } }],
            ['line', { attrs: { x1: 10, y1: 4, x2: 5, y2: 9, } }],
        ]
    ];
}


function closeSvg(size) {
    return ['svg', { attrs: { width: size, height: size } },
        ['line', { attrs: { x1: 0, y1: 0, x2: size, y2: size, stroke: 'black' } }],
        ['line', { attrs: { x1: size, y1: 0, x2: 0, y2: size, stroke: 'black' } }]
    ];
}


/***/ }),
/* 29 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "pickerState": () => (/* binding */ pickerState),
/* harmony export */   "utcTimestampToLocalString": () => (/* binding */ utcTimestampToLocalString),
/* harmony export */   "pickerVt": () => (/* binding */ pickerVt)
/* harmony export */ });
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(11);
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1);
/* harmony import */ var _datetimepicker__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(30);






const pickerState = {
    visible: false,
    tab: 'DATE',
    datePicker: _datetimepicker__WEBPACK_IMPORTED_MODULE_2__.getDatePickerDefaultState(),
    timePicker: _datetimepicker__WEBPACK_IMPORTED_MODULE_2__.getTimePickerDefaultState(),
    timestamp: null,
};


function utcTimestampToLocalString(utcTimestamp) {
    if (utcTimestamp === null) {
        return '';
    }

    const date = new Date(utcTimestamp * 1000);

    function padZero(value, requiredLength) {
        const valueString = `${value}`;
        return '0'.repeat(requiredLength - valueString.length) + valueString;
    }

    const year = date.getFullYear();
    const month = padZero(date.getMonth() + 1, 2);
    const day = padZero(date.getDate(), 2);
    const hour = padZero(date.getHours(), 2);
    const minutes = padZero(date.getMinutes(), 2);
    const seconds = padZero(date.getSeconds(), 2);
    const milliseconds = padZero(date.getMilliseconds(), 3);

    return `${year}-${month}-${day} ${hour}:${minutes}:${seconds}.${milliseconds}`;
}


function localStringToUTCTimestamp(localString) {
    try {
        const [dateString, timeString] = localString.split(' ');
        const [yearString, monthString, dayString] = dateString.split('-');
        const [hourString, minutesString, secondsString, milliseconsString] = timeString.split(/[:.]/);

        const parse = _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.strictParseInt;

        const date = new Date(
            parse(yearString), parse(monthString) - 1, parse(dayString),
            parse(hourString), parse(minutesString), parse(secondsString), parse(milliseconsString));
        return date.getTime() / 1000;
    } catch (error) {
        return NaN;
    }
}


function pickerVt(statePath, timestampPath, changeCb, placeholder) {
    const pickerVisiblePath = [statePath, 'visible'];
    const pickerVisible = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(pickerVisiblePath);

    const value = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(timestampPath);

    return ['span.timestamp-filter',
        ['input', {
            props: {
                value: utcTimestampToLocalString(value),
                placeholder: placeholder || ''
            },
            on: {
                blur: evt => evt.target.value = utcTimestampToLocalString(value),
                keydown: evt => {
                    if (evt.key != 'Enter')
                        return;
                    const ts = evt.target.value == '' ? null : localStringToUTCTimestamp(evt.target.value);
                    if (isNaN(ts)) {
                        evt.target.value = utcTimestampToLocalString(value);
                        return;
                    }
                    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(timestampPath, ts);
                }
            }
        }],
        value ? ['span.icon.clear', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(timestampPath, null)
            }},
            ['span.fa.fa-times']
        ] : [],
        ['span.icon.calendar', {
            class: {
                active: _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(pickerVisiblePath)
            },
            props: {
                tabIndex: -1
            },
            on: {
                focusin: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(pickerVisiblePath, pickerVisible),
                click: () => {
                    const ts = value != null ? value * 1000: Date.now();
                    const date = new Date(ts);
                    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.change(statePath, _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.pipe(
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.set('visible', !pickerVisible),
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.set('tab', 'TIME'),
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.set('timestamp', ts),
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.set('datePicker', _datetimepicker__WEBPACK_IMPORTED_MODULE_2__.getDatePickerDefaultState(date.getFullYear(), date.getMonth()))
                    ));
                }
            }},
            ['span.fa.fa-calendar']
        ],
        timestampPicker(statePath, ts => {
            _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set([statePath, 'visible'], false);
            changeCb(ts);
        }, placeholder)
    ];
}


function timestampPicker(statePath, onChange, title) {
    const visiblePath = [statePath, 'visible'];
    const timestampPath = [statePath, 'timestamp'];
    const timestamp = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(timestampPath);
    const tabPath = [statePath, 'tab'];
    const tab = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(tabPath);

    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(visiblePath) ? ['div.timestamp-picker', {
        props: {
            tabIndex: -1
        },
        on: {
            focusin: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(visiblePath, true),
            focusout: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(visiblePath, false)
        },
        hook: {
            insert: vnode => vnode.elm.focus()
        }},
        ['div.header',
            ['span.title', title],
            ['span.spacer'],
            ['span.tab', {
                class: {
                    active: tab == 'TIME'
                },
                on: {
                    click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(tabPath, 'TIME')
                }},
                ['span.fa.fa-clock-o']
            ],
            ['span.tab', {
                class: {
                    active: tab == 'DATE'
                },
                on: {
                    click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.set(tabPath, 'DATE')
                }},
                ['span.fa.fa-calendar']
            ],
            ['button', {
                on: {
                    click: () => {
                        const ts = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(timestampPath) / 1000;
                        onChange(ts);
                    }
                }},
                ['span.fa.fa-check'],
                ' Apply'
            ]
        ],
        ['div.main',
            _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.get(statePath, 'tab') == 'DATE' ?
                _datetimepicker__WEBPACK_IMPORTED_MODULE_2__.datePickerVt([statePath, 'datePicker'], timestamp, (year, month, day) =>
                    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.change(timestampPath, ts => updateDate(ts, year, month, day))
                ) :
                _datetimepicker__WEBPACK_IMPORTED_MODULE_2__.timePickerVt([statePath, 'timePicker'], timestamp, (hour, minute, second) =>
                    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_1__.default.change(timestampPath, ts => updateTime(ts, hour, minute, second))
                )
        ]
    ] : [];    
}


function updateDate(ts, year, month, day) {
    const date = new Date(ts);
    date.setFullYear(year);
    date.setMonth(month);
    date.setDate(day);
    return date.getTime();
}


function updateTime(ts, hour, minute, second) {
    const time = new Date(ts);
    time.setHours(hour);
    time.setMinutes(minute);
    time.setSeconds(second);
    return time.getTime();
}


/***/ }),
/* 30 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getDatePickerDefaultState": () => (/* binding */ getDatePickerDefaultState),
/* harmony export */   "getTimePickerDefaultState": () => (/* binding */ getTimePickerDefaultState),
/* harmony export */   "datePickerVt": () => (/* binding */ datePickerVt),
/* harmony export */   "timePickerVt": () => (/* binding */ timePickerVt)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);




function getDatePickerDefaultState(year = 1970, month = 0) {
    return {
        pickerType: 'DAY',
        year: year,
        month: month,
        decadeStart: null
    };
}


function getTimePickerDefaultState() {
    return {
        mouseMove: null
    };
}


function datePickerVt(path, ts, onChange) {
    const pickerType = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'pickerType');
    return ['div.date-picker',
        {
            'YEAR': yearPicker,
            'MONTH': monthPicker,
            'DAY': dayPicker,
        }[pickerType](path, ts, onChange)
    ];
}


function timePickerVt(path, ts, onChange) {
    return ['div.time-picker',
        timePicker(path, ts, onChange)
    ];
}


const monthLabels = [
    'January',
    'February',
    'March',
    'April',
    'May',
    'June',
    'July',
    'August',
    'September',
    'October',
    'November',
    'December'
];


const weekdays = [
    'Mon',
    'Tue',
    'Wed',
    'Thu',
    'Fri',
    'Sat',
    'Sun'
];


function yearPicker(path) {
    const decadeStartPath = [path, 'decadeStart'];
    const yearPath = [path, 'year'];
    const decadeStart = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(decadeStartPath);
    const currentYear = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(yearPath);
    const years = [...Array(10).keys()].map(i => decadeStart + i);
    return ['div.year-picker',
        ['div.year-grid',
            ['div.nav.top', {
                on: {
                    click: () =>  _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(decadeStartPath, i => i - 10)
                }},
                ['span.fa.fa-chevron-up']
            ],
            years.map(i => ['div.year', {
                class: {
                    current: i == currentYear
                },
                on: {
                    click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(path, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('year', i),
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('pickerType', 'DAY')
                    ))
                }},
                String(i)
            ]),
            ['div.nav.bottom', {
                on: {
                    click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(decadeStartPath, i => i + 10)
                }},
                ['span.fa.fa-chevron-down']
            ]
        ]
    ];
}


function monthPicker(path) {
    const monthPath = [path, 'month'];
    const currentMonth = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(monthPath);
    const months = [...Array(12).keys()];
    return ['div.month-picker',
        ['div.month-grid',
            months.map(i => ['div', {
                class: {
                    current: i == currentMonth
                },
                on: {
                    click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(path, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('month', i),
                        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('pickerType', 'DAY')
                    ))
                }},
                monthLabels[i]
            ])
        ]
    ];
}


function dayPicker(path, ts, onChange) {
    const yearPath = [path, 'year'];
    const monthPath = [path, 'month'];
    const year = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(yearPath);
    const month = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(monthPath);
    const currentDay = ts != null ? new Date(ts) : null;
    const today = new Date(Date.now());
    const lastDay = new Date(year, month + 1, 0).getDate();
    const firstDayOfWeek = (new Date(year, month, 1).getDay() + 6) % 7; // First day of week in Europe is Monday
    const days = [...Array(lastDay).keys()].map(_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.inc);
    return ['div.day-picker',
        ['div.header',
            monthHeaderPicker(path),
            yearHeaderPicker(path)
        ],
        ['div.day-grid',
            [...Array(7).keys()].map(i => ['div.weekday', weekdays[i]]),
            [...Array(firstDayOfWeek).keys()].map(() => ['div']),
            days.map(i => ['div.day', {
                class: {
                    current: currentDay != null && currentDay.getFullYear() && month == currentDay.getMonth() && i == currentDay.getDate(),
                    today: year == today.getFullYear() && month == today.getMonth() && i == today.getDate()
                },
                on: {
                    click: () => onChange(year, month, i)
                }},
                String(i)])
        ]
    ];
}


function monthHeaderPicker(path) {
    const monthPath = [path, 'month'];
    const month = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(monthPath);
    const monthLabel = monthLabels[month];
    return ['div.month',
        ['span.fa.fa-chevron-left', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(path, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('month', i => (i + 11) % 12),
                    i => i.month == 11 ? _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('year', _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.dec, i) : i
                ))
            }}
        ],
        ['span.title', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'pickerType'], 'MONTH')
            }},
            monthLabel
        ],
        ['span.fa.fa-chevron-right', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(path, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('month', i => (i + 1) % 12),
                    i => i.month == 0 ? _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('year', _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.inc, i) : i
                ))
            }}
        ],
    ];
}


function yearHeaderPicker(path) {
    const yearPath = [path, 'year'];
    const year = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(yearPath);
    return ['div.year',
        ['span.fa.fa-chevron-left', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(yearPath, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.dec)
            }}
        ],
        ['span.title', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(path, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('pickerType', 'YEAR'),
                    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('decadeStart', year - year % 10)
                ))
            }},
            String(year)
        ],
        ['span.fa.fa-chevron-right', {
            on: {
                click: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(yearPath, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.inc)
            }}
        ]
    ];
}


function timePicker(path, ts, onChange) {
    const mouseMovePath = [path, 'mouseMove'];
    const date = ts != null ? new Date(ts) : null;
    const hour = ts ? date.getHours() : 0;
    const minute = ts ? date.getMinutes() : 0;
    const second = ts ? date.getSeconds() : 0;
    return ['div.time-picker',
        ['svg', {
            attrs: {
                height: 200,
                width: 200,
                viewBox: '-100 -100 200 200'
            }},
            ['circle', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 100,
                    fill: 'white'
                }},
            ],
            drawHourBoxes(74, 99, 87, ts, minute, second, onChange),
            ['circle.minute-ring', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 60,
                    'stroke-width': 1,
                    fill: 'none'
                }},
            ],
            drawMinute(57, 0, '60'),
            drawMinute(57, 90, '15'),
            drawMinute(57, 180, '30'),
            drawMinute(57, 270, '45'),
            drawTicks(68, 74, 60, 1, 'minute-tick'),
            drawTicks(64, 74, 12, 2, 'minute-tick'),
            drawMinutePointer(minute, 60, 74),
            drawTicks(44, 50, 60, 1, 'second-tick'),
            drawSecondPointer(second, 44, 60),
            ['circle.hour-ring', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 74,
                    'stroke-width': 1,
                    fill: 'none'
                }},
            ],
            ['circle', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 74,
                    fill: 'transparent'
                },
                on: {
                    mousedown: evt => {
                        const newMinute = getValueFromCoords(60, evt.offsetX - 100, evt.offsetY - 100);
                        _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set(mouseMovePath, 'minutes');
                        onChange(hour, newMinute, second);
                    }
                }}
            ],
            ['circle', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 60,
                    fill: 'transparent'
                },
                on: {
                    mousedown: evt => {
                        const newSecond = getValueFromCoords(60, evt.offsetX - 100, evt.offsetY - 100);
                        _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set(mouseMovePath, 'seconds');
                        onChange(hour, minute, newSecond);
                    }
                }}
            ],
            drawCentral(hour, minute, second),
            ['circle.outer-ring', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 99,
                    'stroke-width': 1,
                    fill: 'none'
                }}
            ],
            _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'mouseMove') ? ['circle', {
                attrs: {
                    cx: 0,
                    cy: 0,
                    r: 100,
                    fill: 'transparent'
                },
                on: {
                    mousemove: evt => {
                        const value = getValueFromCoords(60, evt.offsetX - 100, evt.offsetY - 100);
                        const mouseMove = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(mouseMovePath);
                        if (mouseMove == 'minutes') {
                            onChange(hour, value, second);
                        } else if (mouseMove == 'seconds'){
                            onChange(hour, minute, value);
                        }
                    },
                    mouseup: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set(mouseMovePath, null),
                    mouseleave: () => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set(mouseMovePath, null),
                }}
            ] : [],
            drawComplication(-84, -84, 15, '0:00', () => onChange(0, 0, 0)),
            drawComplication(84, -84, 15, 'now', () => {
                const now = new Date();
                onChange(now.getHours(), now.getMinutes(), now.getSeconds());
            }),
        ]
    ];
}


function drawCentral(hour, minute, second) {
    return [
        ['g.central',
            ['text', {
                attrs: {
                    x: 0,
                    y: 0,
                }},
                ':'
            ],
            ['text', {
                attrs: {
                    x: -16,
                    y: 0,
                }},
                formatDigits(hour)
            ],
            ['text', {
                attrs: {
                    x: 16,
                    y: 0,
                }},
                formatDigits(minute)
            ],
            ['text.seconds', {
                attrs: {
                    x: 0,
                    y: 25,
                }},
                formatDigits(second)
            ]
        ]
    ];
}


function drawTicks(r1, r2, n, w, className) {
    return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(v => {
        var t = theta(n, v);
        return [`line.tick.${className}`, {
            attrs: {
                x1: r1 * Math.cos(t),
                y1: r1 * Math.sin(t),
                x2: r2 * Math.cos(t),
                y2: r2 * Math.sin(t),
                'stroke-width': w,
            }}];
    }, [...Array(n).keys()]);
}


function drawHourBoxes(r1, r2, rText, ts, minute, second, onChange) {
    const hour = ts != null ? new Date(ts).getHours() : null;
    return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(v => {
        const t = theta(24, v);
        return ['g.hour-box', {
            class: {
                selected: v == hour
            },
            on: {
                click: () => onChange(v, minute, second)
            }},
            drawBox(r1, r2, 24, v, 7.5),
            ['text', {
                attrs: {
                    x: rText * Math.cos(t),
                    y: rText * Math.sin(t),
                    style: `font-size:12px;font-weight:normal;alignment-baseline:central;text-anchor:middle`
                }},
                String(v)
            ]
        ];
    }, [...Array(24).keys()]);
}


function drawBox(r1, r2, n, v, delta) {
    const t = theta(n, v);
    const t1 = t - radians(delta);
    const t2 = t + radians(delta);
    const aX = r1 * Math.cos(t1);
    const aY = r1 * Math.sin(t1);
    const bX = r2 * Math.cos(t1);
    const bY = r2 * Math.sin(t1);
    const cX = r2 * Math.cos(t2);
    const cY = r2 * Math.sin(t2);
    const dX = r1 * Math.cos(t2);
    const dY = r1 * Math.sin(t2);
    return ['path.box', {
        attrs: {
            d: [`M ${aX} ${aY}`,
                `L ${bX} ${bY}`,
                `A ${r2} ${r2} 0 0 1 ${cX} ${cY}`,
                `L ${dX} ${dY}`,
                `A ${r1} ${r1} 0 0 0 ${aX} ${aY}`].join(' '),
        }}
    ];
}


function drawMinutePointer(minute, r1, r2) {
    const t = theta(60, minute);
    const t1 = t - radians(4);
    const t2 = t + radians(4);
    const aX = r1 * Math.cos(t);
    const aY = r1 * Math.sin(t);
    const bX = r2 * Math.cos(t1);
    const bY = r2 * Math.sin(t1);
    const cX = r2 * Math.cos(t2);
    const cY = r2 * Math.sin(t2);
    return ['path.minutes-pointer', {
        attrs: {
            d: [`M ${aX} ${aY}`,
                `L ${bX}, ${bY}`,
                `A ${r2} ${r2} 0 0 1 ${cX} ${cY}`,
                `L ${aX} ${aY}`].join(' '),
        }}
    ];
}


function drawSecondPointer(second, r1, r2) {
    const t = theta(60, second);
    return ['line.seconds-pointer', {
        attrs: {
            x1: r1 * Math.cos(t),
            y1: r1 * Math.sin(t),
            x2: r2 * Math.cos(t),
            y2: r2 * Math.sin(t)
        }}
    ];
}


function drawMinute(r, deg, text) {
    const t = radians(deg - 90);
    const x = r * Math.cos(t);
    const y = r * Math.sin(t);
    return [
        ['circle', {
            attrs: {
                cx: x,
                cy: y,
                r: 8,
                fill: 'white'
            }},
        ],
        ['text.minute-text', {
            attrs: {
                x: x,
                y: y,
                style: `font-size:10px;font-weight:normal;alignment-baseline:central;text-anchor:middle`
            }},
            text
        ]
    ];
}


function drawComplication(x, y, r, text, onClick) {
    return ['g.complication', {
        on: {
            click: onClick
        },
        attrs: {
            transform: `translate(${x} ${y})`
        }},
        ['circle', {
            attrs: {
                cx: 0,
                cy: 0,
                r: r,
                'stroke-width': 1,
                fill: 'white'
            }}
        ],
        ['text', {
            attrs: {
                style: `font-size:12px;font-weight:normal;alignment-baseline:central;text-anchor:middle`

            }},
            text
        ]
    ];
}


function radians(deg) {
    return deg * Math.PI / 180;
}


function degrees(rad) {
    return rad * 180 / Math.PI;
}


const theta = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.curry((n, v) => {
    return radians(270) + radians(360 / n) * v;
});


function formatDigits(v) {
    return v < 10 ? `0${v}` : `${v}`;
}


function getValueFromCoords(n, x, y) {
    const theta = atan2(x, y);
    const deg = degrees(theta) + 90;
    return Math.round(deg / 6) % 60;
}


function atan2(x, y) {
    if (x > 0)
        return Math.atan(y / x);
    else if (x < 0)
        return Math.atan(y / x) + Math.PI;
    else if (x == 0 && y > 0)
        return Math.PI / 2;
    else if (x == 0 && y < 0)
        return Math.PI / -2;
    else
        return 0;
}


/***/ }),
/* 31 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "defaultFilter": () => (/* binding */ defaultFilter),
/* harmony export */   "defaultMenuResize": () => (/* binding */ defaultMenuResize),
/* harmony export */   "defaultMenu": () => (/* binding */ defaultMenu),
/* harmony export */   "defaultColumnResize": () => (/* binding */ defaultColumnResize),
/* harmony export */   "defaultColumnDrag": () => (/* binding */ defaultColumnDrag),
/* harmony export */   "defaultTable": () => (/* binding */ defaultTable),
/* harmony export */   "defaultDetailsResize": () => (/* binding */ defaultDetailsResize),
/* harmony export */   "defaultDetails": () => (/* binding */ defaultDetails),
/* harmony export */   "main": () => (/* binding */ main)
/* harmony export */ });
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(11);
/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29);





const defaultFilter = {
    max_results: 50,
    last_id: null,
    entry_timestamp_from: null,
    entry_timestamp_to: null,
    facility: null,
    severity: null,
    hostname: null,
    app_name: null,
    procid: null,
    msgid: null,
    msg: null,
};


const facilityOptions = [
    'KERNEL',
    'USER',
    'MAIL',
    'SYSTEM',
    'AUTHORIZATION1',
    'INTERNAL',
    'PRINTER',
    'NETWORK',
    'UUCP',
    'CLOCK1',
    'AUTHORIZATION2',
    'FTP',
    'NTP',
    'AUDIT',
    'ALERT',
    'CLOCK2',
    'LOCAL0',
    'LOCAL1',
    'LOCAL2',
    'LOCAL3',
    'LOCAL4',
    'LOCAL5',
    'LOCAL6',
    'LOCAL7',
];


const severityOptions = [
    'EMERGENCY',
    'ALERT',
    'CRITICAL',
    'ERROR',
    'WARNING',
    'NOTICE',
    'INFORMATIONAL',
    'DEBUG',
];


const defaultMenuResize = {
    xInitial: null,
    widthInitial: null
};


const defaultMenu = {
    resize: defaultMenuResize,
    collapsed: true,
    width: 200
};


const defaultColumnResize = {
    columnName: null,
    xInitial: null,
    widthInitial: null
};


const defaultColumnDrag = {
    columnName: null
};


const column = {
    label: null,
    path: null,
    visible: false,
    width: 150,
    minWidth: 90,
    position: null,
    filterKey: null,
    filterOptions: null,
};


const defaultTable = {
    columnResize: defaultColumnResize,
    columnDrag: defaultColumnDrag,
    borderHover: null,
    columns: {
        id: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'ID',
            path: 'id',
            visible: true,
            position: 0,
            minWidth: 10,
            width: 40,
        }),
        timestamp: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Timestamp',
            path: 'timestamp',
            visible: true,
            position: 1,
            minWidth: 65,
            width: 200
        }),
        facility: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Facility',
            path: ['msg', 'facility'],
            filterKey: 'facility',
            filterOptions: facilityOptions,
            position: 2
        }),
        severity: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Severity',
            path: ['msg', 'severity'],
            filterKey: 'severity',
            filterOptions: severityOptions,
            visible: true,
            position: 3,
            minWidth: 45
        }),
        version: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Version',
            path: ['msg', 'version'],
            position: 4,
            minWidth: 40,
            width: 50
        }),
        msg_timestamp: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Message timestamp',
            path: ['msg', 'timestamp'],
            position: 5,
            minWidth: 65
        }),
        hostname: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Hostname',
            path: ['msg', 'hostname'],
            filterKey: 'hostname',
            position: 6,
            minWidth: 60,
            width: 70
        }),
        app_name: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'App name',
            path: ['msg', 'app_name'],
            filterKey: 'app_name',
            position: 7,
            minWidth: 30
        }),
        procid: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Proc ID',
            path: ['msg', 'procid'],
            filterKey: 'procid',
            position: 8,
            minWidth: 30
        }),
        msgid: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Message ID',
            path: ['msg', 'msgid'],
            filterKey: 'msgid',
            visible: true,
            position: 9,
            minWidth: 50,
        }),
        data: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Data',
            path: ['msg', 'data'],
            position: 10,
            width: 390
        }),
        msg: _hat_open_util__WEBPACK_IMPORTED_MODULE_0__.merge(column, {
            label: 'Message',
            path: ['msg', 'msg'],
            filterKey: 'msg',
            visible: true,
            position: 11,
            width: 120
        }),
    }
};


const defaultDetailsResize = {
    xInitial: null,
    widthInitial: null
};


const defaultDetails = {
    selected: null,
    resize: defaultDetailsResize,
    width: 400,
    collapsed: true,
    rawDataCollapsed: true,
    snackbarQueue: []
};


const main = {
    local: {
        menu: defaultMenu,
        table: defaultTable,
        details: defaultDetails,
        datetimePickers: {
            from: _datetime__WEBPACK_IMPORTED_MODULE_1__.pickerState,
            to: _datetime__WEBPACK_IMPORTED_MODULE_1__.pickerState
        },
        pageLastIds: null,
        filter: defaultFilter,
    },
    remote: null
};


/***/ }),
/* 32 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "changeDefaultLayout": () => (/* binding */ changeDefaultLayout),
/* harmony export */   "getEntries": () => (/* binding */ getEntries),
/* harmony export */   "columnsSorted": () => (/* binding */ columnsSorted),
/* harmony export */   "columnsVisibleSorted": () => (/* binding */ columnsVisibleSorted),
/* harmony export */   "isColumnVisible": () => (/* binding */ isColumnVisible),
/* harmony export */   "setColumnVisible": () => (/* binding */ setColumnVisible),
/* harmony export */   "startColumnResize": () => (/* binding */ startColumnResize),
/* harmony export */   "stopColumnResize": () => (/* binding */ stopColumnResize),
/* harmony export */   "getColumnResize": () => (/* binding */ getColumnResize),
/* harmony export */   "lastColumnExpanded": () => (/* binding */ lastColumnExpanded),
/* harmony export */   "updateColumnWidth": () => (/* binding */ updateColumnWidth),
/* harmony export */   "columnDragstart": () => (/* binding */ columnDragstart),
/* harmony export */   "getDraggedColumnName": () => (/* binding */ getDraggedColumnName),
/* harmony export */   "columnDrop": () => (/* binding */ columnDrop),
/* harmony export */   "stopColumnDrag": () => (/* binding */ stopColumnDrag),
/* harmony export */   "getRowColors": () => (/* binding */ getRowColors),
/* harmony export */   "getBorderHover": () => (/* binding */ getBorderHover),
/* harmony export */   "borderHoverStart": () => (/* binding */ borderHoverStart),
/* harmony export */   "borderHoverStop": () => (/* binding */ borderHoverStop)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _state__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(31);
/* harmony import */ var _menu__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(33);
/* harmony import */ var _details__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(35);








const path = ['local', 'table'];
const changeDefaultLayout = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(path, _state__WEBPACK_IMPORTED_MODULE_2__.defaultTable);


function getEntries() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries');
}


function columnsSorted() {
    return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.toPairs,
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.sortBy(([_, column]) => column.position),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(([name, column]) => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('name', name, column)),
    )(_hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columns'));
}


function columnsVisibleSorted() {
    return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.filter(column => column.visible, columnsSorted());
}


function isColumnVisible(name) {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columns', name, 'visible');
}


function setColumnVisible(name, value) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'columns', name, 'visible'], value);
}


function startColumnResize(columnName, x) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'columnResize'], _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('columnName', columnName),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('xInitial', x),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('widthInitial', _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get([path, 'columns'], columnName, 'width'))
    )(_state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnResize));
}


function stopColumnResize() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'columnResize'], _state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnResize);
}


function getColumnResize() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columnResize');
}


function fixedColumnsWidth() {
    return columnsVisibleSorted().slice(0, -1).reduce((sum, column) => sum + column.width + 4, 0);
}


function lastColumnExpanded() {
    const windowWidth = window.innerWidth;
    const menuWidth = _menu__WEBPACK_IMPORTED_MODULE_3__.isCollapsed() ? 0 : _menu__WEBPACK_IMPORTED_MODULE_3__.getWidth();
    const detailsWidth = _details__WEBPACK_IMPORTED_MODULE_4__.getSelectedEntry() && !_details__WEBPACK_IMPORTED_MODULE_4__.isCollapsed() ? _details__WEBPACK_IMPORTED_MODULE_4__.getWidth() : 0;
    const tableWidth = fixedColumnsWidth();
    const relevantColumns = columnsVisibleSorted();
    const columnMinWidth = relevantColumns.slice(-1)[0].minWidth;
    return (tableWidth + columnMinWidth) < (windowWidth - menuWidth - detailsWidth);
}


function updateColumnWidth(x) {
    const columnResize = getColumnResize();
    if (_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(columnResize, _state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnResize)) {
        return;
    }
    const dx = columnResize.xInitial - x;
    const columnPath = [[path, 'columns'], columnResize.columnName];
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([columnPath, 'width'], Math.max(columnResize.widthInitial - dx, _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(columnPath, 'minWidth')));
}


function columnDragstart(columnName) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'columnDrag'], _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('columnName', columnName)
    )(_state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnDrag));
}


function getDraggedColumnName() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columnDrag', 'columnName');
}


function columnDrop(dropColumnName) {
    if (_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(_hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columnDrag'), _state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnDrag)) {
        return;
    }
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change([path, 'columns'], columns => {
            let movedColumn = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.toPairs,
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.find(([name, _]) => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(name, _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'columnDrag', 'columnName')))
            )(columns);
            if (_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(dropColumnName, movedColumn[0])) {
                return columns;
            }
            columns = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.omit(movedColumn[0], columns);

            if (movedColumn[0] == columnsVisibleSorted().slice(-1)[0].name) {
                movedColumn = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(
                    [1, 'width'],
                    lastColumnExpanded() ?
                        (window.innerWidth
                            - (_menu__WEBPACK_IMPORTED_MODULE_3__.isCollapsed() ? 0 : _menu__WEBPACK_IMPORTED_MODULE_3__.getWidth())
                            - (_details__WEBPACK_IMPORTED_MODULE_4__.getSelectedEntry() && !_details__WEBPACK_IMPORTED_MODULE_4__.isCollapsed() ? _details__WEBPACK_IMPORTED_MODULE_4__.getWidth() : 0)
                            - fixedColumnsWidth()) :
                        movedColumn[1].minWidth,
                    movedColumn);
            } else if (dropColumnName == columnsVisibleSorted().slice(-1)[0].name) {
                columns = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change(dropColumnName, dropColumn => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(
                    'width',
                    lastColumnExpanded() ?
                        (window.innerWidth
                            - (_menu__WEBPACK_IMPORTED_MODULE_3__.isCollapsed() ? 0 : _menu__WEBPACK_IMPORTED_MODULE_3__.getWidth())
                            - (_details__WEBPACK_IMPORTED_MODULE_4__.getSelectedEntry() && !_details__WEBPACK_IMPORTED_MODULE_4__.isCollapsed() ? _details__WEBPACK_IMPORTED_MODULE_4__.getWidth() : 0)
                            - fixedColumnsWidth()) :
                        dropColumn.minWidth,
                    dropColumn
                ), columns);
            }

            let newIndex = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.toPairs(columns).findIndex(([name, _]) => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(name, dropColumnName));
            newIndex = newIndex + (newIndex >= movedColumn[1].position ? 1 : 0);
            return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.toPairs,
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.sortBy(([_, column]) => column.position),
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.insert(newIndex, movedColumn),
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(([name, column], index) => [name, _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('position', index, column)]),
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.fromPairs
            )(columns);
        }),
    ));
}


function stopColumnDrag() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'columnDrag'], _state__WEBPACK_IMPORTED_MODULE_2__.defaultColumnDrag);
}


function getRowColors(entry) {
    const maxBrightness = 100;
    const brightness = entry == _details__WEBPACK_IMPORTED_MODULE_4__.getSelectedEntry() ? 85 : maxBrightness;
    switch (entry.msg.severity) {
        case 'ERROR':
            return {
                background: '#FFCCCC',
                brightness: brightness
            };
        case 'WARNING':
            return {
                background: '#FFE6CC',
                brightness: brightness
            };
        default:
            return {
                background: 'white',
                brightness: brightness
            };
    }
}


function getBorderHover() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'borderHover');
}


function borderHoverStart(columnName) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'borderHover'], columnName);
}


function borderHoverStop() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'borderHover'], null);
}


/***/ }),
/* 33 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "changeDefaultLayout": () => (/* binding */ changeDefaultLayout),
/* harmony export */   "isCollapsed": () => (/* binding */ isCollapsed),
/* harmony export */   "setCollapsed": () => (/* binding */ setCollapsed),
/* harmony export */   "getWidth": () => (/* binding */ getWidth),
/* harmony export */   "startResize": () => (/* binding */ startResize),
/* harmony export */   "stopResize": () => (/* binding */ stopResize),
/* harmony export */   "getResize": () => (/* binding */ getResize),
/* harmony export */   "updateWidth": () => (/* binding */ updateWidth),
/* harmony export */   "invisibleColumnHasFilter": () => (/* binding */ invisibleColumnHasFilter)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _state__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(31);
/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(32);
/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(34);








const path = ['local', 'menu'];
const changeDefaultLayout = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.identity;


function isCollapsed() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'collapsed');
}


function setCollapsed(value) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'collapsed'], value);
}


function getWidth() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'width');
}


function startResize(x) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'resize'], _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('xInitial', x),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('widthInitial', _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'width')),
    )(_state__WEBPACK_IMPORTED_MODULE_2__.defaultMenuResize));
}


function stopResize() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'resize'], _state__WEBPACK_IMPORTED_MODULE_2__.defaultMenuResize);
}


function getResize() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'resize');
}


function updateWidth(x) {
    const menuResize = getResize();
    if (_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(menuResize, _state__WEBPACK_IMPORTED_MODULE_2__.defaultMenuResize)) {
        return;
    }
    const dx = menuResize.xInitial - x;
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'width'], Math.max(menuResize.widthInitial + dx, 120));
}


function invisibleColumnHasFilter(columnName, filterKey) {
    let filterValue = null;
    if (columnName == 'timestamp') {
        filterValue = _filter__WEBPACK_IMPORTED_MODULE_4__.getValue('entry_timestamp_from') || _filter__WEBPACK_IMPORTED_MODULE_4__.getValue('entry_timestamp_to');
    } else {
        filterValue = _filter__WEBPACK_IMPORTED_MODULE_4__.getValue(filterKey);
    }
    return !_table__WEBPACK_IMPORTED_MODULE_3__.isColumnVisible(columnName) && filterValue !== null && filterValue !== undefined;
}


/***/ }),
/* 34 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "frozen": () => (/* binding */ frozen),
/* harmony export */   "setFreeze": () => (/* binding */ setFreeze),
/* harmony export */   "setPageSize": () => (/* binding */ setPageSize),
/* harmony export */   "getPageSize": () => (/* binding */ getPageSize),
/* harmony export */   "getPageIndex": () => (/* binding */ getPageIndex),
/* harmony export */   "getGlobalLast": () => (/* binding */ getGlobalLast),
/* harmony export */   "getGlobalFirst": () => (/* binding */ getGlobalFirst),
/* harmony export */   "getLast": () => (/* binding */ getLast),
/* harmony export */   "getNextLastId": () => (/* binding */ getNextLastId),
/* harmony export */   "navigatePreviousDisabled": () => (/* binding */ navigatePreviousDisabled),
/* harmony export */   "navigateNextDisabled": () => (/* binding */ navigateNextDisabled),
/* harmony export */   "navigateNext": () => (/* binding */ navigateNext),
/* harmony export */   "navigatePrevious": () => (/* binding */ navigatePrevious),
/* harmony export */   "navigateFirst": () => (/* binding */ navigateFirst),
/* harmony export */   "getValue": () => (/* binding */ getValue),
/* harmony export */   "setTimestampFrom": () => (/* binding */ setTimestampFrom),
/* harmony export */   "setTimestampTo": () => (/* binding */ setTimestampTo),
/* harmony export */   "setValue": () => (/* binding */ setValue),
/* harmony export */   "getActive": () => (/* binding */ getActive),
/* harmony export */   "clearAllActive": () => (/* binding */ clearAllActive)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _table__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(32);
/* harmony import */ var _datetime__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29);







function frozen() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'filter', 'last_id') !== null;
}


const changeLastId = lastId => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('local', _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(['filter', 'last_id'], lastId),
    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('pageLastIds', lastIds => {
        if (lastId === null)
            return null;
        if (lastIds === null) {
            const globalLast = getGlobalLast();
            if (lastId == globalLast)
                return [globalLast];
            return [globalLast, lastId];
        }
        if (!lastIds.includes(lastId))
            return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.append(lastId, lastIds);
        return lastIds;
    })
));


function setFreeze(isFrozen) {
    const newLastId = isFrozen ? _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(['remote', 'last_id']) : null;
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeLastId(newLastId));
}


function setPageSize(size) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeSetFilterValue('max_results', _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.strictParseInt(size)));
}


function getPageSize() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(['remote', 'filter', 'max_results']);
}


function getPageIndex() {
    const pages = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('local', 'pageLastIds');
    if (pages === null)
        return 0;
    return pages.findIndex(lastId => lastId == getLast());
}


function getGlobalLast() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'last_id');
}


function getGlobalFirst() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'first_id');
}


function getLast() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'filter', 'last_id') || _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'last_id');
}


function getNextLastId() {
    const entries = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries');
    if (entries.length < _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'filter', 'max_results')) {
        return null;
    }
    return entries.slice(-1)[0].id - 1;
}


function navigatePreviousDisabled() {
    return getLast() == getGlobalLast(); 
}


function navigateNextDisabled() {
    const nextLastId = getNextLastId();
    if (nextLastId === null) {
        return true;
    }
    return nextLastId < _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'first_id'); 
}


function navigateNext() {
    if (navigateNextDisabled())
        return;
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeLastId(_hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries').slice(-1)[0].id - 1));
}


function navigatePrevious() {
    if (navigatePreviousDisabled())
        return;
    const pages = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('local', 'pageLastIds');
    const currentPageIndex = pages.findIndex(page => page == getLast());
    if (currentPageIndex > 0)
        _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeLastId(pages[currentPageIndex - 1]));
}


function navigateFirst() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeLastId(_hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'last_id')));
}


function getValue(key) {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'filter', key);
}


const changeSetFilterValue = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.curry(
    (key, value, state) => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(['local', 'filter', key], value),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change([], state => {
            const lastId = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.get(['remote', 'filter', 'last_id'], state);
            if (lastId === null)
                return state;
            return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
                changeLastId(null),
                changeLastId(getGlobalLast())
            )(state);
        })
    )(state)
);


function setTimestampFrom(timestamp) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeSetFilterValue('entry_timestamp_from', timestamp));
}


function setTimestampTo(timestamp) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeSetFilterValue('entry_timestamp_to', timestamp));
}


function setValue(key, value) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(changeSetFilterValue(key, value));
}


function getActive() {
    return _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(column => ({ key: column.filterKey, label: column.label })),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.filter(filterItem => filterItem.key),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(filterItem => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('value', getValue(filterItem.key), filterItem)),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.concat([{
            key: 'entry_timestamp_from',
            label: 'Timestamp from',
            value: _datetime__WEBPACK_IMPORTED_MODULE_3__.utcTimestampToLocalString(getValue('entry_timestamp_from'))
        }, {
            key: 'entry_timestamp_to',
            label: 'Timestamp to',
            value: _datetime__WEBPACK_IMPORTED_MODULE_3__.utcTimestampToLocalString(getValue('entry_timestamp_to'))
        }]),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.filter(filterItem => filterItem.value)
    )(_table__WEBPACK_IMPORTED_MODULE_2__.columnsSorted());
}


function clearAllActive() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        ...getActive().map(({key}) => changeSetFilterValue(key, null)),
    ));
}


/***/ }),
/* 35 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "changeDefaultLayout": () => (/* binding */ changeDefaultLayout),
/* harmony export */   "selectEntry": () => (/* binding */ selectEntry),
/* harmony export */   "getSelectedEntry": () => (/* binding */ getSelectedEntry),
/* harmony export */   "startResize": () => (/* binding */ startResize),
/* harmony export */   "stopResize": () => (/* binding */ stopResize),
/* harmony export */   "getResize": () => (/* binding */ getResize),
/* harmony export */   "getWidth": () => (/* binding */ getWidth),
/* harmony export */   "updateWidth": () => (/* binding */ updateWidth),
/* harmony export */   "isCollapsed": () => (/* binding */ isCollapsed),
/* harmony export */   "setCollapsed": () => (/* binding */ setCollapsed),
/* harmony export */   "selectPreviousEntry": () => (/* binding */ selectPreviousEntry),
/* harmony export */   "selectNextEntry": () => (/* binding */ selectNextEntry),
/* harmony export */   "isRawDataCollapsed": () => (/* binding */ isRawDataCollapsed),
/* harmony export */   "toggleRawDataCollapsed": () => (/* binding */ toggleRawDataCollapsed),
/* harmony export */   "selectedEntryStringified": () => (/* binding */ selectedEntryStringified),
/* harmony export */   "copy": () => (/* binding */ copy),
/* harmony export */   "getSnackbars": () => (/* binding */ getSnackbars),
/* harmony export */   "snackbarsExist": () => (/* binding */ snackbarsExist)
/* harmony export */ });
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _state__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(31);






const path = ['local', 'details'];
const changeDefaultLayout = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change(path, detailsState => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('collapsed', detailsState.collapsed),
    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('selected', detailsState.selected),
)(_state__WEBPACK_IMPORTED_MODULE_2__.defaultDetails));

const snackbarQueuePath = [path, 'snackbarQueue'];


function selectEntry(entryId) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'selected'], entryId);
}


function getSelectedEntry() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries').find(
        entry => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(entry.id, _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'selected'))
    );
}


function startResize(x) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'resize'], _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('xInitial', x),
        _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set('widthInitial', getWidth())
    )(_state__WEBPACK_IMPORTED_MODULE_2__.defaultEntryDetailsResize));
}


function stopResize() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'resize'], _state__WEBPACK_IMPORTED_MODULE_2__.defaultDetailsResize);
}


function getResize() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'resize');
}


function getWidth() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'width');
}


function updateWidth(x) {
    const entryDetailsResize = getResize();
    if (_hat_open_util__WEBPACK_IMPORTED_MODULE_1__.equals(entryDetailsResize, _state__WEBPACK_IMPORTED_MODULE_2__.defaultDetailsResize)) {
        return;
    }
    const dx = entryDetailsResize.xInitial - x;
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'width'], Math.max(280, entryDetailsResize.widthInitial + dx));
}


function isCollapsed() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'collapsed');
}


function setCollapsed(v) {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.set([path, 'collapsed'], v);
}


function selectPreviousEntry() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change([path, 'selected'], oldId => {
        const newId = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(
            ['remote', 'entries', _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries').findIndex(entry => entry.id == oldId) + 1, 'id'],
        );
        return newId !== undefined ? newId : oldId;
    });
}


function selectNextEntry() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change([path, 'selected'], oldId => {
        const newId = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(
            ['remote', 'entries', _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get('remote', 'entries').findIndex(entry => entry.id == oldId) - 1, 'id'],
        );
        return newId !== undefined ? newId : oldId;
    });
}


function isRawDataCollapsed() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(path, 'rawDataCollapsed');
}


function toggleRawDataCollapsed() {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change([path, 'rawDataCollapsed'], v => !v);
}


function selectedEntryStringified() {
    let entry = getSelectedEntry();
    _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.set(['msg', 'data_raw'], entry.msg.data, entry);
    try {
        entry = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.pipe(
            _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change(['msg', 'data'], JSON.parse),
            _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change(['msg', 'data'], _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.map(
                _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change('exc_info', excInfo => excInfo != '' ? excInfo.split('\n') : excInfo)
            ))
        )(entry);
    } catch(_) {
        entry = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.change(['msg', 'data'], data => data.split('\\n'), entry);
    }
    return JSON.stringify(entry, null, 2);
}


function copy() {
    const navigator = window.navigator;
    const selectedEntry = getSelectedEntry();
    navigator.permissions.query({name: "clipboard-write"}).then(result => {
        if (result.state == "granted" || result.state == "prompt") {
            navigator.clipboard.writeText(selectedEntryStringified()).then(
                () => snackbarCb(`Copied entry ${selectedEntry.id}`),
                () => snackbarCb(`Couldn't copy entry ${selectedEntry.id}`)
            );
        }
    });
}


function getSnackbars() {
    return _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.get(snackbarQueuePath);
}


function snackbarsExist() {
    return getSnackbars().length != 0;
}


function snackbarCb(text) {
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(
        snackbarQueuePath,
        queue => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.concat([text], queue)
    ).then(() => setTimeout(() => _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.change(
        snackbarQueuePath,
        queue => _hat_open_util__WEBPACK_IMPORTED_MODULE_1__.omit(queue.length - 1, queue)
    ), 1000));
}


/***/ }),
/* 36 */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(37);
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_cjs_js_ruleSet_1_rules_0_use_1_node_modules_sass_loader_dist_cjs_js_ruleSet_1_rules_0_use_2_main_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38);

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_css_loader_dist_cjs_js_ruleSet_1_rules_0_use_1_node_modules_sass_loader_dist_cjs_js_ruleSet_1_rules_0_use_2_main_scss__WEBPACK_IMPORTED_MODULE_1__.default, options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_css_loader_dist_cjs_js_ruleSet_1_rules_0_use_1_node_modules_sass_loader_dist_cjs_js_ruleSet_1_rules_0_use_2_main_scss__WEBPACK_IMPORTED_MODULE_1__.default.locals || {});

/***/ }),
/* 37 */
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


var isOldIE = function isOldIE() {
  var memo;
  return function memorize() {
    if (typeof memo === 'undefined') {
      // Test for IE <= 9 as proposed by Browserhacks
      // @see http://browserhacks.com/#hack-e71d8692f65334173fee715c222cb805
      // Tests for existence of standard globals is to allow style-loader
      // to operate correctly into non-standard environments
      // @see https://github.com/webpack-contrib/style-loader/issues/177
      memo = Boolean(window && document && document.all && !window.atob);
    }

    return memo;
  };
}();

var getTarget = function getTarget() {
  var memo = {};
  return function memorize(target) {
    if (typeof memo[target] === 'undefined') {
      var styleTarget = document.querySelector(target); // Special case to return head of iframe instead of iframe itself

      if (window.HTMLIFrameElement && styleTarget instanceof window.HTMLIFrameElement) {
        try {
          // This will throw an exception if access to iframe is blocked
          // due to cross-origin restrictions
          styleTarget = styleTarget.contentDocument.head;
        } catch (e) {
          // istanbul ignore next
          styleTarget = null;
        }
      }

      memo[target] = styleTarget;
    }

    return memo[target];
  };
}();

var stylesInDom = [];

function getIndexByIdentifier(identifier) {
  var result = -1;

  for (var i = 0; i < stylesInDom.length; i++) {
    if (stylesInDom[i].identifier === identifier) {
      result = i;
      break;
    }
  }

  return result;
}

function modulesToDom(list, options) {
  var idCountMap = {};
  var identifiers = [];

  for (var i = 0; i < list.length; i++) {
    var item = list[i];
    var id = options.base ? item[0] + options.base : item[0];
    var count = idCountMap[id] || 0;
    var identifier = "".concat(id, " ").concat(count);
    idCountMap[id] = count + 1;
    var index = getIndexByIdentifier(identifier);
    var obj = {
      css: item[1],
      media: item[2],
      sourceMap: item[3]
    };

    if (index !== -1) {
      stylesInDom[index].references++;
      stylesInDom[index].updater(obj);
    } else {
      stylesInDom.push({
        identifier: identifier,
        updater: addStyle(obj, options),
        references: 1
      });
    }

    identifiers.push(identifier);
  }

  return identifiers;
}

function insertStyleElement(options) {
  var style = document.createElement('style');
  var attributes = options.attributes || {};

  if (typeof attributes.nonce === 'undefined') {
    var nonce =  true ? __webpack_require__.nc : 0;

    if (nonce) {
      attributes.nonce = nonce;
    }
  }

  Object.keys(attributes).forEach(function (key) {
    style.setAttribute(key, attributes[key]);
  });

  if (typeof options.insert === 'function') {
    options.insert(style);
  } else {
    var target = getTarget(options.insert || 'head');

    if (!target) {
      throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");
    }

    target.appendChild(style);
  }

  return style;
}

function removeStyleElement(style) {
  // istanbul ignore if
  if (style.parentNode === null) {
    return false;
  }

  style.parentNode.removeChild(style);
}
/* istanbul ignore next  */


var replaceText = function replaceText() {
  var textStore = [];
  return function replace(index, replacement) {
    textStore[index] = replacement;
    return textStore.filter(Boolean).join('\n');
  };
}();

function applyToSingletonTag(style, index, remove, obj) {
  var css = remove ? '' : obj.media ? "@media ".concat(obj.media, " {").concat(obj.css, "}") : obj.css; // For old IE

  /* istanbul ignore if  */

  if (style.styleSheet) {
    style.styleSheet.cssText = replaceText(index, css);
  } else {
    var cssNode = document.createTextNode(css);
    var childNodes = style.childNodes;

    if (childNodes[index]) {
      style.removeChild(childNodes[index]);
    }

    if (childNodes.length) {
      style.insertBefore(cssNode, childNodes[index]);
    } else {
      style.appendChild(cssNode);
    }
  }
}

function applyToTag(style, options, obj) {
  var css = obj.css;
  var media = obj.media;
  var sourceMap = obj.sourceMap;

  if (media) {
    style.setAttribute('media', media);
  } else {
    style.removeAttribute('media');
  }

  if (sourceMap && typeof btoa !== 'undefined') {
    css += "\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(sourceMap)))), " */");
  } // For old IE

  /* istanbul ignore if  */


  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    while (style.firstChild) {
      style.removeChild(style.firstChild);
    }

    style.appendChild(document.createTextNode(css));
  }
}

var singleton = null;
var singletonCounter = 0;

function addStyle(obj, options) {
  var style;
  var update;
  var remove;

  if (options.singleton) {
    var styleIndex = singletonCounter++;
    style = singleton || (singleton = insertStyleElement(options));
    update = applyToSingletonTag.bind(null, style, styleIndex, false);
    remove = applyToSingletonTag.bind(null, style, styleIndex, true);
  } else {
    style = insertStyleElement(options);
    update = applyToTag.bind(null, style, options);

    remove = function remove() {
      removeStyleElement(style);
    };
  }

  update(obj);
  return function updateStyle(newObj) {
    if (newObj) {
      if (newObj.css === obj.css && newObj.media === obj.media && newObj.sourceMap === obj.sourceMap) {
        return;
      }

      update(obj = newObj);
    } else {
      remove();
    }
  };
}

module.exports = function (list, options) {
  options = options || {}; // Force single-tag solution on IE6-9, which has a hard limit on the # of <style>
  // tags it will allow on a page

  if (!options.singleton && typeof options.singleton !== 'boolean') {
    options.singleton = isOldIE();
  }

  list = list || [];
  var lastIdentifiers = modulesToDom(list, options);
  return function update(newList) {
    newList = newList || [];

    if (Object.prototype.toString.call(newList) !== '[object Array]') {
      return;
    }

    for (var i = 0; i < lastIdentifiers.length; i++) {
      var identifier = lastIdentifiers[i];
      var index = getIndexByIdentifier(identifier);
      stylesInDom[index].references--;
    }

    var newLastIdentifiers = modulesToDom(newList, options);

    for (var _i = 0; _i < lastIdentifiers.length; _i++) {
      var _identifier = lastIdentifiers[_i];

      var _index = getIndexByIdentifier(_identifier);

      if (stylesInDom[_index].references === 0) {
        stylesInDom[_index].updater();

        stylesInDom.splice(_index, 1);
      }
    }

    lastIdentifiers = newLastIdentifiers;
  };
};

/***/ }),
/* 38 */
/***/ ((module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(39);
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, "@charset \"UTF-8\";\n.date-picker, .time-picker {\n  display: flex;\n  flex-direction: column;\n  font-size: 10pt;\n  user-select: none;\n}\n.date-picker.date-picker, .time-picker.date-picker {\n  align-items: stretch;\n  background: white;\n  border: 1px solid #9e9e9e;\n}\n.date-picker.time-picker, .time-picker.time-picker {\n  align-items: center;\n}\n.date-picker > div .current, .time-picker > div .current {\n  background-color: #e0e0e0;\n}\n.date-picker > div .today, .time-picker > div .today {\n  border: 1px solid #757575;\n}\n.date-picker > div > .header, .time-picker > div > .header {\n  height: 25px;\n  display: flex;\n  font-size: 1.1em;\n  border-bottom: 1px solid #bdbdbd;\n}\n.date-picker > div > .header > div, .time-picker > div > .header > div {\n  flex-grow: 1;\n  display: inline-flex;\n  justify-content: space-between;\n}\n.date-picker > div > .header > div.year, .time-picker > div > .header > div.year {\n  flex-basis: 40%;\n  flex-grow: 0;\n}\n.date-picker > div > .header > div:not(:last-child), .time-picker > div > .header > div:not(:last-child) {\n  border-right: 1px solid #bdbdbd;\n  padding-right: 1px;\n}\n.date-picker > div > .header > div > span, .time-picker > div > .header > div > span {\n  display: inline-flex;\n  justify-content: center;\n  align-items: center;\n  padding: 4px;\n}\n.date-picker > div > .header > div > span.title, .time-picker > div > .header > div > span.title {\n  flex-grow: 1;\n}\n.date-picker > div > .header > div > span.fa, .time-picker > div > .header > div > span.fa {\n  color: #9e9e9e;\n}\n.date-picker > div > .header > div > span.fa:hover, .time-picker > div > .header > div > span.fa:hover {\n  color: #212121;\n}\n.date-picker > .year-picker, .time-picker > .year-picker {\n  height: 100%;\n}\n.date-picker > .year-picker > .year-grid, .time-picker > .year-picker > .year-grid {\n  display: grid;\n  grid-template-columns: repeat(5, 1fr);\n  grid-template-rows: 35px 1fr 1fr 35px;\n  height: 100%;\n}\n.date-picker > .year-picker > .year-grid > div, .time-picker > .year-picker > .year-grid > div {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n.date-picker > .year-picker > .year-grid > div.nav, .time-picker > .year-picker > .year-grid > div.nav {\n  grid-column-start: 1;\n  grid-column-end: 6;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  font-size: 1.1em;\n  color: #9e9e9e;\n}\n.date-picker > .year-picker > .year-grid > div.nav.top, .time-picker > .year-picker > .year-grid > div.nav.top {\n  border-bottom: 1px solid #bdbdbd;\n}\n.date-picker > .year-picker > .year-grid > div.nav.bottom, .time-picker > .year-picker > .year-grid > div.nav.bottom {\n  border-top: 1px solid #bdbdbd;\n}\n.date-picker > .year-picker > .year-grid > div.nav:hover, .time-picker > .year-picker > .year-grid > div.nav:hover {\n  color: #212121;\n}\n.date-picker > .year-picker > .year-grid > div.year:hover, .time-picker > .year-picker > .year-grid > div.year:hover {\n  background-color: #eeeeee;\n}\n.date-picker > .month-picker, .time-picker > .month-picker {\n  height: 100%;\n}\n.date-picker > .month-picker > .month-grid, .time-picker > .month-picker > .month-grid {\n  display: grid;\n  grid-template-columns: repeat(3, 1fr);\n  height: 100%;\n}\n.date-picker > .month-picker > .month-grid > div, .time-picker > .month-picker > .month-grid > div {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n.date-picker > .month-picker > .month-grid > div:hover, .time-picker > .month-picker > .month-grid > div:hover {\n  background-color: #eeeeee;\n}\n.date-picker > .day-picker, .time-picker > .day-picker {\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n}\n.date-picker > .day-picker > .day-grid, .time-picker > .day-picker > .day-grid {\n  display: grid;\n  flex-grow: 1;\n  grid-template-columns: repeat(7, 1fr);\n  grid-template-rows: repeat(7, 1fr);\n}\n.date-picker > .day-picker > .day-grid > div, .time-picker > .day-picker > .day-grid > div {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n}\n.date-picker > .day-picker > .day-grid > div:nth-child(7n+7), .time-picker > .day-picker > .day-grid > div:nth-child(7n+7) {\n  color: #EF233C;\n}\n.date-picker > .day-picker > .day-grid > .weekday, .time-picker > .day-picker > .day-grid > .weekday {\n  font-weight: 500;\n}\n.date-picker > .day-picker > .day-grid > .day:hover, .time-picker > .day-picker > .day-grid > .day:hover {\n  background-color: #eeeeee;\n}\n.date-picker > .time-picker svg .central text, .time-picker > .time-picker svg .central text {\n  font-size: 22px;\n  font-weight: bold;\n  alignment-baseline: middle;\n  text-anchor: middle;\n}\n.date-picker > .time-picker svg .central text.seconds, .time-picker > .time-picker svg .central text.seconds {\n  font-size: 16px;\n}\n.date-picker > .time-picker svg .outer-ring, .time-picker > .time-picker svg .outer-ring {\n  stroke: #616161;\n}\n.date-picker > .time-picker svg .hour-ring, .time-picker > .time-picker svg .hour-ring {\n  stroke: #616161;\n}\n.date-picker > .time-picker svg .minute-ring, .time-picker > .time-picker svg .minute-ring {\n  stroke: #e0e0e0;\n}\n.date-picker > .time-picker svg .second-ring, .time-picker > .time-picker svg .second-ring {\n  stroke: #bdbdbd;\n}\n.date-picker > .time-picker svg .minute-tick, .time-picker > .time-picker svg .minute-tick {\n  stroke: #616161;\n}\n.date-picker > .time-picker svg .second-tick, .time-picker > .time-picker svg .second-tick {\n  stroke: #bdbdbd;\n}\n.date-picker > .time-picker svg .hour-box .box, .time-picker > .time-picker svg .hour-box .box {\n  fill: transparent;\n}\n.date-picker > .time-picker svg .hour-box:hover .box, .time-picker > .time-picker svg .hour-box:hover .box {\n  fill: #eeeeee;\n}\n.date-picker > .time-picker svg .hour-box.selected .box, .time-picker > .time-picker svg .hour-box.selected .box {\n  fill: #e0e0e0;\n}\n.date-picker > .time-picker svg .minute-second-box, .time-picker > .time-picker svg .minute-second-box {\n  fill: transparent;\n}\n.date-picker > .time-picker svg .minutes-pointer, .time-picker > .time-picker svg .minutes-pointer {\n  fill: #EF233C;\n}\n.date-picker > .time-picker svg .seconds-pointer, .time-picker > .time-picker svg .seconds-pointer {\n  stroke: #FFBE00;\n  stroke-width: 3px;\n}\n.date-picker > .time-picker svg .minute-text, .time-picker > .time-picker svg .minute-text {\n  fill: #616161;\n}\n.date-picker > .time-picker svg .complication > circle, .time-picker > .time-picker svg .complication > circle {\n  stroke: #616161;\n}\n.date-picker > .time-picker svg .complication > text, .time-picker > .time-picker svg .complication > text {\n  fill: #424242;\n}\n.date-picker > .time-picker svg .complication:hover > circle, .time-picker > .time-picker svg .complication:hover > circle {\n  fill: #eeeeee;\n}\n\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Black.woff2\") format(\"woff2\");\n  font-weight: 900;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-BlackItalic.woff2\") format(\"woff2\");\n  font-weight: 900;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Bold.woff2\") format(\"woff2\");\n  font-weight: 700;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-BoldItalic.woff2\") format(\"woff2\");\n  font-weight: 700;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Medium.woff2\") format(\"woff2\");\n  font-weight: 500;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-MediumItalic.woff2\") format(\"woff2\");\n  font-weight: 500;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Regular.woff2\") format(\"woff2\");\n  font-weight: 400;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-RegularItalic.woff2\") format(\"woff2\");\n  font-weight: 400;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Light.woff2\") format(\"woff2\");\n  font-weight: 300;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-LightItalic.woff2\") format(\"woff2\");\n  font-weight: 300;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-Thin.woff2\") format(\"woff2\");\n  font-weight: 100;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"Roboto\";\n  src: url(\"fonts/Roboto/Roboto-ThinItalic.woff2\") format(\"woff2\");\n  font-weight: 100;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-Bold.woff2\") format(\"woff2\");\n  font-weight: 700;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-BoldItalic.woff2\") format(\"woff2\");\n  font-weight: 700;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-Medium.woff2\") format(\"woff2\");\n  font-weight: 500;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-MediumItalic.woff2\") format(\"woff2\");\n  font-weight: 500;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-Regular.woff2\") format(\"woff2\");\n  font-weight: 400;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-RegularItalic.woff2\") format(\"woff2\");\n  font-weight: 400;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-Light.woff2\") format(\"woff2\");\n  font-weight: 300;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-LightItalic.woff2\") format(\"woff2\");\n  font-weight: 300;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-Thin.woff2\") format(\"woff2\");\n  font-weight: 100;\n  font-style: normal;\n}\n@font-face {\n  font-family: \"RobotoMono\";\n  src: url(\"fonts/RobotoMono/RobotoMono-ThinItalic.woff2\") format(\"woff2\");\n  font-weight: 100;\n  font-style: italic;\n}\n@font-face {\n  font-family: \"FontAwesome\";\n  src: url(\"fonts/FontAwesome/FontAwesome-webfont.woff2\") format(\"woff2\");\n  font-weight: normal;\n  font-style: normal;\n}\n.fa {\n  display: inline-block;\n  font: normal normal normal 14px/1 FontAwesome;\n  font-size: inherit;\n  text-rendering: auto;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n\n/* makes the font 33% larger relative to the icon container */\n.fa-lg {\n  font-size: 1.33333333em;\n  line-height: 0.75em;\n  vertical-align: -15%;\n}\n\n.fa-2x {\n  font-size: 2em;\n}\n\n.fa-3x {\n  font-size: 3em;\n}\n\n.fa-4x {\n  font-size: 4em;\n}\n\n.fa-5x {\n  font-size: 5em;\n}\n\n.fa-fw {\n  width: 1.28571429em;\n  text-align: center;\n}\n\n.fa-ul {\n  padding-left: 0;\n  margin-left: 2.14285714em;\n  list-style-type: none;\n}\n\n.fa-ul > li {\n  position: relative;\n}\n\n.fa-li {\n  position: absolute;\n  left: -2.14285714em;\n  width: 2.14285714em;\n  top: 0.14285714em;\n  text-align: center;\n}\n\n.fa-li.fa-lg {\n  left: -1.85714286em;\n}\n\n.fa-border {\n  padding: 0.2em 0.25em 0.15em;\n  border: solid 0.08em #eeeeee;\n  border-radius: 0.1em;\n}\n\n.fa-pull-left {\n  float: left;\n}\n\n.fa-pull-right {\n  float: right;\n}\n\n.fa.fa-pull-left {\n  margin-right: 0.3em;\n}\n\n.fa.fa-pull-right {\n  margin-left: 0.3em;\n}\n\n/* Deprecated as of 4.4.0 */\n.pull-right {\n  float: right;\n}\n\n.pull-left {\n  float: left;\n}\n\n.fa.pull-left {\n  margin-right: 0.3em;\n}\n\n.fa.pull-right {\n  margin-left: 0.3em;\n}\n\n.fa-spin {\n  -webkit-animation: fa-spin 2s infinite linear;\n  animation: fa-spin 2s infinite linear;\n}\n\n.fa-pulse {\n  -webkit-animation: fa-spin 1s infinite steps(8);\n  animation: fa-spin 1s infinite steps(8);\n}\n\n@-webkit-keyframes fa-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n@keyframes fa-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n.fa-rotate-90 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=1)\";\n  -webkit-transform: rotate(90deg);\n  -ms-transform: rotate(90deg);\n  transform: rotate(90deg);\n}\n\n.fa-rotate-180 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=2)\";\n  -webkit-transform: rotate(180deg);\n  -ms-transform: rotate(180deg);\n  transform: rotate(180deg);\n}\n\n.fa-rotate-270 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=3)\";\n  -webkit-transform: rotate(270deg);\n  -ms-transform: rotate(270deg);\n  transform: rotate(270deg);\n}\n\n.fa-flip-horizontal {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)\";\n  -webkit-transform: scale(-1, 1);\n  -ms-transform: scale(-1, 1);\n  transform: scale(-1, 1);\n}\n\n.fa-flip-vertical {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";\n  -webkit-transform: scale(1, -1);\n  -ms-transform: scale(1, -1);\n  transform: scale(1, -1);\n}\n\n:root .fa-rotate-90,\n:root .fa-rotate-180,\n:root .fa-rotate-270,\n:root .fa-flip-horizontal,\n:root .fa-flip-vertical {\n  filter: none;\n}\n\n.fa-stack {\n  position: relative;\n  display: inline-block;\n  width: 2em;\n  height: 2em;\n  line-height: 2em;\n  vertical-align: middle;\n}\n\n.fa-stack-1x,\n.fa-stack-2x {\n  position: absolute;\n  left: 0;\n  width: 100%;\n  text-align: center;\n}\n\n.fa-stack-1x {\n  line-height: inherit;\n}\n\n.fa-stack-2x {\n  font-size: 2em;\n}\n\n.fa-inverse {\n  color: #ffffff;\n}\n\n/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen\n   readers do not read off random characters that represent icons */\n.fa-glass:before {\n  content: \"\";\n}\n\n.fa-music:before {\n  content: \"\";\n}\n\n.fa-search:before {\n  content: \"\";\n}\n\n.fa-envelope-o:before {\n  content: \"\";\n}\n\n.fa-heart:before {\n  content: \"\";\n}\n\n.fa-star:before {\n  content: \"\";\n}\n\n.fa-star-o:before {\n  content: \"\";\n}\n\n.fa-user:before {\n  content: \"\";\n}\n\n.fa-film:before {\n  content: \"\";\n}\n\n.fa-th-large:before {\n  content: \"\";\n}\n\n.fa-th:before {\n  content: \"\";\n}\n\n.fa-th-list:before {\n  content: \"\";\n}\n\n.fa-check:before {\n  content: \"\";\n}\n\n.fa-remove:before,\n.fa-close:before,\n.fa-times:before {\n  content: \"\";\n}\n\n.fa-search-plus:before {\n  content: \"\";\n}\n\n.fa-search-minus:before {\n  content: \"\";\n}\n\n.fa-power-off:before {\n  content: \"\";\n}\n\n.fa-signal:before {\n  content: \"\";\n}\n\n.fa-gear:before,\n.fa-cog:before {\n  content: \"\";\n}\n\n.fa-trash-o:before {\n  content: \"\";\n}\n\n.fa-home:before {\n  content: \"\";\n}\n\n.fa-file-o:before {\n  content: \"\";\n}\n\n.fa-clock-o:before {\n  content: \"\";\n}\n\n.fa-road:before {\n  content: \"\";\n}\n\n.fa-download:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-o-down:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-o-up:before {\n  content: \"\";\n}\n\n.fa-inbox:before {\n  content: \"\";\n}\n\n.fa-play-circle-o:before {\n  content: \"\";\n}\n\n.fa-rotate-right:before,\n.fa-repeat:before {\n  content: \"\";\n}\n\n.fa-refresh:before {\n  content: \"\";\n}\n\n.fa-list-alt:before {\n  content: \"\";\n}\n\n.fa-lock:before {\n  content: \"\";\n}\n\n.fa-flag:before {\n  content: \"\";\n}\n\n.fa-headphones:before {\n  content: \"\";\n}\n\n.fa-volume-off:before {\n  content: \"\";\n}\n\n.fa-volume-down:before {\n  content: \"\";\n}\n\n.fa-volume-up:before {\n  content: \"\";\n}\n\n.fa-qrcode:before {\n  content: \"\";\n}\n\n.fa-barcode:before {\n  content: \"\";\n}\n\n.fa-tag:before {\n  content: \"\";\n}\n\n.fa-tags:before {\n  content: \"\";\n}\n\n.fa-book:before {\n  content: \"\";\n}\n\n.fa-bookmark:before {\n  content: \"\";\n}\n\n.fa-print:before {\n  content: \"\";\n}\n\n.fa-camera:before {\n  content: \"\";\n}\n\n.fa-font:before {\n  content: \"\";\n}\n\n.fa-bold:before {\n  content: \"\";\n}\n\n.fa-italic:before {\n  content: \"\";\n}\n\n.fa-text-height:before {\n  content: \"\";\n}\n\n.fa-text-width:before {\n  content: \"\";\n}\n\n.fa-align-left:before {\n  content: \"\";\n}\n\n.fa-align-center:before {\n  content: \"\";\n}\n\n.fa-align-right:before {\n  content: \"\";\n}\n\n.fa-align-justify:before {\n  content: \"\";\n}\n\n.fa-list:before {\n  content: \"\";\n}\n\n.fa-dedent:before,\n.fa-outdent:before {\n  content: \"\";\n}\n\n.fa-indent:before {\n  content: \"\";\n}\n\n.fa-video-camera:before {\n  content: \"\";\n}\n\n.fa-photo:before,\n.fa-image:before,\n.fa-picture-o:before {\n  content: \"\";\n}\n\n.fa-pencil:before {\n  content: \"\";\n}\n\n.fa-map-marker:before {\n  content: \"\";\n}\n\n.fa-adjust:before {\n  content: \"\";\n}\n\n.fa-tint:before {\n  content: \"\";\n}\n\n.fa-edit:before,\n.fa-pencil-square-o:before {\n  content: \"\";\n}\n\n.fa-share-square-o:before {\n  content: \"\";\n}\n\n.fa-check-square-o:before {\n  content: \"\";\n}\n\n.fa-arrows:before {\n  content: \"\";\n}\n\n.fa-step-backward:before {\n  content: \"\";\n}\n\n.fa-fast-backward:before {\n  content: \"\";\n}\n\n.fa-backward:before {\n  content: \"\";\n}\n\n.fa-play:before {\n  content: \"\";\n}\n\n.fa-pause:before {\n  content: \"\";\n}\n\n.fa-stop:before {\n  content: \"\";\n}\n\n.fa-forward:before {\n  content: \"\";\n}\n\n.fa-fast-forward:before {\n  content: \"\";\n}\n\n.fa-step-forward:before {\n  content: \"\";\n}\n\n.fa-eject:before {\n  content: \"\";\n}\n\n.fa-chevron-left:before {\n  content: \"\";\n}\n\n.fa-chevron-right:before {\n  content: \"\";\n}\n\n.fa-plus-circle:before {\n  content: \"\";\n}\n\n.fa-minus-circle:before {\n  content: \"\";\n}\n\n.fa-times-circle:before {\n  content: \"\";\n}\n\n.fa-check-circle:before {\n  content: \"\";\n}\n\n.fa-question-circle:before {\n  content: \"\";\n}\n\n.fa-info-circle:before {\n  content: \"\";\n}\n\n.fa-crosshairs:before {\n  content: \"\";\n}\n\n.fa-times-circle-o:before {\n  content: \"\";\n}\n\n.fa-check-circle-o:before {\n  content: \"\";\n}\n\n.fa-ban:before {\n  content: \"\";\n}\n\n.fa-arrow-left:before {\n  content: \"\";\n}\n\n.fa-arrow-right:before {\n  content: \"\";\n}\n\n.fa-arrow-up:before {\n  content: \"\";\n}\n\n.fa-arrow-down:before {\n  content: \"\";\n}\n\n.fa-mail-forward:before,\n.fa-share:before {\n  content: \"\";\n}\n\n.fa-expand:before {\n  content: \"\";\n}\n\n.fa-compress:before {\n  content: \"\";\n}\n\n.fa-plus:before {\n  content: \"\";\n}\n\n.fa-minus:before {\n  content: \"\";\n}\n\n.fa-asterisk:before {\n  content: \"\";\n}\n\n.fa-exclamation-circle:before {\n  content: \"\";\n}\n\n.fa-gift:before {\n  content: \"\";\n}\n\n.fa-leaf:before {\n  content: \"\";\n}\n\n.fa-fire:before {\n  content: \"\";\n}\n\n.fa-eye:before {\n  content: \"\";\n}\n\n.fa-eye-slash:before {\n  content: \"\";\n}\n\n.fa-warning:before,\n.fa-exclamation-triangle:before {\n  content: \"\";\n}\n\n.fa-plane:before {\n  content: \"\";\n}\n\n.fa-calendar:before {\n  content: \"\";\n}\n\n.fa-random:before {\n  content: \"\";\n}\n\n.fa-comment:before {\n  content: \"\";\n}\n\n.fa-magnet:before {\n  content: \"\";\n}\n\n.fa-chevron-up:before {\n  content: \"\";\n}\n\n.fa-chevron-down:before {\n  content: \"\";\n}\n\n.fa-retweet:before {\n  content: \"\";\n}\n\n.fa-shopping-cart:before {\n  content: \"\";\n}\n\n.fa-folder:before {\n  content: \"\";\n}\n\n.fa-folder-open:before {\n  content: \"\";\n}\n\n.fa-arrows-v:before {\n  content: \"\";\n}\n\n.fa-arrows-h:before {\n  content: \"\";\n}\n\n.fa-bar-chart-o:before,\n.fa-bar-chart:before {\n  content: \"\";\n}\n\n.fa-twitter-square:before {\n  content: \"\";\n}\n\n.fa-facebook-square:before {\n  content: \"\";\n}\n\n.fa-camera-retro:before {\n  content: \"\";\n}\n\n.fa-key:before {\n  content: \"\";\n}\n\n.fa-gears:before,\n.fa-cogs:before {\n  content: \"\";\n}\n\n.fa-comments:before {\n  content: \"\";\n}\n\n.fa-thumbs-o-up:before {\n  content: \"\";\n}\n\n.fa-thumbs-o-down:before {\n  content: \"\";\n}\n\n.fa-star-half:before {\n  content: \"\";\n}\n\n.fa-heart-o:before {\n  content: \"\";\n}\n\n.fa-sign-out:before {\n  content: \"\";\n}\n\n.fa-linkedin-square:before {\n  content: \"\";\n}\n\n.fa-thumb-tack:before {\n  content: \"\";\n}\n\n.fa-external-link:before {\n  content: \"\";\n}\n\n.fa-sign-in:before {\n  content: \"\";\n}\n\n.fa-trophy:before {\n  content: \"\";\n}\n\n.fa-github-square:before {\n  content: \"\";\n}\n\n.fa-upload:before {\n  content: \"\";\n}\n\n.fa-lemon-o:before {\n  content: \"\";\n}\n\n.fa-phone:before {\n  content: \"\";\n}\n\n.fa-square-o:before {\n  content: \"\";\n}\n\n.fa-bookmark-o:before {\n  content: \"\";\n}\n\n.fa-phone-square:before {\n  content: \"\";\n}\n\n.fa-twitter:before {\n  content: \"\";\n}\n\n.fa-facebook-f:before,\n.fa-facebook:before {\n  content: \"\";\n}\n\n.fa-github:before {\n  content: \"\";\n}\n\n.fa-unlock:before {\n  content: \"\";\n}\n\n.fa-credit-card:before {\n  content: \"\";\n}\n\n.fa-feed:before,\n.fa-rss:before {\n  content: \"\";\n}\n\n.fa-hdd-o:before {\n  content: \"\";\n}\n\n.fa-bullhorn:before {\n  content: \"\";\n}\n\n.fa-bell:before {\n  content: \"\";\n}\n\n.fa-certificate:before {\n  content: \"\";\n}\n\n.fa-hand-o-right:before {\n  content: \"\";\n}\n\n.fa-hand-o-left:before {\n  content: \"\";\n}\n\n.fa-hand-o-up:before {\n  content: \"\";\n}\n\n.fa-hand-o-down:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-left:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-right:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-up:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-down:before {\n  content: \"\";\n}\n\n.fa-globe:before {\n  content: \"\";\n}\n\n.fa-wrench:before {\n  content: \"\";\n}\n\n.fa-tasks:before {\n  content: \"\";\n}\n\n.fa-filter:before {\n  content: \"\";\n}\n\n.fa-briefcase:before {\n  content: \"\";\n}\n\n.fa-arrows-alt:before {\n  content: \"\";\n}\n\n.fa-group:before,\n.fa-users:before {\n  content: \"\";\n}\n\n.fa-chain:before,\n.fa-link:before {\n  content: \"\";\n}\n\n.fa-cloud:before {\n  content: \"\";\n}\n\n.fa-flask:before {\n  content: \"\";\n}\n\n.fa-cut:before,\n.fa-scissors:before {\n  content: \"\";\n}\n\n.fa-copy:before,\n.fa-files-o:before {\n  content: \"\";\n}\n\n.fa-paperclip:before {\n  content: \"\";\n}\n\n.fa-save:before,\n.fa-floppy-o:before {\n  content: \"\";\n}\n\n.fa-square:before {\n  content: \"\";\n}\n\n.fa-navicon:before,\n.fa-reorder:before,\n.fa-bars:before {\n  content: \"\";\n}\n\n.fa-list-ul:before {\n  content: \"\";\n}\n\n.fa-list-ol:before {\n  content: \"\";\n}\n\n.fa-strikethrough:before {\n  content: \"\";\n}\n\n.fa-underline:before {\n  content: \"\";\n}\n\n.fa-table:before {\n  content: \"\";\n}\n\n.fa-magic:before {\n  content: \"\";\n}\n\n.fa-truck:before {\n  content: \"\";\n}\n\n.fa-pinterest:before {\n  content: \"\";\n}\n\n.fa-pinterest-square:before {\n  content: \"\";\n}\n\n.fa-google-plus-square:before {\n  content: \"\";\n}\n\n.fa-google-plus:before {\n  content: \"\";\n}\n\n.fa-money:before {\n  content: \"\";\n}\n\n.fa-caret-down:before {\n  content: \"\";\n}\n\n.fa-caret-up:before {\n  content: \"\";\n}\n\n.fa-caret-left:before {\n  content: \"\";\n}\n\n.fa-caret-right:before {\n  content: \"\";\n}\n\n.fa-columns:before {\n  content: \"\";\n}\n\n.fa-unsorted:before,\n.fa-sort:before {\n  content: \"\";\n}\n\n.fa-sort-down:before,\n.fa-sort-desc:before {\n  content: \"\";\n}\n\n.fa-sort-up:before,\n.fa-sort-asc:before {\n  content: \"\";\n}\n\n.fa-envelope:before {\n  content: \"\";\n}\n\n.fa-linkedin:before {\n  content: \"\";\n}\n\n.fa-rotate-left:before,\n.fa-undo:before {\n  content: \"\";\n}\n\n.fa-legal:before,\n.fa-gavel:before {\n  content: \"\";\n}\n\n.fa-dashboard:before,\n.fa-tachometer:before {\n  content: \"\";\n}\n\n.fa-comment-o:before {\n  content: \"\";\n}\n\n.fa-comments-o:before {\n  content: \"\";\n}\n\n.fa-flash:before,\n.fa-bolt:before {\n  content: \"\";\n}\n\n.fa-sitemap:before {\n  content: \"\";\n}\n\n.fa-umbrella:before {\n  content: \"\";\n}\n\n.fa-paste:before,\n.fa-clipboard:before {\n  content: \"\";\n}\n\n.fa-lightbulb-o:before {\n  content: \"\";\n}\n\n.fa-exchange:before {\n  content: \"\";\n}\n\n.fa-cloud-download:before {\n  content: \"\";\n}\n\n.fa-cloud-upload:before {\n  content: \"\";\n}\n\n.fa-user-md:before {\n  content: \"\";\n}\n\n.fa-stethoscope:before {\n  content: \"\";\n}\n\n.fa-suitcase:before {\n  content: \"\";\n}\n\n.fa-bell-o:before {\n  content: \"\";\n}\n\n.fa-coffee:before {\n  content: \"\";\n}\n\n.fa-cutlery:before {\n  content: \"\";\n}\n\n.fa-file-text-o:before {\n  content: \"\";\n}\n\n.fa-building-o:before {\n  content: \"\";\n}\n\n.fa-hospital-o:before {\n  content: \"\";\n}\n\n.fa-ambulance:before {\n  content: \"\";\n}\n\n.fa-medkit:before {\n  content: \"\";\n}\n\n.fa-fighter-jet:before {\n  content: \"\";\n}\n\n.fa-beer:before {\n  content: \"\";\n}\n\n.fa-h-square:before {\n  content: \"\";\n}\n\n.fa-plus-square:before {\n  content: \"\";\n}\n\n.fa-angle-double-left:before {\n  content: \"\";\n}\n\n.fa-angle-double-right:before {\n  content: \"\";\n}\n\n.fa-angle-double-up:before {\n  content: \"\";\n}\n\n.fa-angle-double-down:before {\n  content: \"\";\n}\n\n.fa-angle-left:before {\n  content: \"\";\n}\n\n.fa-angle-right:before {\n  content: \"\";\n}\n\n.fa-angle-up:before {\n  content: \"\";\n}\n\n.fa-angle-down:before {\n  content: \"\";\n}\n\n.fa-desktop:before {\n  content: \"\";\n}\n\n.fa-laptop:before {\n  content: \"\";\n}\n\n.fa-tablet:before {\n  content: \"\";\n}\n\n.fa-mobile-phone:before,\n.fa-mobile:before {\n  content: \"\";\n}\n\n.fa-circle-o:before {\n  content: \"\";\n}\n\n.fa-quote-left:before {\n  content: \"\";\n}\n\n.fa-quote-right:before {\n  content: \"\";\n}\n\n.fa-spinner:before {\n  content: \"\";\n}\n\n.fa-circle:before {\n  content: \"\";\n}\n\n.fa-mail-reply:before,\n.fa-reply:before {\n  content: \"\";\n}\n\n.fa-github-alt:before {\n  content: \"\";\n}\n\n.fa-folder-o:before {\n  content: \"\";\n}\n\n.fa-folder-open-o:before {\n  content: \"\";\n}\n\n.fa-smile-o:before {\n  content: \"\";\n}\n\n.fa-frown-o:before {\n  content: \"\";\n}\n\n.fa-meh-o:before {\n  content: \"\";\n}\n\n.fa-gamepad:before {\n  content: \"\";\n}\n\n.fa-keyboard-o:before {\n  content: \"\";\n}\n\n.fa-flag-o:before {\n  content: \"\";\n}\n\n.fa-flag-checkered:before {\n  content: \"\";\n}\n\n.fa-terminal:before {\n  content: \"\";\n}\n\n.fa-code:before {\n  content: \"\";\n}\n\n.fa-mail-reply-all:before,\n.fa-reply-all:before {\n  content: \"\";\n}\n\n.fa-star-half-empty:before,\n.fa-star-half-full:before,\n.fa-star-half-o:before {\n  content: \"\";\n}\n\n.fa-location-arrow:before {\n  content: \"\";\n}\n\n.fa-crop:before {\n  content: \"\";\n}\n\n.fa-code-fork:before {\n  content: \"\";\n}\n\n.fa-unlink:before,\n.fa-chain-broken:before {\n  content: \"\";\n}\n\n.fa-question:before {\n  content: \"\";\n}\n\n.fa-info:before {\n  content: \"\";\n}\n\n.fa-exclamation:before {\n  content: \"\";\n}\n\n.fa-superscript:before {\n  content: \"\";\n}\n\n.fa-subscript:before {\n  content: \"\";\n}\n\n.fa-eraser:before {\n  content: \"\";\n}\n\n.fa-puzzle-piece:before {\n  content: \"\";\n}\n\n.fa-microphone:before {\n  content: \"\";\n}\n\n.fa-microphone-slash:before {\n  content: \"\";\n}\n\n.fa-shield:before {\n  content: \"\";\n}\n\n.fa-calendar-o:before {\n  content: \"\";\n}\n\n.fa-fire-extinguisher:before {\n  content: \"\";\n}\n\n.fa-rocket:before {\n  content: \"\";\n}\n\n.fa-maxcdn:before {\n  content: \"\";\n}\n\n.fa-chevron-circle-left:before {\n  content: \"\";\n}\n\n.fa-chevron-circle-right:before {\n  content: \"\";\n}\n\n.fa-chevron-circle-up:before {\n  content: \"\";\n}\n\n.fa-chevron-circle-down:before {\n  content: \"\";\n}\n\n.fa-html5:before {\n  content: \"\";\n}\n\n.fa-css3:before {\n  content: \"\";\n}\n\n.fa-anchor:before {\n  content: \"\";\n}\n\n.fa-unlock-alt:before {\n  content: \"\";\n}\n\n.fa-bullseye:before {\n  content: \"\";\n}\n\n.fa-ellipsis-h:before {\n  content: \"\";\n}\n\n.fa-ellipsis-v:before {\n  content: \"\";\n}\n\n.fa-rss-square:before {\n  content: \"\";\n}\n\n.fa-play-circle:before {\n  content: \"\";\n}\n\n.fa-ticket:before {\n  content: \"\";\n}\n\n.fa-minus-square:before {\n  content: \"\";\n}\n\n.fa-minus-square-o:before {\n  content: \"\";\n}\n\n.fa-level-up:before {\n  content: \"\";\n}\n\n.fa-level-down:before {\n  content: \"\";\n}\n\n.fa-check-square:before {\n  content: \"\";\n}\n\n.fa-pencil-square:before {\n  content: \"\";\n}\n\n.fa-external-link-square:before {\n  content: \"\";\n}\n\n.fa-share-square:before {\n  content: \"\";\n}\n\n.fa-compass:before {\n  content: \"\";\n}\n\n.fa-toggle-down:before,\n.fa-caret-square-o-down:before {\n  content: \"\";\n}\n\n.fa-toggle-up:before,\n.fa-caret-square-o-up:before {\n  content: \"\";\n}\n\n.fa-toggle-right:before,\n.fa-caret-square-o-right:before {\n  content: \"\";\n}\n\n.fa-euro:before,\n.fa-eur:before {\n  content: \"\";\n}\n\n.fa-gbp:before {\n  content: \"\";\n}\n\n.fa-dollar:before,\n.fa-usd:before {\n  content: \"\";\n}\n\n.fa-rupee:before,\n.fa-inr:before {\n  content: \"\";\n}\n\n.fa-cny:before,\n.fa-rmb:before,\n.fa-yen:before,\n.fa-jpy:before {\n  content: \"\";\n}\n\n.fa-ruble:before,\n.fa-rouble:before,\n.fa-rub:before {\n  content: \"\";\n}\n\n.fa-won:before,\n.fa-krw:before {\n  content: \"\";\n}\n\n.fa-bitcoin:before,\n.fa-btc:before {\n  content: \"\";\n}\n\n.fa-file:before {\n  content: \"\";\n}\n\n.fa-file-text:before {\n  content: \"\";\n}\n\n.fa-sort-alpha-asc:before {\n  content: \"\";\n}\n\n.fa-sort-alpha-desc:before {\n  content: \"\";\n}\n\n.fa-sort-amount-asc:before {\n  content: \"\";\n}\n\n.fa-sort-amount-desc:before {\n  content: \"\";\n}\n\n.fa-sort-numeric-asc:before {\n  content: \"\";\n}\n\n.fa-sort-numeric-desc:before {\n  content: \"\";\n}\n\n.fa-thumbs-up:before {\n  content: \"\";\n}\n\n.fa-thumbs-down:before {\n  content: \"\";\n}\n\n.fa-youtube-square:before {\n  content: \"\";\n}\n\n.fa-youtube:before {\n  content: \"\";\n}\n\n.fa-xing:before {\n  content: \"\";\n}\n\n.fa-xing-square:before {\n  content: \"\";\n}\n\n.fa-youtube-play:before {\n  content: \"\";\n}\n\n.fa-dropbox:before {\n  content: \"\";\n}\n\n.fa-stack-overflow:before {\n  content: \"\";\n}\n\n.fa-instagram:before {\n  content: \"\";\n}\n\n.fa-flickr:before {\n  content: \"\";\n}\n\n.fa-adn:before {\n  content: \"\";\n}\n\n.fa-bitbucket:before {\n  content: \"\";\n}\n\n.fa-bitbucket-square:before {\n  content: \"\";\n}\n\n.fa-tumblr:before {\n  content: \"\";\n}\n\n.fa-tumblr-square:before {\n  content: \"\";\n}\n\n.fa-long-arrow-down:before {\n  content: \"\";\n}\n\n.fa-long-arrow-up:before {\n  content: \"\";\n}\n\n.fa-long-arrow-left:before {\n  content: \"\";\n}\n\n.fa-long-arrow-right:before {\n  content: \"\";\n}\n\n.fa-apple:before {\n  content: \"\";\n}\n\n.fa-windows:before {\n  content: \"\";\n}\n\n.fa-android:before {\n  content: \"\";\n}\n\n.fa-linux:before {\n  content: \"\";\n}\n\n.fa-dribbble:before {\n  content: \"\";\n}\n\n.fa-skype:before {\n  content: \"\";\n}\n\n.fa-foursquare:before {\n  content: \"\";\n}\n\n.fa-trello:before {\n  content: \"\";\n}\n\n.fa-female:before {\n  content: \"\";\n}\n\n.fa-male:before {\n  content: \"\";\n}\n\n.fa-gittip:before,\n.fa-gratipay:before {\n  content: \"\";\n}\n\n.fa-sun-o:before {\n  content: \"\";\n}\n\n.fa-moon-o:before {\n  content: \"\";\n}\n\n.fa-archive:before {\n  content: \"\";\n}\n\n.fa-bug:before {\n  content: \"\";\n}\n\n.fa-vk:before {\n  content: \"\";\n}\n\n.fa-weibo:before {\n  content: \"\";\n}\n\n.fa-renren:before {\n  content: \"\";\n}\n\n.fa-pagelines:before {\n  content: \"\";\n}\n\n.fa-stack-exchange:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-o-right:before {\n  content: \"\";\n}\n\n.fa-arrow-circle-o-left:before {\n  content: \"\";\n}\n\n.fa-toggle-left:before,\n.fa-caret-square-o-left:before {\n  content: \"\";\n}\n\n.fa-dot-circle-o:before {\n  content: \"\";\n}\n\n.fa-wheelchair:before {\n  content: \"\";\n}\n\n.fa-vimeo-square:before {\n  content: \"\";\n}\n\n.fa-turkish-lira:before,\n.fa-try:before {\n  content: \"\";\n}\n\n.fa-plus-square-o:before {\n  content: \"\";\n}\n\n.fa-space-shuttle:before {\n  content: \"\";\n}\n\n.fa-slack:before {\n  content: \"\";\n}\n\n.fa-envelope-square:before {\n  content: \"\";\n}\n\n.fa-wordpress:before {\n  content: \"\";\n}\n\n.fa-openid:before {\n  content: \"\";\n}\n\n.fa-institution:before,\n.fa-bank:before,\n.fa-university:before {\n  content: \"\";\n}\n\n.fa-mortar-board:before,\n.fa-graduation-cap:before {\n  content: \"\";\n}\n\n.fa-yahoo:before {\n  content: \"\";\n}\n\n.fa-google:before {\n  content: \"\";\n}\n\n.fa-reddit:before {\n  content: \"\";\n}\n\n.fa-reddit-square:before {\n  content: \"\";\n}\n\n.fa-stumbleupon-circle:before {\n  content: \"\";\n}\n\n.fa-stumbleupon:before {\n  content: \"\";\n}\n\n.fa-delicious:before {\n  content: \"\";\n}\n\n.fa-digg:before {\n  content: \"\";\n}\n\n.fa-pied-piper-pp:before {\n  content: \"\";\n}\n\n.fa-pied-piper-alt:before {\n  content: \"\";\n}\n\n.fa-drupal:before {\n  content: \"\";\n}\n\n.fa-joomla:before {\n  content: \"\";\n}\n\n.fa-language:before {\n  content: \"\";\n}\n\n.fa-fax:before {\n  content: \"\";\n}\n\n.fa-building:before {\n  content: \"\";\n}\n\n.fa-child:before {\n  content: \"\";\n}\n\n.fa-paw:before {\n  content: \"\";\n}\n\n.fa-spoon:before {\n  content: \"\";\n}\n\n.fa-cube:before {\n  content: \"\";\n}\n\n.fa-cubes:before {\n  content: \"\";\n}\n\n.fa-behance:before {\n  content: \"\";\n}\n\n.fa-behance-square:before {\n  content: \"\";\n}\n\n.fa-steam:before {\n  content: \"\";\n}\n\n.fa-steam-square:before {\n  content: \"\";\n}\n\n.fa-recycle:before {\n  content: \"\";\n}\n\n.fa-automobile:before,\n.fa-car:before {\n  content: \"\";\n}\n\n.fa-cab:before,\n.fa-taxi:before {\n  content: \"\";\n}\n\n.fa-tree:before {\n  content: \"\";\n}\n\n.fa-spotify:before {\n  content: \"\";\n}\n\n.fa-deviantart:before {\n  content: \"\";\n}\n\n.fa-soundcloud:before {\n  content: \"\";\n}\n\n.fa-database:before {\n  content: \"\";\n}\n\n.fa-file-pdf-o:before {\n  content: \"\";\n}\n\n.fa-file-word-o:before {\n  content: \"\";\n}\n\n.fa-file-excel-o:before {\n  content: \"\";\n}\n\n.fa-file-powerpoint-o:before {\n  content: \"\";\n}\n\n.fa-file-photo-o:before,\n.fa-file-picture-o:before,\n.fa-file-image-o:before {\n  content: \"\";\n}\n\n.fa-file-zip-o:before,\n.fa-file-archive-o:before {\n  content: \"\";\n}\n\n.fa-file-sound-o:before,\n.fa-file-audio-o:before {\n  content: \"\";\n}\n\n.fa-file-movie-o:before,\n.fa-file-video-o:before {\n  content: \"\";\n}\n\n.fa-file-code-o:before {\n  content: \"\";\n}\n\n.fa-vine:before {\n  content: \"\";\n}\n\n.fa-codepen:before {\n  content: \"\";\n}\n\n.fa-jsfiddle:before {\n  content: \"\";\n}\n\n.fa-life-bouy:before,\n.fa-life-buoy:before,\n.fa-life-saver:before,\n.fa-support:before,\n.fa-life-ring:before {\n  content: \"\";\n}\n\n.fa-circle-o-notch:before {\n  content: \"\";\n}\n\n.fa-ra:before,\n.fa-resistance:before,\n.fa-rebel:before {\n  content: \"\";\n}\n\n.fa-ge:before,\n.fa-empire:before {\n  content: \"\";\n}\n\n.fa-git-square:before {\n  content: \"\";\n}\n\n.fa-git:before {\n  content: \"\";\n}\n\n.fa-y-combinator-square:before,\n.fa-yc-square:before,\n.fa-hacker-news:before {\n  content: \"\";\n}\n\n.fa-tencent-weibo:before {\n  content: \"\";\n}\n\n.fa-qq:before {\n  content: \"\";\n}\n\n.fa-wechat:before,\n.fa-weixin:before {\n  content: \"\";\n}\n\n.fa-send:before,\n.fa-paper-plane:before {\n  content: \"\";\n}\n\n.fa-send-o:before,\n.fa-paper-plane-o:before {\n  content: \"\";\n}\n\n.fa-history:before {\n  content: \"\";\n}\n\n.fa-circle-thin:before {\n  content: \"\";\n}\n\n.fa-header:before {\n  content: \"\";\n}\n\n.fa-paragraph:before {\n  content: \"\";\n}\n\n.fa-sliders:before {\n  content: \"\";\n}\n\n.fa-share-alt:before {\n  content: \"\";\n}\n\n.fa-share-alt-square:before {\n  content: \"\";\n}\n\n.fa-bomb:before {\n  content: \"\";\n}\n\n.fa-soccer-ball-o:before,\n.fa-futbol-o:before {\n  content: \"\";\n}\n\n.fa-tty:before {\n  content: \"\";\n}\n\n.fa-binoculars:before {\n  content: \"\";\n}\n\n.fa-plug:before {\n  content: \"\";\n}\n\n.fa-slideshare:before {\n  content: \"\";\n}\n\n.fa-twitch:before {\n  content: \"\";\n}\n\n.fa-yelp:before {\n  content: \"\";\n}\n\n.fa-newspaper-o:before {\n  content: \"\";\n}\n\n.fa-wifi:before {\n  content: \"\";\n}\n\n.fa-calculator:before {\n  content: \"\";\n}\n\n.fa-paypal:before {\n  content: \"\";\n}\n\n.fa-google-wallet:before {\n  content: \"\";\n}\n\n.fa-cc-visa:before {\n  content: \"\";\n}\n\n.fa-cc-mastercard:before {\n  content: \"\";\n}\n\n.fa-cc-discover:before {\n  content: \"\";\n}\n\n.fa-cc-amex:before {\n  content: \"\";\n}\n\n.fa-cc-paypal:before {\n  content: \"\";\n}\n\n.fa-cc-stripe:before {\n  content: \"\";\n}\n\n.fa-bell-slash:before {\n  content: \"\";\n}\n\n.fa-bell-slash-o:before {\n  content: \"\";\n}\n\n.fa-trash:before {\n  content: \"\";\n}\n\n.fa-copyright:before {\n  content: \"\";\n}\n\n.fa-at:before {\n  content: \"\";\n}\n\n.fa-eyedropper:before {\n  content: \"\";\n}\n\n.fa-paint-brush:before {\n  content: \"\";\n}\n\n.fa-birthday-cake:before {\n  content: \"\";\n}\n\n.fa-area-chart:before {\n  content: \"\";\n}\n\n.fa-pie-chart:before {\n  content: \"\";\n}\n\n.fa-line-chart:before {\n  content: \"\";\n}\n\n.fa-lastfm:before {\n  content: \"\";\n}\n\n.fa-lastfm-square:before {\n  content: \"\";\n}\n\n.fa-toggle-off:before {\n  content: \"\";\n}\n\n.fa-toggle-on:before {\n  content: \"\";\n}\n\n.fa-bicycle:before {\n  content: \"\";\n}\n\n.fa-bus:before {\n  content: \"\";\n}\n\n.fa-ioxhost:before {\n  content: \"\";\n}\n\n.fa-angellist:before {\n  content: \"\";\n}\n\n.fa-cc:before {\n  content: \"\";\n}\n\n.fa-shekel:before,\n.fa-sheqel:before,\n.fa-ils:before {\n  content: \"\";\n}\n\n.fa-meanpath:before {\n  content: \"\";\n}\n\n.fa-buysellads:before {\n  content: \"\";\n}\n\n.fa-connectdevelop:before {\n  content: \"\";\n}\n\n.fa-dashcube:before {\n  content: \"\";\n}\n\n.fa-forumbee:before {\n  content: \"\";\n}\n\n.fa-leanpub:before {\n  content: \"\";\n}\n\n.fa-sellsy:before {\n  content: \"\";\n}\n\n.fa-shirtsinbulk:before {\n  content: \"\";\n}\n\n.fa-simplybuilt:before {\n  content: \"\";\n}\n\n.fa-skyatlas:before {\n  content: \"\";\n}\n\n.fa-cart-plus:before {\n  content: \"\";\n}\n\n.fa-cart-arrow-down:before {\n  content: \"\";\n}\n\n.fa-diamond:before {\n  content: \"\";\n}\n\n.fa-ship:before {\n  content: \"\";\n}\n\n.fa-user-secret:before {\n  content: \"\";\n}\n\n.fa-motorcycle:before {\n  content: \"\";\n}\n\n.fa-street-view:before {\n  content: \"\";\n}\n\n.fa-heartbeat:before {\n  content: \"\";\n}\n\n.fa-venus:before {\n  content: \"\";\n}\n\n.fa-mars:before {\n  content: \"\";\n}\n\n.fa-mercury:before {\n  content: \"\";\n}\n\n.fa-intersex:before,\n.fa-transgender:before {\n  content: \"\";\n}\n\n.fa-transgender-alt:before {\n  content: \"\";\n}\n\n.fa-venus-double:before {\n  content: \"\";\n}\n\n.fa-mars-double:before {\n  content: \"\";\n}\n\n.fa-venus-mars:before {\n  content: \"\";\n}\n\n.fa-mars-stroke:before {\n  content: \"\";\n}\n\n.fa-mars-stroke-v:before {\n  content: \"\";\n}\n\n.fa-mars-stroke-h:before {\n  content: \"\";\n}\n\n.fa-neuter:before {\n  content: \"\";\n}\n\n.fa-genderless:before {\n  content: \"\";\n}\n\n.fa-facebook-official:before {\n  content: \"\";\n}\n\n.fa-pinterest-p:before {\n  content: \"\";\n}\n\n.fa-whatsapp:before {\n  content: \"\";\n}\n\n.fa-server:before {\n  content: \"\";\n}\n\n.fa-user-plus:before {\n  content: \"\";\n}\n\n.fa-user-times:before {\n  content: \"\";\n}\n\n.fa-hotel:before,\n.fa-bed:before {\n  content: \"\";\n}\n\n.fa-viacoin:before {\n  content: \"\";\n}\n\n.fa-train:before {\n  content: \"\";\n}\n\n.fa-subway:before {\n  content: \"\";\n}\n\n.fa-medium:before {\n  content: \"\";\n}\n\n.fa-yc:before,\n.fa-y-combinator:before {\n  content: \"\";\n}\n\n.fa-optin-monster:before {\n  content: \"\";\n}\n\n.fa-opencart:before {\n  content: \"\";\n}\n\n.fa-expeditedssl:before {\n  content: \"\";\n}\n\n.fa-battery-4:before,\n.fa-battery:before,\n.fa-battery-full:before {\n  content: \"\";\n}\n\n.fa-battery-3:before,\n.fa-battery-three-quarters:before {\n  content: \"\";\n}\n\n.fa-battery-2:before,\n.fa-battery-half:before {\n  content: \"\";\n}\n\n.fa-battery-1:before,\n.fa-battery-quarter:before {\n  content: \"\";\n}\n\n.fa-battery-0:before,\n.fa-battery-empty:before {\n  content: \"\";\n}\n\n.fa-mouse-pointer:before {\n  content: \"\";\n}\n\n.fa-i-cursor:before {\n  content: \"\";\n}\n\n.fa-object-group:before {\n  content: \"\";\n}\n\n.fa-object-ungroup:before {\n  content: \"\";\n}\n\n.fa-sticky-note:before {\n  content: \"\";\n}\n\n.fa-sticky-note-o:before {\n  content: \"\";\n}\n\n.fa-cc-jcb:before {\n  content: \"\";\n}\n\n.fa-cc-diners-club:before {\n  content: \"\";\n}\n\n.fa-clone:before {\n  content: \"\";\n}\n\n.fa-balance-scale:before {\n  content: \"\";\n}\n\n.fa-hourglass-o:before {\n  content: \"\";\n}\n\n.fa-hourglass-1:before,\n.fa-hourglass-start:before {\n  content: \"\";\n}\n\n.fa-hourglass-2:before,\n.fa-hourglass-half:before {\n  content: \"\";\n}\n\n.fa-hourglass-3:before,\n.fa-hourglass-end:before {\n  content: \"\";\n}\n\n.fa-hourglass:before {\n  content: \"\";\n}\n\n.fa-hand-grab-o:before,\n.fa-hand-rock-o:before {\n  content: \"\";\n}\n\n.fa-hand-stop-o:before,\n.fa-hand-paper-o:before {\n  content: \"\";\n}\n\n.fa-hand-scissors-o:before {\n  content: \"\";\n}\n\n.fa-hand-lizard-o:before {\n  content: \"\";\n}\n\n.fa-hand-spock-o:before {\n  content: \"\";\n}\n\n.fa-hand-pointer-o:before {\n  content: \"\";\n}\n\n.fa-hand-peace-o:before {\n  content: \"\";\n}\n\n.fa-trademark:before {\n  content: \"\";\n}\n\n.fa-registered:before {\n  content: \"\";\n}\n\n.fa-creative-commons:before {\n  content: \"\";\n}\n\n.fa-gg:before {\n  content: \"\";\n}\n\n.fa-gg-circle:before {\n  content: \"\";\n}\n\n.fa-tripadvisor:before {\n  content: \"\";\n}\n\n.fa-odnoklassniki:before {\n  content: \"\";\n}\n\n.fa-odnoklassniki-square:before {\n  content: \"\";\n}\n\n.fa-get-pocket:before {\n  content: \"\";\n}\n\n.fa-wikipedia-w:before {\n  content: \"\";\n}\n\n.fa-safari:before {\n  content: \"\";\n}\n\n.fa-chrome:before {\n  content: \"\";\n}\n\n.fa-firefox:before {\n  content: \"\";\n}\n\n.fa-opera:before {\n  content: \"\";\n}\n\n.fa-internet-explorer:before {\n  content: \"\";\n}\n\n.fa-tv:before,\n.fa-television:before {\n  content: \"\";\n}\n\n.fa-contao:before {\n  content: \"\";\n}\n\n.fa-500px:before {\n  content: \"\";\n}\n\n.fa-amazon:before {\n  content: \"\";\n}\n\n.fa-calendar-plus-o:before {\n  content: \"\";\n}\n\n.fa-calendar-minus-o:before {\n  content: \"\";\n}\n\n.fa-calendar-times-o:before {\n  content: \"\";\n}\n\n.fa-calendar-check-o:before {\n  content: \"\";\n}\n\n.fa-industry:before {\n  content: \"\";\n}\n\n.fa-map-pin:before {\n  content: \"\";\n}\n\n.fa-map-signs:before {\n  content: \"\";\n}\n\n.fa-map-o:before {\n  content: \"\";\n}\n\n.fa-map:before {\n  content: \"\";\n}\n\n.fa-commenting:before {\n  content: \"\";\n}\n\n.fa-commenting-o:before {\n  content: \"\";\n}\n\n.fa-houzz:before {\n  content: \"\";\n}\n\n.fa-vimeo:before {\n  content: \"\";\n}\n\n.fa-black-tie:before {\n  content: \"\";\n}\n\n.fa-fonticons:before {\n  content: \"\";\n}\n\n.fa-reddit-alien:before {\n  content: \"\";\n}\n\n.fa-edge:before {\n  content: \"\";\n}\n\n.fa-credit-card-alt:before {\n  content: \"\";\n}\n\n.fa-codiepie:before {\n  content: \"\";\n}\n\n.fa-modx:before {\n  content: \"\";\n}\n\n.fa-fort-awesome:before {\n  content: \"\";\n}\n\n.fa-usb:before {\n  content: \"\";\n}\n\n.fa-product-hunt:before {\n  content: \"\";\n}\n\n.fa-mixcloud:before {\n  content: \"\";\n}\n\n.fa-scribd:before {\n  content: \"\";\n}\n\n.fa-pause-circle:before {\n  content: \"\";\n}\n\n.fa-pause-circle-o:before {\n  content: \"\";\n}\n\n.fa-stop-circle:before {\n  content: \"\";\n}\n\n.fa-stop-circle-o:before {\n  content: \"\";\n}\n\n.fa-shopping-bag:before {\n  content: \"\";\n}\n\n.fa-shopping-basket:before {\n  content: \"\";\n}\n\n.fa-hashtag:before {\n  content: \"\";\n}\n\n.fa-bluetooth:before {\n  content: \"\";\n}\n\n.fa-bluetooth-b:before {\n  content: \"\";\n}\n\n.fa-percent:before {\n  content: \"\";\n}\n\n.fa-gitlab:before {\n  content: \"\";\n}\n\n.fa-wpbeginner:before {\n  content: \"\";\n}\n\n.fa-wpforms:before {\n  content: \"\";\n}\n\n.fa-envira:before {\n  content: \"\";\n}\n\n.fa-universal-access:before {\n  content: \"\";\n}\n\n.fa-wheelchair-alt:before {\n  content: \"\";\n}\n\n.fa-question-circle-o:before {\n  content: \"\";\n}\n\n.fa-blind:before {\n  content: \"\";\n}\n\n.fa-audio-description:before {\n  content: \"\";\n}\n\n.fa-volume-control-phone:before {\n  content: \"\";\n}\n\n.fa-braille:before {\n  content: \"\";\n}\n\n.fa-assistive-listening-systems:before {\n  content: \"\";\n}\n\n.fa-asl-interpreting:before,\n.fa-american-sign-language-interpreting:before {\n  content: \"\";\n}\n\n.fa-deafness:before,\n.fa-hard-of-hearing:before,\n.fa-deaf:before {\n  content: \"\";\n}\n\n.fa-glide:before {\n  content: \"\";\n}\n\n.fa-glide-g:before {\n  content: \"\";\n}\n\n.fa-signing:before,\n.fa-sign-language:before {\n  content: \"\";\n}\n\n.fa-low-vision:before {\n  content: \"\";\n}\n\n.fa-viadeo:before {\n  content: \"\";\n}\n\n.fa-viadeo-square:before {\n  content: \"\";\n}\n\n.fa-snapchat:before {\n  content: \"\";\n}\n\n.fa-snapchat-ghost:before {\n  content: \"\";\n}\n\n.fa-snapchat-square:before {\n  content: \"\";\n}\n\n.fa-pied-piper:before {\n  content: \"\";\n}\n\n.fa-first-order:before {\n  content: \"\";\n}\n\n.fa-yoast:before {\n  content: \"\";\n}\n\n.fa-themeisle:before {\n  content: \"\";\n}\n\n.fa-google-plus-circle:before,\n.fa-google-plus-official:before {\n  content: \"\";\n}\n\n.fa-fa:before,\n.fa-font-awesome:before {\n  content: \"\";\n}\n\n.fa-handshake-o:before {\n  content: \"\";\n}\n\n.fa-envelope-open:before {\n  content: \"\";\n}\n\n.fa-envelope-open-o:before {\n  content: \"\";\n}\n\n.fa-linode:before {\n  content: \"\";\n}\n\n.fa-address-book:before {\n  content: \"\";\n}\n\n.fa-address-book-o:before {\n  content: \"\";\n}\n\n.fa-vcard:before,\n.fa-address-card:before {\n  content: \"\";\n}\n\n.fa-vcard-o:before,\n.fa-address-card-o:before {\n  content: \"\";\n}\n\n.fa-user-circle:before {\n  content: \"\";\n}\n\n.fa-user-circle-o:before {\n  content: \"\";\n}\n\n.fa-user-o:before {\n  content: \"\";\n}\n\n.fa-id-badge:before {\n  content: \"\";\n}\n\n.fa-drivers-license:before,\n.fa-id-card:before {\n  content: \"\";\n}\n\n.fa-drivers-license-o:before,\n.fa-id-card-o:before {\n  content: \"\";\n}\n\n.fa-quora:before {\n  content: \"\";\n}\n\n.fa-free-code-camp:before {\n  content: \"\";\n}\n\n.fa-telegram:before {\n  content: \"\";\n}\n\n.fa-thermometer-4:before,\n.fa-thermometer:before,\n.fa-thermometer-full:before {\n  content: \"\";\n}\n\n.fa-thermometer-3:before,\n.fa-thermometer-three-quarters:before {\n  content: \"\";\n}\n\n.fa-thermometer-2:before,\n.fa-thermometer-half:before {\n  content: \"\";\n}\n\n.fa-thermometer-1:before,\n.fa-thermometer-quarter:before {\n  content: \"\";\n}\n\n.fa-thermometer-0:before,\n.fa-thermometer-empty:before {\n  content: \"\";\n}\n\n.fa-shower:before {\n  content: \"\";\n}\n\n.fa-bathtub:before,\n.fa-s15:before,\n.fa-bath:before {\n  content: \"\";\n}\n\n.fa-podcast:before {\n  content: \"\";\n}\n\n.fa-window-maximize:before {\n  content: \"\";\n}\n\n.fa-window-minimize:before {\n  content: \"\";\n}\n\n.fa-window-restore:before {\n  content: \"\";\n}\n\n.fa-times-rectangle:before,\n.fa-window-close:before {\n  content: \"\";\n}\n\n.fa-times-rectangle-o:before,\n.fa-window-close-o:before {\n  content: \"\";\n}\n\n.fa-bandcamp:before {\n  content: \"\";\n}\n\n.fa-grav:before {\n  content: \"\";\n}\n\n.fa-etsy:before {\n  content: \"\";\n}\n\n.fa-imdb:before {\n  content: \"\";\n}\n\n.fa-ravelry:before {\n  content: \"\";\n}\n\n.fa-eercast:before {\n  content: \"\";\n}\n\n.fa-microchip:before {\n  content: \"\";\n}\n\n.fa-snowflake-o:before {\n  content: \"\";\n}\n\n.fa-superpowers:before {\n  content: \"\";\n}\n\n.fa-wpexplorer:before {\n  content: \"\";\n}\n\n.fa-meetup:before {\n  content: \"\";\n}\n\n.sr-only {\n  position: absolute;\n  width: 1px;\n  height: 1px;\n  padding: 0;\n  margin: -1px;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  border: 0;\n}\n\n.sr-only-focusable:active,\n.sr-only-focusable:focus {\n  position: static;\n  width: auto;\n  height: auto;\n  margin: 0;\n  overflow: visible;\n  clip: auto;\n}\n\nhtml, body {\n  font-size: 9pt;\n  margin: 0px;\n  font-family: \"Roboto\";\n  height: 100%;\n  overflow: hidden;\n  user-select: none;\n  cursor: default;\n}\n\n#main {\n  display: grid;\n  grid-template-columns: auto auto auto;\n  grid-template-rows: 45px auto;\n  height: 100%;\n}\n#main .control-button {\n  height: 44px;\n  width: 44px;\n  font-size: 15pt;\n  background-color: white;\n  position: relative;\n}\n#main .control-button:hover {\n  filter: brightness(90%);\n}\n#main .control-button.frozen {\n  background-color: transparent;\n}\n#main .control-button.frozen:hover {\n  background-color: rgba(255, 0, 0, 0.1);\n}\n#main .control-button > * {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  margin: auto;\n  color: black;\n  cursor: default;\n  stroke-width: 2px;\n}\n#main .stretch {\n  flex-grow: 1;\n}\n#main > .menu-header {\n  grid-row: 1;\n  grid-column: 1;\n  border-bottom: 1px solid #bdbdbd;\n  border-right: 1px solid #bdbdbd;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n}\n#main > .menu-header > .title {\n  margin-left: 10px;\n  font-size: 13pt;\n}\n#main > .menu {\n  grid-column: 1;\n  grid-row: 2;\n  height: 100%;\n  display: flex;\n  flex-direction: column;\n  border-right: 1px solid #9e9e9e;\n}\n#main > .menu > .group {\n  display: flex;\n  flex-direction: column;\n}\n#main > .menu > .group > .title {\n  font-size: 10pt;\n  font-weight: 700;\n  margin: 5px auto 0px 5px;\n}\n#main > .menu > .group > .column-options {\n  display: flex;\n  flex-direction: column;\n  margin: 0px 5px;\n}\n#main > .menu > .group > .column-options > .item {\n  display: flex;\n  align-items: center;\n  border-radius: 5px;\n  border: 1px solid white;\n  margin: 3px;\n}\n#main > .menu > .group > .column-options > .item.dropzone {\n  background-color: #c7dbe7;\n  border: 1px dashed yellow;\n}\n#main > .menu > .group > .column-options > .item.not-visible-has-filter {\n  background-color: rgba(255, 165, 0, 0.2);\n}\n#main > .menu > .group > .reset-button {\n  margin-top: 10px;\n  align-self: center;\n}\n#main > .header {\n  grid-column: 2/span 2;\n  grid-row: 1;\n  display: flex;\n  border-bottom: 1px solid #bdbdbd;\n  z-index: 1;\n}\n#main > .header.frozen {\n  background-color: rgba(255, 0, 0, 0.1);\n}\n#main > .header > .datetime-pickers {\n  padding-top: 2px;\n  margin-left: 12px;\n  display: flex;\n  flex-direction: column;\n  font-size: 10pt;\n}\n#main > .header > .datetime-pickers > .title {\n  font-weight: 600;\n  margin-bottom: 4px;\n}\n#main > .header > .datetime-pickers > .timestamps {\n  align-items: center;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter {\n  position: relative;\n  margin-left: 5px;\n  margin-right: 10px;\n  width: 205px;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter input {\n  width: 185px;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .calendar {\n  margin-left: 3px;\n  outline: none;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .calendar.active {\n  color: #457B9D;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .calendar.active:hover {\n  color: #355f7a;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .clear {\n  margin-left: 3px;\n  position: absolute;\n  right: 20px;\n  top: 50%;\n  transform: translate(0, -50%);\n  visibility: hidden;\n  color: #757575;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .clear:hover {\n  color: #424242;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter:hover > .clear {\n  visibility: visible;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker {\n  box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), 0 2px 4px -1px rgba(0, 0, 0, 0.2);\n  position: absolute;\n  display: flex;\n  flex-direction: column;\n  background: #eeeeee;\n  padding: 3px;\n  border-radius: 0 0 3px 3px;\n  outline: none;\n  animation: fade-in 0.3s;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header {\n  display: flex;\n  align-items: center;\n  padding-bottom: 3px;\n  margin-bottom: 6px;\n  border-bottom: 1px solid #bdbdbd;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > .spacer {\n  flex-grow: 1;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > .tab {\n  font-size: 11pt;\n  color: #757575;\n  width: 25px;\n  height: 22px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > .tab:hover {\n  color: #616161;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > .tab.active {\n  color: #457B9D;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > .tab.active:hover {\n  color: #355f7a;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .header > button {\n  margin-left: 4px;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .main {\n  display: flex;\n}\n#main > .header > .datetime-pickers > .timestamps > .timestamp-filter > .timestamp-picker > .main .date-picker {\n  font-size: 8pt;\n  width: 200px;\n  height: 200px;\n  box-sizing: border-box;\n}\n#main > .header > .filters {\n  padding-top: 2px;\n  display: flex;\n  flex-wrap: wrap;\n  height: fit-content;\n  align-items: baseline;\n}\n#main > .header > .filters > .title {\n  font-weight: 600;\n  font-size: 10pt;\n  margin-right: 5px;\n}\n#main > .header > .filters > .chip {\n  border-radius: 3px;\n  height: fit-content;\n  padding: 2px 5px;\n  margin-right: 3px;\n  margin-bottom: 2px;\n  display: flex;\n  align-items: center;\n}\n#main > .header > .filters > .filter-item {\n  background-color: #a4c3d7;\n}\n#main > .header > .filters > .filter-item > .value {\n  margin-right: 5px;\n  color: black;\n}\n#main > .header > .filters > .filter-item > .icon {\n  cursor: pointer;\n  stroke-width: 1.1px;\n}\n#main > .header > .filters > .clear-all {\n  background-color: #ff9999;\n  cursor: pointer;\n}\n#main > .header > .filters > .clear-all:hover {\n  background-color: #ff6666;\n}\n#main > .header > .navigation {\n  width: 380px;\n  display: flex;\n  align-items: center;\n  justify-content: flex-end;\n}\n#main > .header > .navigation > .labeled-controls {\n  display: flex;\n  align-items: baseline;\n  flex-grow: 1;\n  justify-content: space-around;\n}\n#main > .header > .navigation > .labeled-controls > .freeze-toggle > input {\n  position: relative;\n  top: 2px;\n  margin-right: 5px;\n}\n#main > .header > .navigation > .labeled-controls > .size-select > select {\n  margin-left: 5px;\n}\n#main > .header > .navigation > .labeled-controls > .page-counter {\n  visibility: hidden;\n}\n#main > .header > .navigation > .labeled-controls > .page-counter.frozen {\n  visibility: visible;\n}\n#main > .header > .navigation > .buttons {\n  display: flex;\n  margin-right: 10px;\n}\n#main > .header > .navigation > .buttons > .navigation-button {\n  height: 35px;\n  width: 30px;\n  border: 1px solid #e0e0e0;\n  border-radius: 7px;\n  background-color: whitesmoke;\n  margin-right: 2px;\n  font-size: 12pt;\n  position: relative;\n}\n#main > .header > .navigation > .buttons > .navigation-button:hover {\n  background-color: #eeeeee;\n}\n#main > .header > .navigation > .buttons > .navigation-button:active {\n  background-color: #e0e0e0;\n}\n#main > .header > .navigation > .buttons > .navigation-button > * {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#main > .header > .navigation > .buttons > .navigation-button.disabled {\n  color: #9e9e9e;\n  cursor: default;\n}\n#main > .header > .navigation > .buttons > .navigation-button.disabled:hover {\n  background-color: whitesmoke;\n}\n#main > .table {\n  grid-column: 2;\n  grid-row: 2;\n  overflow-x: auto;\n  overflow-y: auto;\n}\n#main > .table > table {\n  width: 100%;\n  table-layout: fixed;\n  border-collapse: collapse;\n  user-select: text;\n  position: relative;\n}\n#main > .table > table th {\n  position: sticky;\n  top: 0;\n  background-color: #355f7a;\n  color: white;\n  height: 34px;\n  z-index: 1;\n}\n#main > .table > table th > .column-header {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  text-align: start;\n  padding: 0px 3px;\n  text-overflow: ellipsis;\n  height: 100%;\n  border: 1px solid #355f7a;\n}\n#main > .table > table th > .column-header.dropzone {\n  border: 1px dashed yellow;\n}\n#main > .table > table th > .column-header > .label-container {\n  flex-grow: 1;\n  display: flex;\n  align-items: center;\n}\n#main > .table > table th > .column-header > input {\n  width: calc(100% - 4px);\n}\n#main > .table > table th > .column-header > select {\n  width: 100%;\n}\n#main > .table > table td {\n  height: 20px;\n  border-top: 1px solid #9e9e9e;\n  border-bottom: 1px solid #9e9e9e;\n  text-align: center;\n  overflow: hidden;\n  text-overflow: ellipsis;\n}\n#main > .table > table td.text-noncentered, #main > .table > table td.json {\n  text-align: start;\n  padding: 0px 5px;\n  overflow: hidden;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n#main > .table > table td.json {\n  font-family: monospace;\n  font-size: 8pt;\n}\n#main > .table > table td.timestamp {\n  position: relative;\n}\n#main > .table > table td.timestamp > .cell-icons {\n  position: absolute;\n  right: 0px;\n  top: 50%;\n  transform: translate(0, -42%);\n  visibility: hidden;\n  padding: 0px 2px;\n  display: flex;\n  width: 26px;\n  justify-content: space-between;\n}\n#main > .table > table td.timestamp > .cell-icons > .icon {\n  width: 13px;\n  stroke-width: 2;\n  stroke: #757575;\n}\n#main > .table > table td.timestamp > .cell-icons > .icon:hover {\n  stroke: #424242;\n}\n#main > .table > table td.timestamp:hover > .cell-icons {\n  visibility: visible;\n}\n#main > .table > table .border {\n  width: 10px;\n  padding: 0px;\n}\n#main > .table > table .border > .line {\n  height: 100%;\n  width: 1px;\n  background-color: #eeeeee;\n  margin: 0 auto;\n}\n#main > .table > table .border.hover {\n  cursor: ew-resize;\n}\n#main > .table > table .border.hover > .line {\n  background-color: #bdbdbd;\n}\n#main > .table > table .border:last-child {\n  display: none;\n}\n#main > .details {\n  grid-column: 3;\n  grid-row: 2;\n  display: flex;\n  user-select: text;\n  overflow-y: hidden;\n}\n#main > .details > .border {\n  flex-shrink: 0;\n  width: 10px;\n  height: 100%;\n  border-left: 1px solid #bdbdbd;\n  cursor: ew-resize;\n}\n#main > .details > .border:hover {\n  border-left: 1px solid #757575;\n}\n#main > .details > .entry-data {\n  display: flex;\n  flex-direction: column;\n  width: 100%;\n}\n#main > .details > .entry-data > .header {\n  display: flex;\n  height: 45px;\n  align-items: start;\n}\n#main > .details > .entry-data > .header > .title {\n  margin-left: 5px;\n  margin-top: 10px;\n  font-size: 13pt;\n  user-select: none;\n}\n#main > .details > .entry-data > .content {\n  flex-grow: 1;\n  display: flex;\n  flex-direction: column;\n  overflow-y: auto;\n  margin-right: 5px;\n  padding-bottom: 10px;\n}\n#main > .details > .entry-data > .content > .key-value-pairs {\n  display: grid;\n  grid-template-columns: auto 1fr;\n  grid-gap: 5px 10px;\n  align-items: center;\n}\n#main > .details > .entry-data > .content > .key-value-pairs > .key {\n  grid-column: 1;\n  color: #616161;\n}\n#main > .details > .entry-data > .content > .key-value-pairs > .value {\n  grid-column: 2;\n  white-space: pre-wrap;\n  overflow: hidden;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n#main > .details > .entry-data > .content > .label-row {\n  font-size: 10pt;\n  color: #616161;\n}\n#main > .details > .entry-data > .content > .text {\n  padding: 3px;\n  white-space: pre-wrap;\n  margin: 5px 0px;\n  line-height: 16px;\n}\n#main > .details > .entry-data > .content > pre {\n  font-size: 8.5pt;\n}\n#main > .details > .entry-data > .content > .collapsible {\n  cursor: pointer;\n  font-size: 10pt;\n  margin-top: 5px;\n  display: flex;\n  user-select: none;\n}\n#main > .details > .entry-data > .content > .collapsible > .icon {\n  width: 10px;\n  margin-right: 3px;\n  text-align: center;\n}\n#main > .details > .entry-data > .content > .collapsible > .title {\n  color: #616161;\n}\n#main > .mouseevent-overlay {\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  z-index: 2;\n}\n#main > .snackbars {\n  z-index: 2;\n  position: absolute;\n  left: 50%;\n  transform: translate(-50%);\n  height: 100%;\n  bottom: 30px;\n  display: flex;\n  flex-direction: column-reverse;\n}\n#main > .snackbars > .snackbar {\n  margin-top: 3px;\n  padding: 5px;\n  border-radius: 5px;\n  background-color: #a4c3d7;\n  animation: fade-in 0.1s;\n}\n@keyframes fade-in {\n  0% {\n    opacity: 0;\n  }\n  100% {\n    opacity: 1;\n  }\n}", "",{"version":3,"sources":["webpack://./src_scss/main.scss","webpack://./src_scss/_datetimepicker.scss","webpack://./src_scss/_color.scss","webpack://./src_scss/fonts/_font.scss","webpack://./src_scss/fonts/roboto.scss","webpack://./src_scss/fonts/robotomono.scss","webpack://./src_scss/fonts/fontawesome.scss","webpack://./src_scss/_shadow.scss"],"names":[],"mappings":"AAAA,gBAAgB;ACIhB;EACI,aAAA;EACA,sBAAA;EACA,eAAA;EACA,iBAAA;ADFJ;ACKI;EACI,oBAAA;EACA,iBAAA;EACA,yBAAA;ADHR;ACMI;EACI,mBAAA;ADJR;ACSQ;EACI,yBCpBK;AFajB;ACUQ;EACI,yBAAA;ADRZ;ACWQ;EACI,YAAA;EACA,aAAA;EACA,gBAAA;EACA,gCAAA;ADTZ;ACWY;EACI,YAAA;EACA,oBAAA;EACA,8BAAA;ADThB;ACWgB;EACI,eAAA;EACA,YAAA;ADTpB;ACYgB;EACI,+BAAA;EACA,kBAAA;ADVpB;ACagB;EACI,oBAAA;EACA,uBAAA;EACA,mBAAA;EACA,YAAA;ADXpB;ACaoB;EACI,YAAA;ADXxB;ACcoB;EACI,cCzDP;AF6CjB;ACcwB;EACI,cCxDX;AF4CjB;ACoBI;EACI,YAAA;ADlBR;ACoBQ;EACI,aAAA;EACA,qCAAA;EACA,qCAAA;EACA,YAAA;ADlBZ;ACoBY;EACI,aAAA;EACA,mBAAA;EACA,uBAAA;ADlBhB;ACoBgB;EACI,oBAAA;EACA,kBAAA;EACA,aAAA;EACA,mBAAA;EACA,uBAAA;EACA,gBAAA;EACA,cCzFH;AFuEjB;ACoBoB;EACI,gCAAA;ADlBxB;ACqBoB;EACI,6BAAA;ADnBxB;ACsBoB;EACI,cChGP;AF4EjB;ACwBgB;EACI,yBC5GH;AFsFjB;AC4BI;EACI,YAAA;AD1BR;AC4BQ;EACI,aAAA;EACA,qCAAA;EACA,YAAA;AD1BZ;AC4BY;EACI,aAAA;EACA,mBAAA;EACA,uBAAA;AD1BhB;AC4BgB;EACI,yBChIH;AFsGjB;ACgCI;EACI,YAAA;EACA,aAAA;EACA,sBAAA;AD9BR;ACgCQ;EACI,aAAA;EACA,YAAA;EACA,qCAAA;EACA,kCAAA;AD9BZ;ACgCY;EACI,aAAA;EACA,mBAAA;EACA,uBAAA;EACA,sBAAA;AD9BhB;ACgCgB;EACI,cC/IR;AFiHZ;ACkCY;EACI,gBAAA;ADhChB;ACqCgB;EACI,yBCnKH;AFgIjB;AC+CgB;EACI,eAAA;EACA,iBAAA;EACA,0BAAA;EACA,mBAAA;AD7CpB;AC+CoB;EACI,eAAA;AD7CxB;ACkDY;EACI,eCvLC;AFuIjB;ACmDY;EACI,eC3LC;AF0IjB;ACoDY;EACI,eCnMC;AFiJjB;ACqDY;EACI,eCtMC;AFmJjB;ACsDY;EACI,eCvMC;AFmJjB;ACuDY;EACI,eC9MC;AFyJjB;AC0DgB;EACI,iBAAA;ADxDpB;AC6DoB;EACI,aC5NP;AFiKjB;ACiEoB;EACI,aClOP;AFmKjB;ACoEY;EACI,iBAAA;ADlEhB;ACqEY;EACI,aCpOJ;AFiKZ;ACsEY;EACI,eCvOD;EDwOC,iBAAA;ADpEhB;ACuEY;EACI,aCjPC;AF4KjB;AC0EgB;EACI,eCvPH;AF+KjB;AC2EgB;EACI,aC1PH;AFiLjB;AC8EoB;EACI,aCtQP;AF0LjB;;AG3LI;EACI,qBAAA;EACA,2DAAA;EACA,gBCFyB;EDGzB,kBCH8B;AJiMtC;AGlMI;EACI,qBAAA;EACA,iEAAA;EACA,gBCD+B;EDE/B,kBCFoC;AJsM5C;AGxMI;EACI,qBAAA;EACA,0DAAA;EACA,gBAAA;EACA,kBCD6B;AJ2MrC;AG9MI;EACI,qBAAA;EACA,gEAAA;EACA,gBCC8B;EDA9B,kBAAA;AHgNR;AGpNI;EACI,qBAAA;EACA,4DAAA;EACA,gBCE0B;EDD1B,kBCC+B;AJqNvC;AG1NI;EACI,qBAAA;EACA,kEAAA;EACA,gBCGgC;EDFhC,kBCEqC;AJ0N7C;AGhOI;EACI,qBAAA;EACA,6DAAA;EACA,gBCI2B;EDH3B,kBCGgC;AJ+NxC;AGtOI;EACI,qBAAA;EACA,mEAAA;EACA,gBCKiC;EDJjC,kBCIsC;AJoO9C;AG5OI;EACI,qBAAA;EACA,2DAAA;EACA,gBCMyB;EDLzB,kBCK8B;AJyOtC;AGlPI;EACI,qBAAA;EACA,iEAAA;EACA,gBCO+B;EDN/B,kBCMoC;AJ8O5C;AGxPI;EACI,qBAAA;EACA,0DAAA;EACA,gBCQwB;EDPxB,kBCO6B;AJmPrC;AG9PI;EACI,qBAAA;EACA,gEAAA;EACA,gBCS8B;EDR9B,kBCQmC;AJwP3C;AGpQI;EACI,yBAAA;EACA,kEAAA;EACA,gBEF4B;EFG5B,kBEHiC;ALyQzC;AG1QI;EACI,yBAAA;EACA,wEAAA;EACA,gBEDkC;EFElC,kBEFuC;AL8Q/C;AGhRI;EACI,yBAAA;EACA,oEAAA;EACA,gBAAA;EACA,kBEDmC;ALmR3C;AGtRI;EACI,yBAAA;EACA,0EAAA;EACA,gBECoC;EFApC,kBAAA;AHwRR;AG5RI;EACI,yBAAA;EACA,qEAAA;EACA,gBEE+B;EFD/B,kBECoC;AL6R5C;AGlSI;EACI,yBAAA;EACA,2EAAA;EACA,gBEGqC;EFFrC,kBEE0C;ALkSlD;AGxSI;EACI,yBAAA;EACA,mEAAA;EACA,gBEI6B;EFH7B,kBEGkC;ALuS1C;AG9SI;EACI,yBAAA;EACA,yEAAA;EACA,gBEKmC;EFJnC,kBEIwC;AL4ShD;AGpTI;EACI,yBAAA;EACA,kEAAA;EACA,gBEM4B;EFL5B,kBEKiC;ALiTzC;AG1TI;EACI,yBAAA;EACA,wEAAA;EACA,gBEOkC;EFNlC,kBEMuC;ALsT/C;AGhUI;EACI,0BAAA;EACA,uEAAA;EACA,mBGFgC;EHGhC,kBGHwC;ANqUhD;AMnUA;EACE,qBAAA;EACA,6CAAA;EACA,kBAAA;EACA,oBAAA;EACA,mCAAA;EACA,kCAAA;ANqUF;;AMnUA,6DAAA;AACA;EACE,uBAAA;EACA,mBAAA;EACA,oBAAA;ANsUF;;AMpUA;EACE,cAAA;ANuUF;;AMrUA;EACE,cAAA;ANwUF;;AMtUA;EACE,cAAA;ANyUF;;AMvUA;EACE,cAAA;AN0UF;;AMxUA;EACE,mBAAA;EACA,kBAAA;AN2UF;;AMzUA;EACE,eAAA;EACA,yBAAA;EACA,qBAAA;AN4UF;;AM1UA;EACE,kBAAA;AN6UF;;AM3UA;EACE,kBAAA;EACA,mBAAA;EACA,mBAAA;EACA,iBAAA;EACA,kBAAA;AN8UF;;AM5UA;EACE,mBAAA;AN+UF;;AM7UA;EACE,4BAAA;EACA,4BAAA;EACA,oBAAA;ANgVF;;AM9UA;EACE,WAAA;ANiVF;;AM/UA;EACE,YAAA;ANkVF;;AMhVA;EACE,mBAAA;ANmVF;;AMjVA;EACE,kBAAA;ANoVF;;AMlVA,2BAAA;AACA;EACE,YAAA;ANqVF;;AMnVA;EACE,WAAA;ANsVF;;AMpVA;EACE,mBAAA;ANuVF;;AMrVA;EACE,kBAAA;ANwVF;;AMtVA;EACE,6CAAA;EACA,qCAAA;ANyVF;;AMvVA;EACE,+CAAA;EACA,uCAAA;AN0VF;;AMxVA;EACE;IACE,+BAAA;IACA,uBAAA;EN2VF;EMzVA;IACE,iCAAA;IACA,yBAAA;EN2VF;AACF;AMzVA;EACE;IACE,+BAAA;IACA,uBAAA;EN2VF;EMzVA;IACE,iCAAA;IACA,yBAAA;EN2VF;AACF;AMzVA;EACE,sEAAA;EACA,gCAAA;EACA,4BAAA;EACA,wBAAA;AN2VF;;AMzVA;EACE,sEAAA;EACA,iCAAA;EACA,6BAAA;EACA,yBAAA;AN4VF;;AM1VA;EACE,sEAAA;EACA,iCAAA;EACA,6BAAA;EACA,yBAAA;AN6VF;;AM3VA;EACE,gFAAA;EACA,+BAAA;EACA,2BAAA;EACA,uBAAA;AN8VF;;AM5VA;EACE,gFAAA;EACA,+BAAA;EACA,2BAAA;EACA,uBAAA;AN+VF;;AM7VA;;;;;EAKE,YAAA;ANgWF;;AM9VA;EACE,kBAAA;EACA,qBAAA;EACA,UAAA;EACA,WAAA;EACA,gBAAA;EACA,sBAAA;ANiWF;;AM/VA;;EAEE,kBAAA;EACA,OAAA;EACA,WAAA;EACA,kBAAA;ANkWF;;AMhWA;EACE,oBAAA;ANmWF;;AMjWA;EACE,cAAA;ANoWF;;AMlWA;EACE,cAAA;ANqWF;;AMnWA;mEAAA;AAEA;EACE,YAAA;ANsWF;;AMpWA;EACE,YAAA;ANuWF;;AMrWA;EACE,YAAA;ANwWF;;AMtWA;EACE,YAAA;ANyWF;;AMvWA;EACE,YAAA;AN0WF;;AMxWA;EACE,YAAA;AN2WF;;AMzWA;EACE,YAAA;AN4WF;;AM1WA;EACE,YAAA;AN6WF;;AM3WA;EACE,YAAA;AN8WF;;AM5WA;EACE,YAAA;AN+WF;;AM7WA;EACE,YAAA;ANgXF;;AM9WA;EACE,YAAA;ANiXF;;AM/WA;EACE,YAAA;ANkXF;;AMhXA;;;EAGE,YAAA;ANmXF;;AMjXA;EACE,YAAA;ANoXF;;AMlXA;EACE,YAAA;ANqXF;;AMnXA;EACE,YAAA;ANsXF;;AMpXA;EACE,YAAA;ANuXF;;AMrXA;;EAEE,YAAA;ANwXF;;AMtXA;EACE,YAAA;ANyXF;;AMvXA;EACE,YAAA;AN0XF;;AMxXA;EACE,YAAA;AN2XF;;AMzXA;EACE,YAAA;AN4XF;;AM1XA;EACE,YAAA;AN6XF;;AM3XA;EACE,YAAA;AN8XF;;AM5XA;EACE,YAAA;AN+XF;;AM7XA;EACE,YAAA;ANgYF;;AM9XA;EACE,YAAA;ANiYF;;AM/XA;EACE,YAAA;ANkYF;;AMhYA;;EAEE,YAAA;ANmYF;;AMjYA;EACE,YAAA;ANoYF;;AMlYA;EACE,YAAA;ANqYF;;AMnYA;EACE,YAAA;ANsYF;;AMpYA;EACE,YAAA;ANuYF;;AMrYA;EACE,YAAA;ANwYF;;AMtYA;EACE,YAAA;ANyYF;;AMvYA;EACE,YAAA;AN0YF;;AMxYA;EACE,YAAA;AN2YF;;AMzYA;EACE,YAAA;AN4YF;;AM1YA;EACE,YAAA;AN6YF;;AM3YA;EACE,YAAA;AN8YF;;AM5YA;EACE,YAAA;AN+YF;;AM7YA;EACE,YAAA;ANgZF;;AM9YA;EACE,YAAA;ANiZF;;AM/YA;EACE,YAAA;ANkZF;;AMhZA;EACE,YAAA;ANmZF;;AMjZA;EACE,YAAA;ANoZF;;AMlZA;EACE,YAAA;ANqZF;;AMnZA;EACE,YAAA;ANsZF;;AMpZA;EACE,YAAA;ANuZF;;AMrZA;EACE,YAAA;ANwZF;;AMtZA;EACE,YAAA;ANyZF;;AMvZA;EACE,YAAA;AN0ZF;;AMxZA;EACE,YAAA;AN2ZF;;AMzZA;EACE,YAAA;AN4ZF;;AM1ZA;EACE,YAAA;AN6ZF;;AM3ZA;;EAEE,YAAA;AN8ZF;;AM5ZA;EACE,YAAA;AN+ZF;;AM7ZA;EACE,YAAA;ANgaF;;AM9ZA;;;EAGE,YAAA;ANiaF;;AM/ZA;EACE,YAAA;ANkaF;;AMhaA;EACE,YAAA;ANmaF;;AMjaA;EACE,YAAA;ANoaF;;AMlaA;EACE,YAAA;ANqaF;;AMnaA;;EAEE,YAAA;ANsaF;;AMpaA;EACE,YAAA;ANuaF;;AMraA;EACE,YAAA;ANwaF;;AMtaA;EACE,YAAA;ANyaF;;AMvaA;EACE,YAAA;AN0aF;;AMxaA;EACE,YAAA;AN2aF;;AMzaA;EACE,YAAA;AN4aF;;AM1aA;EACE,YAAA;AN6aF;;AM3aA;EACE,YAAA;AN8aF;;AM5aA;EACE,YAAA;AN+aF;;AM7aA;EACE,YAAA;ANgbF;;AM9aA;EACE,YAAA;ANibF;;AM/aA;EACE,YAAA;ANkbF;;AMhbA;EACE,YAAA;ANmbF;;AMjbA;EACE,YAAA;ANobF;;AMlbA;EACE,YAAA;ANqbF;;AMnbA;EACE,YAAA;ANsbF;;AMpbA;EACE,YAAA;ANubF;;AMrbA;EACE,YAAA;ANwbF;;AMtbA;EACE,YAAA;ANybF;;AMvbA;EACE,YAAA;AN0bF;;AMxbA;EACE,YAAA;AN2bF;;AMzbA;EACE,YAAA;AN4bF;;AM1bA;EACE,YAAA;AN6bF;;AM3bA;EACE,YAAA;AN8bF;;AM5bA;EACE,YAAA;AN+bF;;AM7bA;EACE,YAAA;ANgcF;;AM9bA;EACE,YAAA;ANicF;;AM/bA;EACE,YAAA;ANkcF;;AMhcA;EACE,YAAA;ANmcF;;AMjcA;;EAEE,YAAA;ANocF;;AMlcA;EACE,YAAA;ANqcF;;AMncA;EACE,YAAA;ANscF;;AMpcA;EACE,YAAA;ANucF;;AMrcA;EACE,YAAA;ANwcF;;AMtcA;EACE,YAAA;ANycF;;AMvcA;EACE,YAAA;AN0cF;;AMxcA;EACE,YAAA;AN2cF;;AMzcA;EACE,YAAA;AN4cF;;AM1cA;EACE,YAAA;AN6cF;;AM3cA;EACE,YAAA;AN8cF;;AM5cA;EACE,YAAA;AN+cF;;AM7cA;;EAEE,YAAA;ANgdF;;AM9cA;EACE,YAAA;ANidF;;AM/cA;EACE,YAAA;ANkdF;;AMhdA;EACE,YAAA;ANmdF;;AMjdA;EACE,YAAA;ANodF;;AMldA;EACE,YAAA;ANqdF;;AMndA;EACE,YAAA;ANsdF;;AMpdA;EACE,YAAA;ANudF;;AMrdA;EACE,YAAA;ANwdF;;AMtdA;EACE,YAAA;ANydF;;AMvdA;EACE,YAAA;AN0dF;;AMxdA;EACE,YAAA;AN2dF;;AMzdA;EACE,YAAA;AN4dF;;AM1dA;EACE,YAAA;AN6dF;;AM3dA;;EAEE,YAAA;AN8dF;;AM5dA;EACE,YAAA;AN+dF;;AM7dA;EACE,YAAA;ANgeF;;AM9dA;EACE,YAAA;ANieF;;AM/dA;EACE,YAAA;ANkeF;;AMheA;;EAEE,YAAA;ANmeF;;AMjeA;EACE,YAAA;ANoeF;;AMleA;EACE,YAAA;ANqeF;;AMneA;EACE,YAAA;ANseF;;AMpeA;EACE,YAAA;ANueF;;AMreA;EACE,YAAA;ANweF;;AMteA;EACE,YAAA;ANyeF;;AMveA;EACE,YAAA;AN0eF;;AMxeA;EACE,YAAA;AN2eF;;AMzeA;EACE,YAAA;AN4eF;;AM1eA;EACE,YAAA;AN6eF;;AM3eA;EACE,YAAA;AN8eF;;AM5eA;EACE,YAAA;AN+eF;;AM7eA;EACE,YAAA;ANgfF;;AM9eA;EACE,YAAA;ANifF;;AM/eA;EACE,YAAA;ANkfF;;AMhfA;EACE,YAAA;ANmfF;;AMjfA;EACE,YAAA;ANofF;;AMlfA;EACE,YAAA;ANqfF;;AMnfA;EACE,YAAA;ANsfF;;AMpfA;;EAEE,YAAA;ANufF;;AMrfA;EACE,YAAA;ANwfF;;AMtfA;EACE,YAAA;ANyfF;;AMvfA;EACE,YAAA;AN0fF;;AMxfA;;EAEE,YAAA;AN2fF;;AMzfA;EACE,YAAA;AN4fF;;AM1fA;EACE,YAAA;AN6fF;;AM3fA;EACE,YAAA;AN8fF;;AM5fA;EACE,YAAA;AN+fF;;AM7fA;EACE,YAAA;ANggBF;;AM9fA;EACE,YAAA;ANigBF;;AM/fA;EACE,YAAA;ANkgBF;;AMhgBA;EACE,YAAA;ANmgBF;;AMjgBA;EACE,YAAA;ANogBF;;AMlgBA;EACE,YAAA;ANqgBF;;AMngBA;EACE,YAAA;ANsgBF;;AMpgBA;EACE,YAAA;ANugBF;;AMrgBA;EACE,YAAA;ANwgBF;;AMtgBA;EACE,YAAA;ANygBF;;AMvgBA;EACE,YAAA;AN0gBF;;AMxgBA;EACE,YAAA;AN2gBF;;AMzgBA;EACE,YAAA;AN4gBF;;AM1gBA;EACE,YAAA;AN6gBF;;AM3gBA;;EAEE,YAAA;AN8gBF;;AM5gBA;;EAEE,YAAA;AN+gBF;;AM7gBA;EACE,YAAA;ANghBF;;AM9gBA;EACE,YAAA;ANihBF;;AM/gBA;;EAEE,YAAA;ANkhBF;;AMhhBA;;EAEE,YAAA;ANmhBF;;AMjhBA;EACE,YAAA;ANohBF;;AMlhBA;;EAEE,YAAA;ANqhBF;;AMnhBA;EACE,YAAA;ANshBF;;AMphBA;;;EAGE,YAAA;ANuhBF;;AMrhBA;EACE,YAAA;ANwhBF;;AMthBA;EACE,YAAA;ANyhBF;;AMvhBA;EACE,YAAA;AN0hBF;;AMxhBA;EACE,YAAA;AN2hBF;;AMzhBA;EACE,YAAA;AN4hBF;;AM1hBA;EACE,YAAA;AN6hBF;;AM3hBA;EACE,YAAA;AN8hBF;;AM5hBA;EACE,YAAA;AN+hBF;;AM7hBA;EACE,YAAA;ANgiBF;;AM9hBA;EACE,YAAA;ANiiBF;;AM/hBA;EACE,YAAA;ANkiBF;;AMhiBA;EACE,YAAA;ANmiBF;;AMjiBA;EACE,YAAA;ANoiBF;;AMliBA;EACE,YAAA;ANqiBF;;AMniBA;EACE,YAAA;ANsiBF;;AMpiBA;EACE,YAAA;ANuiBF;;AMriBA;EACE,YAAA;ANwiBF;;AMtiBA;;EAEE,YAAA;ANyiBF;;AMviBA;;EAEE,YAAA;AN0iBF;;AMxiBA;;EAEE,YAAA;AN2iBF;;AMziBA;EACE,YAAA;AN4iBF;;AM1iBA;EACE,YAAA;AN6iBF;;AM3iBA;;EAEE,YAAA;AN8iBF;;AM5iBA;;EAEE,YAAA;AN+iBF;;AM7iBA;;EAEE,YAAA;ANgjBF;;AM9iBA;EACE,YAAA;ANijBF;;AM/iBA;EACE,YAAA;ANkjBF;;AMhjBA;;EAEE,YAAA;ANmjBF;;AMjjBA;EACE,YAAA;ANojBF;;AMljBA;EACE,YAAA;ANqjBF;;AMnjBA;;EAEE,YAAA;ANsjBF;;AMpjBA;EACE,YAAA;ANujBF;;AMrjBA;EACE,YAAA;ANwjBF;;AMtjBA;EACE,YAAA;ANyjBF;;AMvjBA;EACE,YAAA;AN0jBF;;AMxjBA;EACE,YAAA;AN2jBF;;AMzjBA;EACE,YAAA;AN4jBF;;AM1jBA;EACE,YAAA;AN6jBF;;AM3jBA;EACE,YAAA;AN8jBF;;AM5jBA;EACE,YAAA;AN+jBF;;AM7jBA;EACE,YAAA;ANgkBF;;AM9jBA;EACE,YAAA;ANikBF;;AM/jBA;EACE,YAAA;ANkkBF;;AMhkBA;EACE,YAAA;ANmkBF;;AMjkBA;EACE,YAAA;ANokBF;;AMlkBA;EACE,YAAA;ANqkBF;;AMnkBA;EACE,YAAA;ANskBF;;AMpkBA;EACE,YAAA;ANukBF;;AMrkBA;EACE,YAAA;ANwkBF;;AMtkBA;EACE,YAAA;ANykBF;;AMvkBA;EACE,YAAA;AN0kBF;;AMxkBA;EACE,YAAA;AN2kBF;;AMzkBA;EACE,YAAA;AN4kBF;;AM1kBA;EACE,YAAA;AN6kBF;;AM3kBA;EACE,YAAA;AN8kBF;;AM5kBA;EACE,YAAA;AN+kBF;;AM7kBA;EACE,YAAA;ANglBF;;AM9kBA;EACE,YAAA;ANilBF;;AM/kBA;EACE,YAAA;ANklBF;;AMhlBA;EACE,YAAA;ANmlBF;;AMjlBA;EACE,YAAA;ANolBF;;AMllBA;;EAEE,YAAA;ANqlBF;;AMnlBA;EACE,YAAA;ANslBF;;AMplBA;EACE,YAAA;ANulBF;;AMrlBA;EACE,YAAA;ANwlBF;;AMtlBA;EACE,YAAA;ANylBF;;AMvlBA;EACE,YAAA;AN0lBF;;AMxlBA;;EAEE,YAAA;AN2lBF;;AMzlBA;EACE,YAAA;AN4lBF;;AM1lBA;EACE,YAAA;AN6lBF;;AM3lBA;EACE,YAAA;AN8lBF;;AM5lBA;EACE,YAAA;AN+lBF;;AM7lBA;EACE,YAAA;ANgmBF;;AM9lBA;EACE,YAAA;ANimBF;;AM/lBA;EACE,YAAA;ANkmBF;;AMhmBA;EACE,YAAA;ANmmBF;;AMjmBA;EACE,YAAA;ANomBF;;AMlmBA;EACE,YAAA;ANqmBF;;AMnmBA;EACE,YAAA;ANsmBF;;AMpmBA;EACE,YAAA;ANumBF;;AMrmBA;;EAEE,YAAA;ANwmBF;;AMtmBA;;;EAGE,YAAA;ANymBF;;AMvmBA;EACE,YAAA;AN0mBF;;AMxmBA;EACE,YAAA;AN2mBF;;AMzmBA;EACE,YAAA;AN4mBF;;AM1mBA;;EAEE,YAAA;AN6mBF;;AM3mBA;EACE,YAAA;AN8mBF;;AM5mBA;EACE,YAAA;AN+mBF;;AM7mBA;EACE,YAAA;ANgnBF;;AM9mBA;EACE,YAAA;ANinBF;;AM/mBA;EACE,YAAA;ANknBF;;AMhnBA;EACE,YAAA;ANmnBF;;AMjnBA;EACE,YAAA;ANonBF;;AMlnBA;EACE,YAAA;ANqnBF;;AMnnBA;EACE,YAAA;ANsnBF;;AMpnBA;EACE,YAAA;ANunBF;;AMrnBA;EACE,YAAA;ANwnBF;;AMtnBA;EACE,YAAA;ANynBF;;AMvnBA;EACE,YAAA;AN0nBF;;AMxnBA;EACE,YAAA;AN2nBF;;AMznBA;EACE,YAAA;AN4nBF;;AM1nBA;EACE,YAAA;AN6nBF;;AM3nBA;EACE,YAAA;AN8nBF;;AM5nBA;EACE,YAAA;AN+nBF;;AM7nBA;EACE,YAAA;ANgoBF;;AM9nBA;EACE,YAAA;ANioBF;;AM/nBA;EACE,YAAA;ANkoBF;;AMhoBA;EACE,YAAA;ANmoBF;;AMjoBA;EACE,YAAA;ANooBF;;AMloBA;EACE,YAAA;ANqoBF;;AMnoBA;EACE,YAAA;ANsoBF;;AMpoBA;EACE,YAAA;ANuoBF;;AMroBA;EACE,YAAA;ANwoBF;;AMtoBA;EACE,YAAA;ANyoBF;;AMvoBA;EACE,YAAA;AN0oBF;;AMxoBA;EACE,YAAA;AN2oBF;;AMzoBA;EACE,YAAA;AN4oBF;;AM1oBA;EACE,YAAA;AN6oBF;;AM3oBA;EACE,YAAA;AN8oBF;;AM5oBA;EACE,YAAA;AN+oBF;;AM7oBA;EACE,YAAA;ANgpBF;;AM9oBA;EACE,YAAA;ANipBF;;AM/oBA;EACE,YAAA;ANkpBF;;AMhpBA;;EAEE,YAAA;ANmpBF;;AMjpBA;;EAEE,YAAA;ANopBF;;AMlpBA;;EAEE,YAAA;ANqpBF;;AMnpBA;;EAEE,YAAA;ANspBF;;AMppBA;EACE,YAAA;ANupBF;;AMrpBA;;EAEE,YAAA;ANwpBF;;AMtpBA;;EAEE,YAAA;ANypBF;;AMvpBA;;;;EAIE,YAAA;AN0pBF;;AMxpBA;;;EAGE,YAAA;AN2pBF;;AMzpBA;;EAEE,YAAA;AN4pBF;;AM1pBA;;EAEE,YAAA;AN6pBF;;AM3pBA;EACE,YAAA;AN8pBF;;AM5pBA;EACE,YAAA;AN+pBF;;AM7pBA;EACE,YAAA;ANgqBF;;AM9pBA;EACE,YAAA;ANiqBF;;AM/pBA;EACE,YAAA;ANkqBF;;AMhqBA;EACE,YAAA;ANmqBF;;AMjqBA;EACE,YAAA;ANoqBF;;AMlqBA;EACE,YAAA;ANqqBF;;AMnqBA;EACE,YAAA;ANsqBF;;AMpqBA;EACE,YAAA;ANuqBF;;AMrqBA;EACE,YAAA;ANwqBF;;AMtqBA;EACE,YAAA;ANyqBF;;AMvqBA;EACE,YAAA;AN0qBF;;AMxqBA;EACE,YAAA;AN2qBF;;AMzqBA;EACE,YAAA;AN4qBF;;AM1qBA;EACE,YAAA;AN6qBF;;AM3qBA;EACE,YAAA;AN8qBF;;AM5qBA;EACE,YAAA;AN+qBF;;AM7qBA;EACE,YAAA;ANgrBF;;AM9qBA;EACE,YAAA;ANirBF;;AM/qBA;EACE,YAAA;ANkrBF;;AMhrBA;EACE,YAAA;ANmrBF;;AMjrBA;EACE,YAAA;ANorBF;;AMlrBA;EACE,YAAA;ANqrBF;;AMnrBA;EACE,YAAA;ANsrBF;;AMprBA;EACE,YAAA;ANurBF;;AMrrBA;EACE,YAAA;ANwrBF;;AMtrBA;EACE,YAAA;ANyrBF;;AMvrBA;EACE,YAAA;AN0rBF;;AMxrBA;EACE,YAAA;AN2rBF;;AMzrBA;EACE,YAAA;AN4rBF;;AM1rBA;EACE,YAAA;AN6rBF;;AM3rBA;EACE,YAAA;AN8rBF;;AM5rBA;EACE,YAAA;AN+rBF;;AM7rBA;EACE,YAAA;ANgsBF;;AM9rBA;EACE,YAAA;ANisBF;;AM/rBA;EACE,YAAA;ANksBF;;AMhsBA;EACE,YAAA;ANmsBF;;AMjsBA;;EAEE,YAAA;ANosBF;;AMlsBA;EACE,YAAA;ANqsBF;;AMnsBA;EACE,YAAA;ANssBF;;AMpsBA;EACE,YAAA;ANusBF;;AMrsBA;EACE,YAAA;ANwsBF;;AMtsBA;EACE,YAAA;ANysBF;;AMvsBA;EACE,YAAA;AN0sBF;;AMxsBA;EACE,YAAA;AN2sBF;;AMzsBA;EACE,YAAA;AN4sBF;;AM1sBA;EACE,YAAA;AN6sBF;;AM3sBA;EACE,YAAA;AN8sBF;;AM5sBA;EACE,YAAA;AN+sBF;;AM7sBA;;EAEE,YAAA;ANgtBF;;AM9sBA;EACE,YAAA;ANitBF;;AM/sBA;EACE,YAAA;ANktBF;;AMhtBA;EACE,YAAA;ANmtBF;;AMjtBA;;EAEE,YAAA;ANotBF;;AMltBA;EACE,YAAA;ANqtBF;;AMntBA;EACE,YAAA;ANstBF;;AMptBA;EACE,YAAA;ANutBF;;AMrtBA;EACE,YAAA;ANwtBF;;AMttBA;EACE,YAAA;ANytBF;;AMvtBA;EACE,YAAA;AN0tBF;;AMxtBA;;;EAGE,YAAA;AN2tBF;;AMztBA;;EAEE,YAAA;AN4tBF;;AM1tBA;EACE,YAAA;AN6tBF;;AM3tBA;EACE,YAAA;AN8tBF;;AM5tBA;EACE,YAAA;AN+tBF;;AM7tBA;EACE,YAAA;ANguBF;;AM9tBA;EACE,YAAA;ANiuBF;;AM/tBA;EACE,YAAA;ANkuBF;;AMhuBA;EACE,YAAA;ANmuBF;;AMjuBA;EACE,YAAA;ANouBF;;AMluBA;EACE,YAAA;ANquBF;;AMnuBA;EACE,YAAA;ANsuBF;;AMpuBA;EACE,YAAA;ANuuBF;;AMruBA;EACE,YAAA;ANwuBF;;AMtuBA;EACE,YAAA;ANyuBF;;AMvuBA;EACE,YAAA;AN0uBF;;AMxuBA;EACE,YAAA;AN2uBF;;AMzuBA;EACE,YAAA;AN4uBF;;AM1uBA;EACE,YAAA;AN6uBF;;AM3uBA;EACE,YAAA;AN8uBF;;AM5uBA;EACE,YAAA;AN+uBF;;AM7uBA;EACE,YAAA;ANgvBF;;AM9uBA;EACE,YAAA;ANivBF;;AM/uBA;EACE,YAAA;ANkvBF;;AMhvBA;EACE,YAAA;ANmvBF;;AMjvBA;EACE,YAAA;ANovBF;;AMlvBA;EACE,YAAA;ANqvBF;;AMnvBA;;EAEE,YAAA;ANsvBF;;AMpvBA;;EAEE,YAAA;ANuvBF;;AMrvBA;EACE,YAAA;ANwvBF;;AMtvBA;EACE,YAAA;ANyvBF;;AMvvBA;EACE,YAAA;AN0vBF;;AMxvBA;EACE,YAAA;AN2vBF;;AMzvBA;EACE,YAAA;AN4vBF;;AM1vBA;EACE,YAAA;AN6vBF;;AM3vBA;EACE,YAAA;AN8vBF;;AM5vBA;EACE,YAAA;AN+vBF;;AM7vBA;EACE,YAAA;ANgwBF;;AM9vBA;;;EAGE,YAAA;ANiwBF;;AM/vBA;;EAEE,YAAA;ANkwBF;;AMhwBA;;EAEE,YAAA;ANmwBF;;AMjwBA;;EAEE,YAAA;ANowBF;;AMlwBA;EACE,YAAA;ANqwBF;;AMnwBA;EACE,YAAA;ANswBF;;AMpwBA;EACE,YAAA;ANuwBF;;AMrwBA;EACE,YAAA;ANwwBF;;AMtwBA;;;;;EAKE,YAAA;ANywBF;;AMvwBA;EACE,YAAA;AN0wBF;;AMxwBA;;;EAGE,YAAA;AN2wBF;;AMzwBA;;EAEE,YAAA;AN4wBF;;AM1wBA;EACE,YAAA;AN6wBF;;AM3wBA;EACE,YAAA;AN8wBF;;AM5wBA;;;EAGE,YAAA;AN+wBF;;AM7wBA;EACE,YAAA;ANgxBF;;AM9wBA;EACE,YAAA;ANixBF;;AM/wBA;;EAEE,YAAA;ANkxBF;;AMhxBA;;EAEE,YAAA;ANmxBF;;AMjxBA;;EAEE,YAAA;ANoxBF;;AMlxBA;EACE,YAAA;ANqxBF;;AMnxBA;EACE,YAAA;ANsxBF;;AMpxBA;EACE,YAAA;ANuxBF;;AMrxBA;EACE,YAAA;ANwxBF;;AMtxBA;EACE,YAAA;ANyxBF;;AMvxBA;EACE,YAAA;AN0xBF;;AMxxBA;EACE,YAAA;AN2xBF;;AMzxBA;EACE,YAAA;AN4xBF;;AM1xBA;;EAEE,YAAA;AN6xBF;;AM3xBA;EACE,YAAA;AN8xBF;;AM5xBA;EACE,YAAA;AN+xBF;;AM7xBA;EACE,YAAA;ANgyBF;;AM9xBA;EACE,YAAA;ANiyBF;;AM/xBA;EACE,YAAA;ANkyBF;;AMhyBA;EACE,YAAA;ANmyBF;;AMjyBA;EACE,YAAA;ANoyBF;;AMlyBA;EACE,YAAA;ANqyBF;;AMnyBA;EACE,YAAA;ANsyBF;;AMpyBA;EACE,YAAA;ANuyBF;;AMryBA;EACE,YAAA;ANwyBF;;AMtyBA;EACE,YAAA;ANyyBF;;AMvyBA;EACE,YAAA;AN0yBF;;AMxyBA;EACE,YAAA;AN2yBF;;AMzyBA;EACE,YAAA;AN4yBF;;AM1yBA;EACE,YAAA;AN6yBF;;AM3yBA;EACE,YAAA;AN8yBF;;AM5yBA;EACE,YAAA;AN+yBF;;AM7yBA;EACE,YAAA;ANgzBF;;AM9yBA;EACE,YAAA;ANizBF;;AM/yBA;EACE,YAAA;ANkzBF;;AMhzBA;EACE,YAAA;ANmzBF;;AMjzBA;EACE,YAAA;ANozBF;;AMlzBA;EACE,YAAA;ANqzBF;;AMnzBA;EACE,YAAA;ANszBF;;AMpzBA;EACE,YAAA;ANuzBF;;AMrzBA;EACE,YAAA;ANwzBF;;AMtzBA;EACE,YAAA;ANyzBF;;AMvzBA;EACE,YAAA;AN0zBF;;AMxzBA;EACE,YAAA;AN2zBF;;AMzzBA;EACE,YAAA;AN4zBF;;AM1zBA;EACE,YAAA;AN6zBF;;AM3zBA;EACE,YAAA;AN8zBF;;AM5zBA;EACE,YAAA;AN+zBF;;AM7zBA;EACE,YAAA;ANg0BF;;AM9zBA;EACE,YAAA;ANi0BF;;AM/zBA;EACE,YAAA;ANk0BF;;AMh0BA;;;EAGE,YAAA;ANm0BF;;AMj0BA;EACE,YAAA;ANo0BF;;AMl0BA;EACE,YAAA;ANq0BF;;AMn0BA;EACE,YAAA;ANs0BF;;AMp0BA;EACE,YAAA;ANu0BF;;AMr0BA;EACE,YAAA;ANw0BF;;AMt0BA;EACE,YAAA;ANy0BF;;AMv0BA;EACE,YAAA;AN00BF;;AMx0BA;EACE,YAAA;AN20BF;;AMz0BA;EACE,YAAA;AN40BF;;AM10BA;EACE,YAAA;AN60BF;;AM30BA;EACE,YAAA;AN80BF;;AM50BA;EACE,YAAA;AN+0BF;;AM70BA;EACE,YAAA;ANg1BF;;AM90BA;EACE,YAAA;ANi1BF;;AM/0BA;EACE,YAAA;ANk1BF;;AMh1BA;EACE,YAAA;ANm1BF;;AMj1BA;EACE,YAAA;ANo1BF;;AMl1BA;EACE,YAAA;ANq1BF;;AMn1BA;EACE,YAAA;ANs1BF;;AMp1BA;EACE,YAAA;ANu1BF;;AMr1BA;EACE,YAAA;ANw1BF;;AMt1BA;;EAEE,YAAA;ANy1BF;;AMv1BA;EACE,YAAA;AN01BF;;AMx1BA;EACE,YAAA;AN21BF;;AMz1BA;EACE,YAAA;AN41BF;;AM11BA;EACE,YAAA;AN61BF;;AM31BA;EACE,YAAA;AN81BF;;AM51BA;EACE,YAAA;AN+1BF;;AM71BA;EACE,YAAA;ANg2BF;;AM91BA;EACE,YAAA;ANi2BF;;AM/1BA;EACE,YAAA;ANk2BF;;AMh2BA;EACE,YAAA;ANm2BF;;AMj2BA;EACE,YAAA;ANo2BF;;AMl2BA;EACE,YAAA;ANq2BF;;AMn2BA;EACE,YAAA;ANs2BF;;AMp2BA;EACE,YAAA;ANu2BF;;AMr2BA;EACE,YAAA;ANw2BF;;AMt2BA;;EAEE,YAAA;ANy2BF;;AMv2BA;EACE,YAAA;AN02BF;;AMx2BA;EACE,YAAA;AN22BF;;AMz2BA;EACE,YAAA;AN42BF;;AM12BA;EACE,YAAA;AN62BF;;AM32BA;;EAEE,YAAA;AN82BF;;AM52BA;EACE,YAAA;AN+2BF;;AM72BA;EACE,YAAA;ANg3BF;;AM92BA;EACE,YAAA;ANi3BF;;AM/2BA;;;EAGE,YAAA;ANk3BF;;AMh3BA;;EAEE,YAAA;ANm3BF;;AMj3BA;;EAEE,YAAA;ANo3BF;;AMl3BA;;EAEE,YAAA;ANq3BF;;AMn3BA;;EAEE,YAAA;ANs3BF;;AMp3BA;EACE,YAAA;ANu3BF;;AMr3BA;EACE,YAAA;ANw3BF;;AMt3BA;EACE,YAAA;ANy3BF;;AMv3BA;EACE,YAAA;AN03BF;;AMx3BA;EACE,YAAA;AN23BF;;AMz3BA;EACE,YAAA;AN43BF;;AM13BA;EACE,YAAA;AN63BF;;AM33BA;EACE,YAAA;AN83BF;;AM53BA;EACE,YAAA;AN+3BF;;AM73BA;EACE,YAAA;ANg4BF;;AM93BA;EACE,YAAA;ANi4BF;;AM/3BA;;EAEE,YAAA;ANk4BF;;AMh4BA;;EAEE,YAAA;ANm4BF;;AMj4BA;;EAEE,YAAA;ANo4BF;;AMl4BA;EACE,YAAA;ANq4BF;;AMn4BA;;EAEE,YAAA;ANs4BF;;AMp4BA;;EAEE,YAAA;ANu4BF;;AMr4BA;EACE,YAAA;ANw4BF;;AMt4BA;EACE,YAAA;ANy4BF;;AMv4BA;EACE,YAAA;AN04BF;;AMx4BA;EACE,YAAA;AN24BF;;AMz4BA;EACE,YAAA;AN44BF;;AM14BA;EACE,YAAA;AN64BF;;AM34BA;EACE,YAAA;AN84BF;;AM54BA;EACE,YAAA;AN+4BF;;AM74BA;EACE,YAAA;ANg5BF;;AM94BA;EACE,YAAA;ANi5BF;;AM/4BA;EACE,YAAA;ANk5BF;;AMh5BA;EACE,YAAA;ANm5BF;;AMj5BA;EACE,YAAA;ANo5BF;;AMl5BA;EACE,YAAA;ANq5BF;;AMn5BA;EACE,YAAA;ANs5BF;;AMp5BA;EACE,YAAA;ANu5BF;;AMr5BA;EACE,YAAA;ANw5BF;;AMt5BA;EACE,YAAA;ANy5BF;;AMv5BA;EACE,YAAA;AN05BF;;AMx5BA;EACE,YAAA;AN25BF;;AMz5BA;;EAEE,YAAA;AN45BF;;AM15BA;EACE,YAAA;AN65BF;;AM35BA;EACE,YAAA;AN85BF;;AM55BA;EACE,YAAA;AN+5BF;;AM75BA;EACE,YAAA;ANg6BF;;AM95BA;EACE,YAAA;ANi6BF;;AM/5BA;EACE,YAAA;ANk6BF;;AMh6BA;EACE,YAAA;ANm6BF;;AMj6BA;EACE,YAAA;ANo6BF;;AMl6BA;EACE,YAAA;ANq6BF;;AMn6BA;EACE,YAAA;ANs6BF;;AMp6BA;EACE,YAAA;ANu6BF;;AMr6BA;EACE,YAAA;ANw6BF;;AMt6BA;EACE,YAAA;ANy6BF;;AMv6BA;EACE,YAAA;AN06BF;;AMx6BA;EACE,YAAA;AN26BF;;AMz6BA;EACE,YAAA;AN46BF;;AM16BA;EACE,YAAA;AN66BF;;AM36BA;EACE,YAAA;AN86BF;;AM56BA;EACE,YAAA;AN+6BF;;AM76BA;EACE,YAAA;ANg7BF;;AM96BA;EACE,YAAA;ANi7BF;;AM/6BA;EACE,YAAA;ANk7BF;;AMh7BA;EACE,YAAA;ANm7BF;;AMj7BA;EACE,YAAA;ANo7BF;;AMl7BA;EACE,YAAA;ANq7BF;;AMn7BA;EACE,YAAA;ANs7BF;;AMp7BA;EACE,YAAA;ANu7BF;;AMr7BA;EACE,YAAA;ANw7BF;;AMt7BA;EACE,YAAA;ANy7BF;;AMv7BA;EACE,YAAA;AN07BF;;AMx7BA;EACE,YAAA;AN27BF;;AMz7BA;EACE,YAAA;AN47BF;;AM17BA;EACE,YAAA;AN67BF;;AM37BA;EACE,YAAA;AN87BF;;AM57BA;EACE,YAAA;AN+7BF;;AM77BA;EACE,YAAA;ANg8BF;;AM97BA;EACE,YAAA;ANi8BF;;AM/7BA;EACE,YAAA;ANk8BF;;AMh8BA;EACE,YAAA;ANm8BF;;AMj8BA;EACE,YAAA;ANo8BF;;AMl8BA;EACE,YAAA;ANq8BF;;AMn8BA;EACE,YAAA;ANs8BF;;AMp8BA;EACE,YAAA;ANu8BF;;AMr8BA;EACE,YAAA;ANw8BF;;AMt8BA;EACE,YAAA;ANy8BF;;AMv8BA;EACE,YAAA;AN08BF;;AMx8BA;EACE,YAAA;AN28BF;;AMz8BA;EACE,YAAA;AN48BF;;AM18BA;EACE,YAAA;AN68BF;;AM38BA;EACE,YAAA;AN88BF;;AM58BA;;EAEE,YAAA;AN+8BF;;AM78BA;;;EAGE,YAAA;ANg9BF;;AM98BA;EACE,YAAA;ANi9BF;;AM/8BA;EACE,YAAA;ANk9BF;;AMh9BA;;EAEE,YAAA;ANm9BF;;AMj9BA;EACE,YAAA;ANo9BF;;AMl9BA;EACE,YAAA;ANq9BF;;AMn9BA;EACE,YAAA;ANs9BF;;AMp9BA;EACE,YAAA;ANu9BF;;AMr9BA;EACE,YAAA;ANw9BF;;AMt9BA;EACE,YAAA;ANy9BF;;AMv9BA;EACE,YAAA;AN09BF;;AMx9BA;EACE,YAAA;AN29BF;;AMz9BA;EACE,YAAA;AN49BF;;AM19BA;EACE,YAAA;AN69BF;;AM39BA;;EAEE,YAAA;AN89BF;;AM59BA;;EAEE,YAAA;AN+9BF;;AM79BA;EACE,YAAA;ANg+BF;;AM99BA;EACE,YAAA;ANi+BF;;AM/9BA;EACE,YAAA;ANk+BF;;AMh+BA;EACE,YAAA;ANm+BF;;AMj+BA;EACE,YAAA;ANo+BF;;AMl+BA;EACE,YAAA;ANq+BF;;AMn+BA;;EAEE,YAAA;ANs+BF;;AMp+BA;;EAEE,YAAA;ANu+BF;;AMr+BA;EACE,YAAA;ANw+BF;;AMt+BA;EACE,YAAA;ANy+BF;;AMv+BA;EACE,YAAA;AN0+BF;;AMx+BA;EACE,YAAA;AN2+BF;;AMz+BA;;EAEE,YAAA;AN4+BF;;AM1+BA;;EAEE,YAAA;AN6+BF;;AM3+BA;EACE,YAAA;AN8+BF;;AM5+BA;EACE,YAAA;AN++BF;;AM7+BA;EACE,YAAA;ANg/BF;;AM9+BA;;;EAGE,YAAA;ANi/BF;;AM/+BA;;EAEE,YAAA;ANk/BF;;AMh/BA;;EAEE,YAAA;ANm/BF;;AMj/BA;;EAEE,YAAA;ANo/BF;;AMl/BA;;EAEE,YAAA;ANq/BF;;AMn/BA;EACE,YAAA;ANs/BF;;AMp/BA;;;EAGE,YAAA;ANu/BF;;AMr/BA;EACE,YAAA;ANw/BF;;AMt/BA;EACE,YAAA;ANy/BF;;AMv/BA;EACE,YAAA;AN0/BF;;AMx/BA;EACE,YAAA;AN2/BF;;AMz/BA;;EAEE,YAAA;AN4/BF;;AM1/BA;;EAEE,YAAA;AN6/BF;;AM3/BA;EACE,YAAA;AN8/BF;;AM5/BA;EACE,YAAA;AN+/BF;;AM7/BA;EACE,YAAA;ANggCF;;AM9/BA;EACE,YAAA;ANigCF;;AM//BA;EACE,YAAA;ANkgCF;;AMhgCA;EACE,YAAA;ANmgCF;;AMjgCA;EACE,YAAA;ANogCF;;AMlgCA;EACE,YAAA;ANqgCF;;AMngCA;EACE,YAAA;ANsgCF;;AMpgCA;EACE,YAAA;ANugCF;;AMrgCA;EACE,YAAA;ANwgCF;;AMtgCA;EACE,kBAAA;EACA,UAAA;EACA,WAAA;EACA,UAAA;EACA,YAAA;EACA,gBAAA;EACA,sBAAA;EACA,SAAA;ANygCF;;AMvgCA;;EAEE,gBAAA;EACA,WAAA;EACA,YAAA;EACA,SAAA;EACA,iBAAA;EACA,UAAA;AN0gCF;;AAzxGA;EACI,cAAA;EACA,WAAA;EACA,qBAAA;EACA,YAAA;EACA,gBAAA;EACA,iBAAA;EACA,eAAA;AA4xGJ;;AAxxGA;EACI,aAAA;EACA,qCAAA;EACA,6BAAA;EACA,YAAA;AA2xGJ;AAzxGI;EACI,YAAA;EACA,WAAA;EACA,eAAA;EACA,uBAAA;EAcA,kBAAA;AA8wGR;AA1xGQ;EACI,uBAAA;AA4xGZ;AAzxGQ;EACI,6BAAA;AA2xGZ;AAzxGY;EACI,sCAAA;AA2xGhB;AAtxGQ;EACI,kBAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;EACA,YAAA;EACA,YAAA;EACA,eAAA;EACA,iBAAA;AAwxGZ;AApxGI;EACI,YAAA;AAsxGR;AAnxGI;EACI,WAAA;EACA,cAAA;EACA,gCAAA;EACA,+BAAA;EACA,aAAA;EACA,mBAAA;EACA,8BAAA;AAqxGR;AAnxGQ;EACI,iBAAA;EACA,eAAA;AAqxGZ;AAjxGI;EACI,cAAA;EACA,WAAA;EACA,YAAA;EACA,aAAA;EACA,sBAAA;EACA,+BAAA;AAmxGR;AAjxGQ;EACI,aAAA;EACA,sBAAA;AAmxGZ;AAjxGY;EACI,eAAA;EACA,gBAAA;EACA,wBAAA;AAmxGhB;AAhxGY;EACI,aAAA;EACA,sBAAA;EACA,eAAA;AAkxGhB;AAhxGgB;EACI,aAAA;EACA,mBAAA;EACA,kBAAA;EACA,uBAAA;EACA,WAAA;AAkxGpB;AAhxGoB;EACI,yBAAA;EACA,yBAAA;AAkxGxB;AA/wGoB;EACI,wCAAA;AAixGxB;AA5wGY;EACI,gBAAA;EACA,kBAAA;AA8wGhB;AAzwGI;EACI,qBAAA;EACA,WAAA;EAEA,aAAA;EACA,gCAAA;EACA,UAAA;AA0wGR;AAxwGQ;EACI,sCAAA;AA0wGZ;AAvwGQ;EACI,gBAAA;EACA,iBAAA;EACA,aAAA;EACA,sBAAA;EACA,eAAA;AAywGZ;AAvwGY;EACI,gBAAA;EACA,kBAAA;AAywGhB;AAtwGY;EACI,mBAAA;AAwwGhB;AAtwGgB;EACI,kBAAA;EACA,gBAAA;EACA,kBAAA;EACA,YAAA;AAwwGpB;AAvwGoB;EACI,YAAA;AAywGxB;AAtwGoB;EACI,gBAAA;EACA,aAAA;AAwwGxB;AAtwGwB;EACI,cEtJf;AF85Gb;AAtwG4B;EACI,cAAA;AAwwGhC;AAnwGoB;EACI,gBAAA;EACA,kBAAA;EACA,WAAA;EACA,QAAA;EACA,6BAAA;EACA,kBAAA;EACA,cE5KP;AFi7GjB;AAnwGwB;EACI,cE7KX;AFk7GjB;AAhwGwB;EACI,mBAAA;AAkwG5B;AA9vGoB;EO7KlB,gHAAA;EPgLsB,kBAAA;EACA,aAAA;EACA,sBAAA;EACA,mBEnMP;EFoMO,YAAA;EACA,0BAAA;EACA,aAAA;EACA,uBAAA;AA+vGxB;AA7vGwB;EACI,aAAA;EACA,mBAAA;EACA,mBAAA;EACA,kBAAA;EACA,gCAAA;AA+vG5B;AA5vG4B;EACI,YAAA;AA8vGhC;AA3vG4B;EACI,eAAA;EACA,cEnNf;EFoNe,WAAA;EACA,YAAA;EACA,aAAA;EACA,mBAAA;EACA,uBAAA;AA6vGhC;AA3vGgC;EACI,cE1NnB;AFu9GjB;AA1vGgC;EACI,cExNvB;AFo9Gb;AA1vGoC;EACI,cAAA;AA4vGxC;AAvvG4B;EACI,gBAAA;AAyvGhC;AArvGwB;EACI,aAAA;AAuvG5B;AArvG4B;EACI,cAAA;EACA,YAAA;EACA,aAAA;EACA,sBAAA;AAuvGhC;AA/uGQ;EACI,gBAAA;EACA,aAAA;EACA,eAAA;EACA,mBAAA;EACA,qBAAA;AAivGZ;AA/uGY;EACI,gBAAA;EACA,eAAA;EACA,iBAAA;AAivGhB;AA9uGY;EACI,kBAAA;EACA,mBAAA;EACA,gBAAA;EACA,iBAAA;EACA,kBAAA;EAEA,aAAA;EACA,mBAAA;AA+uGhB;AA5uGY;EACI,yBAAA;AA8uGhB;AA5uGgB;EACI,iBAAA;EACA,YAAA;AA8uGpB;AA3uGgB;EACI,eAAA;EACA,mBAAA;AA6uGpB;AAzuGY;EACI,yBAAA;EACA,eAAA;AA2uGhB;AAzuGgB;EACI,yBAAA;AA2uGpB;AAtuGQ;EACI,YAAA;EACA,aAAA;EACA,mBAAA;EACA,yBAAA;AAwuGZ;AAtuGY;EACI,aAAA;EACA,qBAAA;EACA,YAAA;EACA,6BAAA;AAwuGhB;AAruGoB;EACI,kBAAA;EACA,QAAA;EACA,iBAAA;AAuuGxB;AAluGoB;EACI,gBAAA;AAouGxB;AAhuGgB;EACI,kBAAA;AAkuGpB;AAhuGoB;EACI,mBAAA;AAkuGxB;AA7tGY;EACI,aAAA;EACA,kBAAA;AA+tGhB;AA7tGgB;EAEI,YAAA;EACA,WAAA;EACA,yBAAA;EACA,kBAAA;EACA,4BE7VH;EF8VG,iBAAA;EACA,eAAA;EAUA,kBAAA;AAqtGpB;AA7tGoB;EACI,yBEjWP;AFgkHjB;AA5tGoB;EACI,yBEpWP;AFkkHjB;AA1tGoB;EACI,kBAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;AA4tGxB;AAztGoB;EACI,cE9WP;EF+WO,eAAA;AA2tGxB;AAztGwB;EACI,4BEtXX;AFilHjB;AAntGI;EACI,cAAA;EACA,WAAA;EACA,gBAAA;EACA,gBAAA;AAqtGR;AAntGQ;EACI,WAAA;EACA,mBAAA;EACA,yBAAA;EACA,iBAAA;EAEA,kBAAA;AAotGZ;AAntGY;EACI,gBAAA;EACA,MAAA;EACA,yBAAA;EACA,YAAA;EACA,YAAA;EACA,UAAA;AAqtGhB;AAntGgB;EACI,aAAA;EACA,sBAAA;EACA,uBAAA;EACA,iBAAA;EACA,gBAAA;EACA,uBAAA;EACA,YAAA;EACA,yBAAA;AAqtGpB;AAntGoB;EACI,yBAAA;AAqtGxB;AAltGoB;EACI,YAAA;EACA,aAAA;EACA,mBAAA;AAotGxB;AAjtGoB;EACI,uBAAA;AAmtGxB;AAhtGoB;EACI,WAAA;AAktGxB;AA7sGY;EACI,YAAA;EACA,6BAAA;EACA,gCAAA;EACA,kBAAA;EACA,gBAAA;EACA,uBAAA;AA+sGhB;AA7sGgB;EACI,iBAAA;EACA,gBAAA;EACA,gBAAA;EACA,mBAAA;EACA,uBAAA;AA+sGpB;AA5sGgB;EACI,sBAAA;EACA,cAAA;AA8sGpB;AA3sGgB;EACI,kBAAA;AA6sGpB;AA3sGoB;EACI,kBAAA;EACA,UAAA;EACA,QAAA;EACA,6BAAA;EACA,kBAAA;EACA,gBAAA;EAEA,aAAA;EACA,WAAA;EACA,8BAAA;AA4sGxB;AA1sGwB;EACI,WAAA;EACA,eAAA;EACA,eEndX;AF+pHjB;AA3sG4B;EACI,eEndf;AFgqHjB;AAvsGwB;EACI,mBAAA;AAysG5B;AAnsGY;EACI,WAAA;EACA,YAAA;AAqsGhB;AAnsGgB;EACI,YAAA;EACA,UAAA;EACA,yBE7eH;EF8eG,cAAA;AAqsGpB;AAlsGgB;EACI,iBAAA;AAosGpB;AAlsGoB;EACI,yBEnfP;AFurHjB;AA/rGY;EACI,aAAA;AAisGhB;AA5rGI;EACI,cAAA;EACA,WAAA;EAEA,aAAA;EACA,iBAAA;EACA,kBAAA;AA6rGR;AA3rGQ;EACI,cAAA;EACA,WAAA;EACA,YAAA;EACA,8BAAA;EACA,iBAAA;AA6rGZ;AA3rGY;EACI,8BAAA;AA6rGhB;AAzrGQ;EACI,aAAA;EACA,sBAAA;EACA,WAAA;AA2rGZ;AAzrGY;EACI,aAAA;EACA,YAAA;EACA,kBAAA;AA2rGhB;AAzrGgB;EACI,gBAAA;EACA,gBAAA;EACA,eAAA;EACA,iBAAA;AA2rGpB;AAvrGY;EACI,YAAA;EACA,aAAA;EACA,sBAAA;EACA,gBAAA;EACA,iBAAA;EACA,oBAAA;AAyrGhB;AAvrGgB;EACI,aAAA;EACA,+BAAA;EACA,kBAAA;EACA,mBAAA;AAyrGpB;AAvrGoB;EACI,cAAA;EACA,cEjjBP;AF0uHjB;AAtrGoB;EACI,cAAA;EACA,qBAAA;EACA,gBAAA;EACA,mBAAA;EACA,uBAAA;AAwrGxB;AAprGgB;EACI,eAAA;EACA,cE/jBH;AFqvHjB;AAnrGgB;EACI,YAAA;EACA,qBAAA;EACA,eAAA;EACA,iBAAA;AAqrGpB;AAlrGgB;EACI,gBAAA;AAorGpB;AAjrGgB;EACI,eAAA;EACA,eAAA;EACA,eAAA;EACA,aAAA;EACA,iBAAA;AAmrGpB;AAjrGoB;EACI,WAAA;EACA,iBAAA;EACA,kBAAA;AAmrGxB;AAhrGoB;EACI,cE3lBP;AF6wHjB;AA3qGI;EACI,kBAAA;EACA,WAAA;EACA,YAAA;EACA,UAAA;AA6qGR;AA1qGI;EACI,UAAA;EAEA,kBAAA;EACA,SAAA;EACA,0BAAA;EACA,YAAA;EACA,YAAA;EAEA,aAAA;EACA,8BAAA;AA0qGR;AAxqGQ;EACI,eAAA;EACA,YAAA;EACA,kBAAA;EACA,yBAAA;EACA,uBAAA;AA0qGZ;AAxqGY;EACI;IACI,UAAA;EA0qGlB;EAvqGc;IACI,UAAA;EAyqGlB;AACF","sourcesContent":["@import 'color';\n@import 'shadow';\n@import 'datetimepicker';\n@import 'fonts/roboto';\n@import 'fonts/robotomono';\n@import 'fonts/fontawesome';\n\n\nhtml, body {\n    font-size: 9pt;\n    margin: 0px;\n    font-family: 'Roboto';\n    height: 100%;\n    overflow: hidden;\n    user-select: none;\n    cursor: default;\n}\n\n\n#main {\n    display: grid;\n    grid-template-columns: auto auto auto;\n    grid-template-rows: 45px auto;\n    height: 100%;\n\n    .control-button {\n        height: 44px;\n        width: 44px;\n        font-size: 15pt;\n        background-color: white;\n\n        &:hover {\n            filter: brightness(90%);\n        }\n\n        &.frozen {\n            background-color: transparent;\n\n            &:hover {\n                background-color: rgba(red, 0.1);\n            }\n        }\n\n        position: relative;\n        & > * {\n            position: absolute;\n            top: 50%;\n            left: 50%;\n            transform: translate(-50%, -50%);\n            margin: auto;\n            color: black;\n            cursor: default;\n            stroke-width: 2px;\n        }\n    }\n\n    .stretch {\n        flex-grow: 1;\n    }\n\n    & > .menu-header {\n        grid-row: 1;\n        grid-column: 1;\n        border-bottom: 1px solid $color-grey-400;\n        border-right: 1px solid $color-grey-400;\n        display: flex;\n        align-items: center;\n        justify-content: space-between;\n\n        & > .title {\n            margin-left: 10px;\n            font-size: 13pt;\n        }\n    }\n\n    & > .menu {\n        grid-column: 1;\n        grid-row: 2;\n        height: 100%;\n        display: flex;\n        flex-direction: column;\n        border-right: 1px solid $color-grey-500;\n\n        & > .group {\n            display: flex;\n            flex-direction: column;\n\n            & > .title {\n                font-size: 10pt;\n                font-weight: 700;\n                margin: 5px auto 0px 5px;\n            }\n\n            & > .column-options {\n                display: flex;\n                flex-direction: column;\n                margin: 0px 5px;\n\n                & > .item {\n                    display: flex;\n                    align-items: center;\n                    border-radius: 5px;\n                    border: 1px solid white;\n                    margin: 3px;\n\n                    &.dropzone {\n                        background-color: lighten($color-blue, 40%);\n                        border: 1px dashed yellow;\n                    }\n\n                    &.not-visible-has-filter {\n                        background-color: rgba(orange, 0.2);\n                    }\n                }\n            }\n\n            & > .reset-button {\n                margin-top: 10px;\n                align-self: center;\n            }\n        }\n    }\n\n    & > .header {\n        grid-column: 2 / span 2;\n        grid-row: 1;\n\n        display: flex;\n        border-bottom: 1px solid $color-grey-400;\n        z-index: 1;\n\n        &.frozen {\n            background-color: rgba(red, 0.1);\n        }\n\n        & > .datetime-pickers {\n            padding-top: 2px;\n            margin-left: 12px;\n            display: flex;\n            flex-direction: column;\n            font-size: 10pt;\n\n            & > .title {\n                font-weight: 600;\n                margin-bottom: 4px;\n            }\n\n            & > .timestamps {\n                align-items: center;\n\n                & > .timestamp-filter {\n                    position: relative;\n                    margin-left: 5px;\n                    margin-right: 10px;\n                    width: 205px;\n                    input {\n                        width: 185px;\n                    }\n\n                    & > .calendar {\n                        margin-left: 3px;\n                        outline: none;\n\n                        &.active {\n                            color: $color-blue;\n\n                            &:hover {\n                                color: darken($color-blue, 10%);\n                            }\n                        }\n                    }\n\n                    & > .clear {\n                        margin-left: 3px;\n                        position: absolute;\n                        right: 20px;\n                        top: 50%;\n                        transform: translate(0, -50%);\n                        visibility: hidden;\n                        color: $color-grey-600;\n\n                        &:hover {\n                            color: $color-grey-800;\n                        }\n                    }\n\n                    &:hover {\n                        & > .clear {\n                            visibility: visible;\n                        }\n                    }\n\n                    & > .timestamp-picker {\n                        @include shadow-4dp();\n\n                        position: absolute;\n                        display: flex;\n                        flex-direction: column;\n                        background: $color-grey-200;\n                        padding: 3px;\n                        border-radius: 0 0 3px 3px;\n                        outline: none;\n                        animation: fade-in 0.3s;\n\n                        & > .header {\n                            display: flex;\n                            align-items: center;\n                            padding-bottom: 3px;\n                            margin-bottom: 6px;\n                            border-bottom: 1px solid $color-grey-400;\n\n\n                            & > .spacer {\n                                flex-grow: 1;\n                            }\n\n                            & > .tab {\n                                font-size: 11pt;\n                                color: $color-grey-600;\n                                width: 25px;\n                                height: 22px;\n                                display: flex;\n                                align-items: center;\n                                justify-content: center;\n\n                                &:hover {\n                                    color: $color-grey-700;\n                                }\n\n                                &.active {\n                                    color: $color-blue;\n\n                                    &:hover {\n                                        color: darken($color-blue, 10%);\n                                    }\n                                }\n                            }\n\n                            & > button {\n                                margin-left: 4px;\n                            }\n                        }\n\n                        & > .main {\n                            display: flex;\n\n                            .date-picker {\n                                font-size: 8pt;\n                                width: 200px;\n                                height: 200px;\n                                box-sizing: border-box;\n                            }\n                        }\n                    }\n                }\n            }\n        }\n\n        & > .filters {\n            padding-top: 2px;\n            display: flex;\n            flex-wrap: wrap;\n            height: fit-content;\n            align-items: baseline;\n\n            & > .title {\n                font-weight: 600;\n                font-size: 10pt;\n                margin-right: 5px;\n            }\n\n            & > .chip {\n                border-radius: 3px;\n                height: fit-content;\n                padding: 2px 5px;\n                margin-right: 3px;\n                margin-bottom: 2px;\n\n                display: flex;\n                align-items: center;\n            }\n\n            & > .filter-item {\n                background-color: lighten($color-blue, 30%);\n\n                & > .value {\n                    margin-right: 5px;\n                    color: black;\n                }\n\n                & > .icon {\n                    cursor: pointer;\n                    stroke-width: 1.1px;\n                }\n            }\n\n            & > .clear-all {\n                background-color: lighten(red, 30%);\n                cursor: pointer;\n\n                &:hover {\n                    background-color: lighten(red, 20%);\n                }\n            }\n        }\n\n        & > .navigation {\n            width: 380px;\n            display: flex;\n            align-items: center;\n            justify-content: flex-end;\n\n            & > .labeled-controls {\n                display: flex;\n                align-items: baseline;\n                flex-grow: 1;\n                justify-content: space-around;\n\n                & > .freeze-toggle {\n                    & > input {\n                        position: relative;\n                        top: 2px;\n                        margin-right: 5px;\n                    }\n                }\n\n                & > .size-select {\n                    & > select {\n                        margin-left: 5px;\n                    }\n                }\n\n                & > .page-counter {\n                    visibility: hidden;\n\n                    &.frozen {\n                        visibility: visible;\n                    }\n                }\n            }\n\n            & > .buttons {\n                display: flex;\n                margin-right: 10px;\n\n                & > .navigation-button {\n\n                    height: 35px;\n                    width: 30px;\n                    border: 1px solid $color-grey-300;\n                    border-radius: 7px;\n                    background-color: $color-grey-100;\n                    margin-right: 2px;\n                    font-size: 12pt;\n\n                    &:hover {\n                        background-color: $color-grey-200;\n                    }\n\n                    &:active {\n                        background-color: $color-grey-300;\n                    }\n\n                    position: relative;\n                    & > * {\n                        position: absolute;\n                        top: 50%;\n                        left: 50%;\n                        transform: translate(-50%, -50%);\n                    }\n\n                    &.disabled {\n                        color: $color-grey-500;\n                        cursor: default;\n\n                        &:hover {\n                            background-color: $color-grey-100;\n                        }\n                    }\n                }\n            }\n        }\n    }\n\n    & > .table {\n        grid-column: 2;\n        grid-row: 2;\n        overflow-x: auto;\n        overflow-y: auto;\n\n        & > table {\n            width: 100%;\n            table-layout: fixed;\n            border-collapse: collapse;\n            user-select: text;\n\n            position:relative;\n            th {\n                position: sticky;\n                top: 0;\n                background-color: darken($color-blue, 10%);\n                color: white;\n                height: 34px;\n                z-index: 1;\n\n                & > .column-header {\n                    display: flex;\n                    flex-direction: column;\n                    justify-content: center;\n                    text-align: start;\n                    padding: 0px 3px;\n                    text-overflow: ellipsis;\n                    height: 100%;\n                    border: 1px solid darken($color-blue, 10%);\n\n                    &.dropzone {\n                        border: 1px dashed yellow;\n                    }\n\n                    & > .label-container {\n                        flex-grow: 1;\n                        display: flex;\n                        align-items: center;\n                    }\n\n                    & > input {\n                        width: calc(100% - 4px);\n                    }\n\n                    & > select {\n                        width: 100%;\n                    }\n                }\n            }\n\n            td {\n                height: 20px;\n                border-top: 1px solid $color-grey-500;\n                border-bottom: 1px solid $color-grey-500;\n                text-align: center;\n                overflow: hidden;\n                text-overflow: ellipsis;\n\n                &.text-noncentered, &.json {\n                    text-align: start;\n                    padding: 0px 5px;\n                    overflow: hidden;\n                    white-space: nowrap;\n                    text-overflow: ellipsis;\n                }\n\n                &.json {\n                    font-family: monospace;\n                    font-size: 8pt;\n                }\n\n                &.timestamp {\n                    position: relative;\n\n                    & > .cell-icons {\n                        position: absolute;\n                        right: 0px;\n                        top: 50%;\n                        transform: translate(0, -42%);\n                        visibility: hidden;\n                        padding: 0px 2px;\n\n                        display: flex;\n                        width: 26px;\n                        justify-content: space-between;\n\n                        & > .icon {\n                            width: 13px;\n                            stroke-width: 2;\n                            stroke: $color-grey-600;\n                            &:hover {\n                                stroke: $color-grey-800;\n                            }\n                        }\n                    }\n\n                    &:hover {\n                        & > .cell-icons {\n                            visibility: visible;\n                        }\n                    }\n                }\n            }\n\n            .border {\n                width: 10px;\n                padding: 0px;\n\n                & > .line {\n                    height: 100%;\n                    width: 1px;\n                    background-color: $color-grey-200;\n                    margin: 0 auto;\n                }\n\n                &.hover {\n                    cursor: ew-resize;\n\n                    & > .line{\n                        background-color: $color-grey-400;\n                    }\n                }\n            }\n\n            .border:last-child {\n                display: none;\n            }\n        }\n    }\n\n    & > .details {\n        grid-column: 3;\n        grid-row: 2;\n\n        display: flex;\n        user-select: text;\n        overflow-y: hidden;\n\n        & > .border {\n            flex-shrink: 0;\n            width: 10px;\n            height: 100%;\n            border-left: 1px solid $color-grey-400;\n            cursor: ew-resize;\n\n            &:hover {\n                border-left: 1px solid $color-grey-600;\n            }\n        }\n\n        & > .entry-data {\n            display: flex;\n            flex-direction: column;\n            width: 100%;\n\n            & > .header {\n                display: flex;\n                height: 45px;\n                align-items: start;\n\n                & > .title {\n                    margin-left: 5px;\n                    margin-top: 10px;\n                    font-size: 13pt;\n                    user-select: none;\n                }\n            }\n\n            & > .content {\n                flex-grow: 1;\n                display: flex;\n                flex-direction: column;\n                overflow-y: auto;\n                margin-right: 5px;\n                padding-bottom:10px;\n\n                & > .key-value-pairs {\n                    display: grid;\n                    grid-template-columns: auto 1fr;\n                    grid-gap: 5px 10px;\n                    align-items: center;\n\n                    & > .key {\n                        grid-column: 1;\n                        color: $color-grey-700;\n                    }\n\n                    & > .value {\n                        grid-column: 2;\n                        white-space: pre-wrap;\n                        overflow: hidden;\n                        white-space: nowrap;\n                        text-overflow: ellipsis;\n                    }\n                }\n\n                & > .label-row {\n                    font-size: 10pt;\n                    color: $color-grey-700;\n                }\n\n                & > .text {\n                    padding: 3px;\n                    white-space: pre-wrap;\n                    margin: 5px 0px;\n                    line-height: 16px;\n                }\n\n                & > pre {\n                    font-size:8.5pt;\n                }\n\n                & > .collapsible {\n                    cursor: pointer;\n                    font-size: 10pt;\n                    margin-top: 5px;\n                    display: flex;\n                    user-select: none;\n\n                    & > .icon {\n                        width: 10px;\n                        margin-right: 3px;\n                        text-align: center;\n                    }\n\n                    & > .title {\n                        color: $color-grey-700;\n                    }\n                }\n            }\n        }\n    }\n\n    & > .mouseevent-overlay {\n        position: absolute;\n        width: 100%;\n        height: 100%;\n        z-index: 2;\n    }\n\n    & > .snackbars {\n        z-index: 2;\n\n        position: absolute;\n        left: 50%;\n        transform: translate(-50%);\n        height: 100%;\n        bottom: 30px;\n\n        display: flex;\n        flex-direction: column-reverse;\n\n        & > .snackbar {\n            margin-top: 3px;\n            padding: 5px;\n            border-radius: 5px;\n            background-color: lighten($color-blue, 30%);\n            animation: fade-in 0.1s;\n\n            @keyframes fade-in {\n                0% {\n                    opacity: 0;\n                }\n\n                100% {\n                    opacity: 1;\n                }\n            }\n        }\n    }\n}\n","@import \"color\";\n@import \"shadow\";\n\n\n.date-picker, .time-picker {\n    display: flex;\n    flex-direction: column;\n    font-size: 10pt;\n    user-select: none;\n\n\n    &.date-picker {\n        align-items: stretch;\n        background: white;\n        border: 1px solid $color-grey-500;\n    }\n\n    &.time-picker {\n        align-items: center;\n    }\n\n    & > div {\n\n        .current {\n            background-color: $color-grey-300;\n        }\n\n        .today {\n            border: 1px solid $color-grey-600;\n        }\n\n        & > .header {\n            height: 25px;\n            display: flex;\n            font-size: 1.1em;\n            border-bottom: 1px solid $color-grey-400;\n\n            & > div {\n                flex-grow: 1;\n                display: inline-flex;\n                justify-content: space-between;\n\n                &.year {\n                    flex-basis: 40%;\n                    flex-grow: 0;\n                }\n\n                &:not(:last-child) {\n                    border-right: 1px solid $color-grey-400;\n                    padding-right: 1px;\n                }\n\n                & > span {\n                    display: inline-flex;\n                    justify-content: center;\n                    align-items: center;\n                    padding: 4px;\n\n                    &.title {\n                        flex-grow: 1;\n                    }\n\n                    &.fa {\n                        color: $color-grey-500;\n\n                        &:hover {\n                            color: $color-grey-900;\n                        }\n                    }\n                }\n            }\n        }\n    }\n\n    & > .year-picker {\n        height: 100%;\n\n        & > .year-grid {\n            display: grid;\n            grid-template-columns: repeat(5, 1fr);\n            grid-template-rows: 35px 1fr 1fr 35px;\n            height: 100%;\n\n            & > div {\n                display: flex;\n                align-items: center;\n                justify-content: center;\n\n                &.nav {\n                    grid-column-start: 1;\n                    grid-column-end: 6;\n                    display: flex;\n                    align-items: center;\n                    justify-content: center;\n                    font-size: 1.1em;\n                    color: $color-grey-500;\n\n                    &.top {\n                        border-bottom: 1px solid $color-grey-400;\n                    }\n\n                    &.bottom {\n                        border-top: 1px solid $color-grey-400;\n                    }\n\n                    &:hover {\n                        color: $color-grey-900;\n                    }\n                }\n\n                &.year:hover {\n                    background-color: $color-grey-200;\n                }\n            }\n        }\n    }\n\n    & > .month-picker {\n        height: 100%;\n\n        & > .month-grid {\n            display: grid;\n            grid-template-columns: repeat(3, 1fr);\n            height: 100%;\n\n            & > div {\n                display: flex;\n                align-items: center;\n                justify-content: center;\n\n                &:hover {\n                    background-color: $color-grey-200;\n                }\n            }\n        }\n    }\n\n    & > .day-picker {\n        height: 100%;\n        display: flex;\n        flex-direction: column;\n\n        & > .day-grid {\n            display: grid;\n            flex-grow: 1;\n            grid-template-columns: repeat(7, 1fr);\n            grid-template-rows: repeat(7, 1fr);\n\n            & > div {\n                display: flex;\n                align-items: center;\n                justify-content: center;\n                box-sizing: border-box;\n\n                &:nth-child(7n+7) {\n                    color: $color-red;\n                }\n            }\n\n            & > .weekday {\n                font-weight: 500;\n            }\n\n            & > .day {\n\n                &:hover {\n                    background-color: $color-grey-200;\n                }\n            }\n        }\n    }\n\n    & > .time-picker {\n\n        svg {\n\n            .central {\n\n                text {\n                    font-size:22px;\n                    font-weight:bold;\n                    alignment-baseline:middle;\n                    text-anchor:middle;\n\n                    &.seconds {\n                        font-size:16px;\n                    }\n                }\n            }\n\n            .outer-ring {\n                stroke: $color-grey-700;\n            }\n\n            .hour-ring {\n                stroke: $color-grey-700;\n            }\n\n            .minute-ring {\n                stroke: $color-grey-300;\n            }\n\n            .second-ring {\n                stroke: $color-grey-400;\n            }\n\n            .minute-tick {\n                stroke: $color-grey-700;\n            }\n\n            .second-tick {\n                stroke: $color-grey-400;\n            }\n\n            .hour-box {\n\n                .box {\n                    fill: transparent;\n                }\n\n                &:hover {\n\n                    .box {\n                        fill: $color-grey-200;\n                    }\n                }\n\n                &.selected {\n\n                    .box {\n                        fill: $color-grey-300;\n                    }\n                }\n            }\n\n            .minute-second-box {\n                fill: transparent;\n            }\n\n            .minutes-pointer {\n                fill: $color-red;\n            }\n\n            .seconds-pointer {\n                stroke: $color-yellow;\n                stroke-width: 3px;\n            }\n\n            .minute-text {\n                fill: $color-grey-700;\n            }\n\n            .complication {\n\n                & > circle {\n                    stroke: $color-grey-700;\n                }\n\n                & > text {\n                    fill: $color-grey-800;\n                }\n\n                &:hover {\n\n                    & > circle {\n                        fill: $color-grey-200;\n                    }\n                }\n            }\n        }\n\n    }\n}\n","\n$color-grey-50: rgb(250, 250, 250);\n$color-grey-100: rgb(245, 245, 245);\n$color-grey-200: rgb(238, 238, 238);\n$color-grey-300: rgb(224, 224, 224);\n$color-grey-400: rgb(189, 189, 189);\n$color-grey-500: rgb(158, 158, 158);\n$color-grey-600: rgb(117, 117, 117);\n$color-grey-700: rgb(97, 97, 97);\n$color-grey-800: rgb(66, 66, 66);\n$color-grey-900: rgb(33, 33, 33);\n\n$color-red: #EF233C;\n$color-yellow: #FFBE00;\n$color-blue: #457B9D;\n","\n@mixin font($variant, $type, $weight, $style) {\n    @font-face {\n        font-family: '#{$variant}';\n        src: url('fonts/#{$variant}/#{$variant}-#{$type}.woff2') format('woff2');\n        font-weight: $weight;\n        font-style: $style;\n    }\n}\n","@import \"font\";\n\n\n@include font('Roboto', 'Black', 900, normal);\n@include font('Roboto', 'BlackItalic', 900, italic);\n@include font('Roboto', 'Bold', 700, normal);\n@include font('Roboto', 'BoldItalic', 700, italic);\n@include font('Roboto', 'Medium', 500, normal);\n@include font('Roboto', 'MediumItalic', 500, italic);\n@include font('Roboto', 'Regular', 400, normal);\n@include font('Roboto', 'RegularItalic', 400, italic);\n@include font('Roboto', 'Light', 300, normal);\n@include font('Roboto', 'LightItalic', 300, italic);\n@include font('Roboto', 'Thin', 100, normal);\n@include font('Roboto', 'ThinItalic', 100, italic);\n","@import \"font\";\n\n\n@include font('RobotoMono', 'Bold', 700, normal);\n@include font('RobotoMono', 'BoldItalic', 700, italic);\n@include font('RobotoMono', 'Medium', 500, normal);\n@include font('RobotoMono', 'MediumItalic', 500, italic);\n@include font('RobotoMono', 'Regular', 400, normal);\n@include font('RobotoMono', 'RegularItalic', 400, italic);\n@include font('RobotoMono', 'Light', 300, normal);\n@include font('RobotoMono', 'LightItalic', 300, italic);\n@include font('RobotoMono', 'Thin', 100, normal);\n@include font('RobotoMono', 'ThinItalic', 100, italic);\n","@import \"font\";\n\n\n@include font('FontAwesome', 'webfont', normal, normal);\n\n.fa {\n  display: inline-block;\n  font: normal normal normal 14px/1 FontAwesome;\n  font-size: inherit;\n  text-rendering: auto;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n/* makes the font 33% larger relative to the icon container */\n.fa-lg {\n  font-size: 1.33333333em;\n  line-height: 0.75em;\n  vertical-align: -15%;\n}\n.fa-2x {\n  font-size: 2em;\n}\n.fa-3x {\n  font-size: 3em;\n}\n.fa-4x {\n  font-size: 4em;\n}\n.fa-5x {\n  font-size: 5em;\n}\n.fa-fw {\n  width: 1.28571429em;\n  text-align: center;\n}\n.fa-ul {\n  padding-left: 0;\n  margin-left: 2.14285714em;\n  list-style-type: none;\n}\n.fa-ul > li {\n  position: relative;\n}\n.fa-li {\n  position: absolute;\n  left: -2.14285714em;\n  width: 2.14285714em;\n  top: 0.14285714em;\n  text-align: center;\n}\n.fa-li.fa-lg {\n  left: -1.85714286em;\n}\n.fa-border {\n  padding: .2em .25em .15em;\n  border: solid 0.08em #eeeeee;\n  border-radius: .1em;\n}\n.fa-pull-left {\n  float: left;\n}\n.fa-pull-right {\n  float: right;\n}\n.fa.fa-pull-left {\n  margin-right: .3em;\n}\n.fa.fa-pull-right {\n  margin-left: .3em;\n}\n/* Deprecated as of 4.4.0 */\n.pull-right {\n  float: right;\n}\n.pull-left {\n  float: left;\n}\n.fa.pull-left {\n  margin-right: .3em;\n}\n.fa.pull-right {\n  margin-left: .3em;\n}\n.fa-spin {\n  -webkit-animation: fa-spin 2s infinite linear;\n  animation: fa-spin 2s infinite linear;\n}\n.fa-pulse {\n  -webkit-animation: fa-spin 1s infinite steps(8);\n  animation: fa-spin 1s infinite steps(8);\n}\n@-webkit-keyframes fa-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n@keyframes fa-spin {\n  0% {\n    -webkit-transform: rotate(0deg);\n    transform: rotate(0deg);\n  }\n  100% {\n    -webkit-transform: rotate(359deg);\n    transform: rotate(359deg);\n  }\n}\n.fa-rotate-90 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=1)\";\n  -webkit-transform: rotate(90deg);\n  -ms-transform: rotate(90deg);\n  transform: rotate(90deg);\n}\n.fa-rotate-180 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=2)\";\n  -webkit-transform: rotate(180deg);\n  -ms-transform: rotate(180deg);\n  transform: rotate(180deg);\n}\n.fa-rotate-270 {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=3)\";\n  -webkit-transform: rotate(270deg);\n  -ms-transform: rotate(270deg);\n  transform: rotate(270deg);\n}\n.fa-flip-horizontal {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)\";\n  -webkit-transform: scale(-1, 1);\n  -ms-transform: scale(-1, 1);\n  transform: scale(-1, 1);\n}\n.fa-flip-vertical {\n  -ms-filter: \"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";\n  -webkit-transform: scale(1, -1);\n  -ms-transform: scale(1, -1);\n  transform: scale(1, -1);\n}\n:root .fa-rotate-90,\n:root .fa-rotate-180,\n:root .fa-rotate-270,\n:root .fa-flip-horizontal,\n:root .fa-flip-vertical {\n  filter: none;\n}\n.fa-stack {\n  position: relative;\n  display: inline-block;\n  width: 2em;\n  height: 2em;\n  line-height: 2em;\n  vertical-align: middle;\n}\n.fa-stack-1x,\n.fa-stack-2x {\n  position: absolute;\n  left: 0;\n  width: 100%;\n  text-align: center;\n}\n.fa-stack-1x {\n  line-height: inherit;\n}\n.fa-stack-2x {\n  font-size: 2em;\n}\n.fa-inverse {\n  color: #ffffff;\n}\n/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen\n   readers do not read off random characters that represent icons */\n.fa-glass:before {\n  content: \"\\f000\";\n}\n.fa-music:before {\n  content: \"\\f001\";\n}\n.fa-search:before {\n  content: \"\\f002\";\n}\n.fa-envelope-o:before {\n  content: \"\\f003\";\n}\n.fa-heart:before {\n  content: \"\\f004\";\n}\n.fa-star:before {\n  content: \"\\f005\";\n}\n.fa-star-o:before {\n  content: \"\\f006\";\n}\n.fa-user:before {\n  content: \"\\f007\";\n}\n.fa-film:before {\n  content: \"\\f008\";\n}\n.fa-th-large:before {\n  content: \"\\f009\";\n}\n.fa-th:before {\n  content: \"\\f00a\";\n}\n.fa-th-list:before {\n  content: \"\\f00b\";\n}\n.fa-check:before {\n  content: \"\\f00c\";\n}\n.fa-remove:before,\n.fa-close:before,\n.fa-times:before {\n  content: \"\\f00d\";\n}\n.fa-search-plus:before {\n  content: \"\\f00e\";\n}\n.fa-search-minus:before {\n  content: \"\\f010\";\n}\n.fa-power-off:before {\n  content: \"\\f011\";\n}\n.fa-signal:before {\n  content: \"\\f012\";\n}\n.fa-gear:before,\n.fa-cog:before {\n  content: \"\\f013\";\n}\n.fa-trash-o:before {\n  content: \"\\f014\";\n}\n.fa-home:before {\n  content: \"\\f015\";\n}\n.fa-file-o:before {\n  content: \"\\f016\";\n}\n.fa-clock-o:before {\n  content: \"\\f017\";\n}\n.fa-road:before {\n  content: \"\\f018\";\n}\n.fa-download:before {\n  content: \"\\f019\";\n}\n.fa-arrow-circle-o-down:before {\n  content: \"\\f01a\";\n}\n.fa-arrow-circle-o-up:before {\n  content: \"\\f01b\";\n}\n.fa-inbox:before {\n  content: \"\\f01c\";\n}\n.fa-play-circle-o:before {\n  content: \"\\f01d\";\n}\n.fa-rotate-right:before,\n.fa-repeat:before {\n  content: \"\\f01e\";\n}\n.fa-refresh:before {\n  content: \"\\f021\";\n}\n.fa-list-alt:before {\n  content: \"\\f022\";\n}\n.fa-lock:before {\n  content: \"\\f023\";\n}\n.fa-flag:before {\n  content: \"\\f024\";\n}\n.fa-headphones:before {\n  content: \"\\f025\";\n}\n.fa-volume-off:before {\n  content: \"\\f026\";\n}\n.fa-volume-down:before {\n  content: \"\\f027\";\n}\n.fa-volume-up:before {\n  content: \"\\f028\";\n}\n.fa-qrcode:before {\n  content: \"\\f029\";\n}\n.fa-barcode:before {\n  content: \"\\f02a\";\n}\n.fa-tag:before {\n  content: \"\\f02b\";\n}\n.fa-tags:before {\n  content: \"\\f02c\";\n}\n.fa-book:before {\n  content: \"\\f02d\";\n}\n.fa-bookmark:before {\n  content: \"\\f02e\";\n}\n.fa-print:before {\n  content: \"\\f02f\";\n}\n.fa-camera:before {\n  content: \"\\f030\";\n}\n.fa-font:before {\n  content: \"\\f031\";\n}\n.fa-bold:before {\n  content: \"\\f032\";\n}\n.fa-italic:before {\n  content: \"\\f033\";\n}\n.fa-text-height:before {\n  content: \"\\f034\";\n}\n.fa-text-width:before {\n  content: \"\\f035\";\n}\n.fa-align-left:before {\n  content: \"\\f036\";\n}\n.fa-align-center:before {\n  content: \"\\f037\";\n}\n.fa-align-right:before {\n  content: \"\\f038\";\n}\n.fa-align-justify:before {\n  content: \"\\f039\";\n}\n.fa-list:before {\n  content: \"\\f03a\";\n}\n.fa-dedent:before,\n.fa-outdent:before {\n  content: \"\\f03b\";\n}\n.fa-indent:before {\n  content: \"\\f03c\";\n}\n.fa-video-camera:before {\n  content: \"\\f03d\";\n}\n.fa-photo:before,\n.fa-image:before,\n.fa-picture-o:before {\n  content: \"\\f03e\";\n}\n.fa-pencil:before {\n  content: \"\\f040\";\n}\n.fa-map-marker:before {\n  content: \"\\f041\";\n}\n.fa-adjust:before {\n  content: \"\\f042\";\n}\n.fa-tint:before {\n  content: \"\\f043\";\n}\n.fa-edit:before,\n.fa-pencil-square-o:before {\n  content: \"\\f044\";\n}\n.fa-share-square-o:before {\n  content: \"\\f045\";\n}\n.fa-check-square-o:before {\n  content: \"\\f046\";\n}\n.fa-arrows:before {\n  content: \"\\f047\";\n}\n.fa-step-backward:before {\n  content: \"\\f048\";\n}\n.fa-fast-backward:before {\n  content: \"\\f049\";\n}\n.fa-backward:before {\n  content: \"\\f04a\";\n}\n.fa-play:before {\n  content: \"\\f04b\";\n}\n.fa-pause:before {\n  content: \"\\f04c\";\n}\n.fa-stop:before {\n  content: \"\\f04d\";\n}\n.fa-forward:before {\n  content: \"\\f04e\";\n}\n.fa-fast-forward:before {\n  content: \"\\f050\";\n}\n.fa-step-forward:before {\n  content: \"\\f051\";\n}\n.fa-eject:before {\n  content: \"\\f052\";\n}\n.fa-chevron-left:before {\n  content: \"\\f053\";\n}\n.fa-chevron-right:before {\n  content: \"\\f054\";\n}\n.fa-plus-circle:before {\n  content: \"\\f055\";\n}\n.fa-minus-circle:before {\n  content: \"\\f056\";\n}\n.fa-times-circle:before {\n  content: \"\\f057\";\n}\n.fa-check-circle:before {\n  content: \"\\f058\";\n}\n.fa-question-circle:before {\n  content: \"\\f059\";\n}\n.fa-info-circle:before {\n  content: \"\\f05a\";\n}\n.fa-crosshairs:before {\n  content: \"\\f05b\";\n}\n.fa-times-circle-o:before {\n  content: \"\\f05c\";\n}\n.fa-check-circle-o:before {\n  content: \"\\f05d\";\n}\n.fa-ban:before {\n  content: \"\\f05e\";\n}\n.fa-arrow-left:before {\n  content: \"\\f060\";\n}\n.fa-arrow-right:before {\n  content: \"\\f061\";\n}\n.fa-arrow-up:before {\n  content: \"\\f062\";\n}\n.fa-arrow-down:before {\n  content: \"\\f063\";\n}\n.fa-mail-forward:before,\n.fa-share:before {\n  content: \"\\f064\";\n}\n.fa-expand:before {\n  content: \"\\f065\";\n}\n.fa-compress:before {\n  content: \"\\f066\";\n}\n.fa-plus:before {\n  content: \"\\f067\";\n}\n.fa-minus:before {\n  content: \"\\f068\";\n}\n.fa-asterisk:before {\n  content: \"\\f069\";\n}\n.fa-exclamation-circle:before {\n  content: \"\\f06a\";\n}\n.fa-gift:before {\n  content: \"\\f06b\";\n}\n.fa-leaf:before {\n  content: \"\\f06c\";\n}\n.fa-fire:before {\n  content: \"\\f06d\";\n}\n.fa-eye:before {\n  content: \"\\f06e\";\n}\n.fa-eye-slash:before {\n  content: \"\\f070\";\n}\n.fa-warning:before,\n.fa-exclamation-triangle:before {\n  content: \"\\f071\";\n}\n.fa-plane:before {\n  content: \"\\f072\";\n}\n.fa-calendar:before {\n  content: \"\\f073\";\n}\n.fa-random:before {\n  content: \"\\f074\";\n}\n.fa-comment:before {\n  content: \"\\f075\";\n}\n.fa-magnet:before {\n  content: \"\\f076\";\n}\n.fa-chevron-up:before {\n  content: \"\\f077\";\n}\n.fa-chevron-down:before {\n  content: \"\\f078\";\n}\n.fa-retweet:before {\n  content: \"\\f079\";\n}\n.fa-shopping-cart:before {\n  content: \"\\f07a\";\n}\n.fa-folder:before {\n  content: \"\\f07b\";\n}\n.fa-folder-open:before {\n  content: \"\\f07c\";\n}\n.fa-arrows-v:before {\n  content: \"\\f07d\";\n}\n.fa-arrows-h:before {\n  content: \"\\f07e\";\n}\n.fa-bar-chart-o:before,\n.fa-bar-chart:before {\n  content: \"\\f080\";\n}\n.fa-twitter-square:before {\n  content: \"\\f081\";\n}\n.fa-facebook-square:before {\n  content: \"\\f082\";\n}\n.fa-camera-retro:before {\n  content: \"\\f083\";\n}\n.fa-key:before {\n  content: \"\\f084\";\n}\n.fa-gears:before,\n.fa-cogs:before {\n  content: \"\\f085\";\n}\n.fa-comments:before {\n  content: \"\\f086\";\n}\n.fa-thumbs-o-up:before {\n  content: \"\\f087\";\n}\n.fa-thumbs-o-down:before {\n  content: \"\\f088\";\n}\n.fa-star-half:before {\n  content: \"\\f089\";\n}\n.fa-heart-o:before {\n  content: \"\\f08a\";\n}\n.fa-sign-out:before {\n  content: \"\\f08b\";\n}\n.fa-linkedin-square:before {\n  content: \"\\f08c\";\n}\n.fa-thumb-tack:before {\n  content: \"\\f08d\";\n}\n.fa-external-link:before {\n  content: \"\\f08e\";\n}\n.fa-sign-in:before {\n  content: \"\\f090\";\n}\n.fa-trophy:before {\n  content: \"\\f091\";\n}\n.fa-github-square:before {\n  content: \"\\f092\";\n}\n.fa-upload:before {\n  content: \"\\f093\";\n}\n.fa-lemon-o:before {\n  content: \"\\f094\";\n}\n.fa-phone:before {\n  content: \"\\f095\";\n}\n.fa-square-o:before {\n  content: \"\\f096\";\n}\n.fa-bookmark-o:before {\n  content: \"\\f097\";\n}\n.fa-phone-square:before {\n  content: \"\\f098\";\n}\n.fa-twitter:before {\n  content: \"\\f099\";\n}\n.fa-facebook-f:before,\n.fa-facebook:before {\n  content: \"\\f09a\";\n}\n.fa-github:before {\n  content: \"\\f09b\";\n}\n.fa-unlock:before {\n  content: \"\\f09c\";\n}\n.fa-credit-card:before {\n  content: \"\\f09d\";\n}\n.fa-feed:before,\n.fa-rss:before {\n  content: \"\\f09e\";\n}\n.fa-hdd-o:before {\n  content: \"\\f0a0\";\n}\n.fa-bullhorn:before {\n  content: \"\\f0a1\";\n}\n.fa-bell:before {\n  content: \"\\f0f3\";\n}\n.fa-certificate:before {\n  content: \"\\f0a3\";\n}\n.fa-hand-o-right:before {\n  content: \"\\f0a4\";\n}\n.fa-hand-o-left:before {\n  content: \"\\f0a5\";\n}\n.fa-hand-o-up:before {\n  content: \"\\f0a6\";\n}\n.fa-hand-o-down:before {\n  content: \"\\f0a7\";\n}\n.fa-arrow-circle-left:before {\n  content: \"\\f0a8\";\n}\n.fa-arrow-circle-right:before {\n  content: \"\\f0a9\";\n}\n.fa-arrow-circle-up:before {\n  content: \"\\f0aa\";\n}\n.fa-arrow-circle-down:before {\n  content: \"\\f0ab\";\n}\n.fa-globe:before {\n  content: \"\\f0ac\";\n}\n.fa-wrench:before {\n  content: \"\\f0ad\";\n}\n.fa-tasks:before {\n  content: \"\\f0ae\";\n}\n.fa-filter:before {\n  content: \"\\f0b0\";\n}\n.fa-briefcase:before {\n  content: \"\\f0b1\";\n}\n.fa-arrows-alt:before {\n  content: \"\\f0b2\";\n}\n.fa-group:before,\n.fa-users:before {\n  content: \"\\f0c0\";\n}\n.fa-chain:before,\n.fa-link:before {\n  content: \"\\f0c1\";\n}\n.fa-cloud:before {\n  content: \"\\f0c2\";\n}\n.fa-flask:before {\n  content: \"\\f0c3\";\n}\n.fa-cut:before,\n.fa-scissors:before {\n  content: \"\\f0c4\";\n}\n.fa-copy:before,\n.fa-files-o:before {\n  content: \"\\f0c5\";\n}\n.fa-paperclip:before {\n  content: \"\\f0c6\";\n}\n.fa-save:before,\n.fa-floppy-o:before {\n  content: \"\\f0c7\";\n}\n.fa-square:before {\n  content: \"\\f0c8\";\n}\n.fa-navicon:before,\n.fa-reorder:before,\n.fa-bars:before {\n  content: \"\\f0c9\";\n}\n.fa-list-ul:before {\n  content: \"\\f0ca\";\n}\n.fa-list-ol:before {\n  content: \"\\f0cb\";\n}\n.fa-strikethrough:before {\n  content: \"\\f0cc\";\n}\n.fa-underline:before {\n  content: \"\\f0cd\";\n}\n.fa-table:before {\n  content: \"\\f0ce\";\n}\n.fa-magic:before {\n  content: \"\\f0d0\";\n}\n.fa-truck:before {\n  content: \"\\f0d1\";\n}\n.fa-pinterest:before {\n  content: \"\\f0d2\";\n}\n.fa-pinterest-square:before {\n  content: \"\\f0d3\";\n}\n.fa-google-plus-square:before {\n  content: \"\\f0d4\";\n}\n.fa-google-plus:before {\n  content: \"\\f0d5\";\n}\n.fa-money:before {\n  content: \"\\f0d6\";\n}\n.fa-caret-down:before {\n  content: \"\\f0d7\";\n}\n.fa-caret-up:before {\n  content: \"\\f0d8\";\n}\n.fa-caret-left:before {\n  content: \"\\f0d9\";\n}\n.fa-caret-right:before {\n  content: \"\\f0da\";\n}\n.fa-columns:before {\n  content: \"\\f0db\";\n}\n.fa-unsorted:before,\n.fa-sort:before {\n  content: \"\\f0dc\";\n}\n.fa-sort-down:before,\n.fa-sort-desc:before {\n  content: \"\\f0dd\";\n}\n.fa-sort-up:before,\n.fa-sort-asc:before {\n  content: \"\\f0de\";\n}\n.fa-envelope:before {\n  content: \"\\f0e0\";\n}\n.fa-linkedin:before {\n  content: \"\\f0e1\";\n}\n.fa-rotate-left:before,\n.fa-undo:before {\n  content: \"\\f0e2\";\n}\n.fa-legal:before,\n.fa-gavel:before {\n  content: \"\\f0e3\";\n}\n.fa-dashboard:before,\n.fa-tachometer:before {\n  content: \"\\f0e4\";\n}\n.fa-comment-o:before {\n  content: \"\\f0e5\";\n}\n.fa-comments-o:before {\n  content: \"\\f0e6\";\n}\n.fa-flash:before,\n.fa-bolt:before {\n  content: \"\\f0e7\";\n}\n.fa-sitemap:before {\n  content: \"\\f0e8\";\n}\n.fa-umbrella:before {\n  content: \"\\f0e9\";\n}\n.fa-paste:before,\n.fa-clipboard:before {\n  content: \"\\f0ea\";\n}\n.fa-lightbulb-o:before {\n  content: \"\\f0eb\";\n}\n.fa-exchange:before {\n  content: \"\\f0ec\";\n}\n.fa-cloud-download:before {\n  content: \"\\f0ed\";\n}\n.fa-cloud-upload:before {\n  content: \"\\f0ee\";\n}\n.fa-user-md:before {\n  content: \"\\f0f0\";\n}\n.fa-stethoscope:before {\n  content: \"\\f0f1\";\n}\n.fa-suitcase:before {\n  content: \"\\f0f2\";\n}\n.fa-bell-o:before {\n  content: \"\\f0a2\";\n}\n.fa-coffee:before {\n  content: \"\\f0f4\";\n}\n.fa-cutlery:before {\n  content: \"\\f0f5\";\n}\n.fa-file-text-o:before {\n  content: \"\\f0f6\";\n}\n.fa-building-o:before {\n  content: \"\\f0f7\";\n}\n.fa-hospital-o:before {\n  content: \"\\f0f8\";\n}\n.fa-ambulance:before {\n  content: \"\\f0f9\";\n}\n.fa-medkit:before {\n  content: \"\\f0fa\";\n}\n.fa-fighter-jet:before {\n  content: \"\\f0fb\";\n}\n.fa-beer:before {\n  content: \"\\f0fc\";\n}\n.fa-h-square:before {\n  content: \"\\f0fd\";\n}\n.fa-plus-square:before {\n  content: \"\\f0fe\";\n}\n.fa-angle-double-left:before {\n  content: \"\\f100\";\n}\n.fa-angle-double-right:before {\n  content: \"\\f101\";\n}\n.fa-angle-double-up:before {\n  content: \"\\f102\";\n}\n.fa-angle-double-down:before {\n  content: \"\\f103\";\n}\n.fa-angle-left:before {\n  content: \"\\f104\";\n}\n.fa-angle-right:before {\n  content: \"\\f105\";\n}\n.fa-angle-up:before {\n  content: \"\\f106\";\n}\n.fa-angle-down:before {\n  content: \"\\f107\";\n}\n.fa-desktop:before {\n  content: \"\\f108\";\n}\n.fa-laptop:before {\n  content: \"\\f109\";\n}\n.fa-tablet:before {\n  content: \"\\f10a\";\n}\n.fa-mobile-phone:before,\n.fa-mobile:before {\n  content: \"\\f10b\";\n}\n.fa-circle-o:before {\n  content: \"\\f10c\";\n}\n.fa-quote-left:before {\n  content: \"\\f10d\";\n}\n.fa-quote-right:before {\n  content: \"\\f10e\";\n}\n.fa-spinner:before {\n  content: \"\\f110\";\n}\n.fa-circle:before {\n  content: \"\\f111\";\n}\n.fa-mail-reply:before,\n.fa-reply:before {\n  content: \"\\f112\";\n}\n.fa-github-alt:before {\n  content: \"\\f113\";\n}\n.fa-folder-o:before {\n  content: \"\\f114\";\n}\n.fa-folder-open-o:before {\n  content: \"\\f115\";\n}\n.fa-smile-o:before {\n  content: \"\\f118\";\n}\n.fa-frown-o:before {\n  content: \"\\f119\";\n}\n.fa-meh-o:before {\n  content: \"\\f11a\";\n}\n.fa-gamepad:before {\n  content: \"\\f11b\";\n}\n.fa-keyboard-o:before {\n  content: \"\\f11c\";\n}\n.fa-flag-o:before {\n  content: \"\\f11d\";\n}\n.fa-flag-checkered:before {\n  content: \"\\f11e\";\n}\n.fa-terminal:before {\n  content: \"\\f120\";\n}\n.fa-code:before {\n  content: \"\\f121\";\n}\n.fa-mail-reply-all:before,\n.fa-reply-all:before {\n  content: \"\\f122\";\n}\n.fa-star-half-empty:before,\n.fa-star-half-full:before,\n.fa-star-half-o:before {\n  content: \"\\f123\";\n}\n.fa-location-arrow:before {\n  content: \"\\f124\";\n}\n.fa-crop:before {\n  content: \"\\f125\";\n}\n.fa-code-fork:before {\n  content: \"\\f126\";\n}\n.fa-unlink:before,\n.fa-chain-broken:before {\n  content: \"\\f127\";\n}\n.fa-question:before {\n  content: \"\\f128\";\n}\n.fa-info:before {\n  content: \"\\f129\";\n}\n.fa-exclamation:before {\n  content: \"\\f12a\";\n}\n.fa-superscript:before {\n  content: \"\\f12b\";\n}\n.fa-subscript:before {\n  content: \"\\f12c\";\n}\n.fa-eraser:before {\n  content: \"\\f12d\";\n}\n.fa-puzzle-piece:before {\n  content: \"\\f12e\";\n}\n.fa-microphone:before {\n  content: \"\\f130\";\n}\n.fa-microphone-slash:before {\n  content: \"\\f131\";\n}\n.fa-shield:before {\n  content: \"\\f132\";\n}\n.fa-calendar-o:before {\n  content: \"\\f133\";\n}\n.fa-fire-extinguisher:before {\n  content: \"\\f134\";\n}\n.fa-rocket:before {\n  content: \"\\f135\";\n}\n.fa-maxcdn:before {\n  content: \"\\f136\";\n}\n.fa-chevron-circle-left:before {\n  content: \"\\f137\";\n}\n.fa-chevron-circle-right:before {\n  content: \"\\f138\";\n}\n.fa-chevron-circle-up:before {\n  content: \"\\f139\";\n}\n.fa-chevron-circle-down:before {\n  content: \"\\f13a\";\n}\n.fa-html5:before {\n  content: \"\\f13b\";\n}\n.fa-css3:before {\n  content: \"\\f13c\";\n}\n.fa-anchor:before {\n  content: \"\\f13d\";\n}\n.fa-unlock-alt:before {\n  content: \"\\f13e\";\n}\n.fa-bullseye:before {\n  content: \"\\f140\";\n}\n.fa-ellipsis-h:before {\n  content: \"\\f141\";\n}\n.fa-ellipsis-v:before {\n  content: \"\\f142\";\n}\n.fa-rss-square:before {\n  content: \"\\f143\";\n}\n.fa-play-circle:before {\n  content: \"\\f144\";\n}\n.fa-ticket:before {\n  content: \"\\f145\";\n}\n.fa-minus-square:before {\n  content: \"\\f146\";\n}\n.fa-minus-square-o:before {\n  content: \"\\f147\";\n}\n.fa-level-up:before {\n  content: \"\\f148\";\n}\n.fa-level-down:before {\n  content: \"\\f149\";\n}\n.fa-check-square:before {\n  content: \"\\f14a\";\n}\n.fa-pencil-square:before {\n  content: \"\\f14b\";\n}\n.fa-external-link-square:before {\n  content: \"\\f14c\";\n}\n.fa-share-square:before {\n  content: \"\\f14d\";\n}\n.fa-compass:before {\n  content: \"\\f14e\";\n}\n.fa-toggle-down:before,\n.fa-caret-square-o-down:before {\n  content: \"\\f150\";\n}\n.fa-toggle-up:before,\n.fa-caret-square-o-up:before {\n  content: \"\\f151\";\n}\n.fa-toggle-right:before,\n.fa-caret-square-o-right:before {\n  content: \"\\f152\";\n}\n.fa-euro:before,\n.fa-eur:before {\n  content: \"\\f153\";\n}\n.fa-gbp:before {\n  content: \"\\f154\";\n}\n.fa-dollar:before,\n.fa-usd:before {\n  content: \"\\f155\";\n}\n.fa-rupee:before,\n.fa-inr:before {\n  content: \"\\f156\";\n}\n.fa-cny:before,\n.fa-rmb:before,\n.fa-yen:before,\n.fa-jpy:before {\n  content: \"\\f157\";\n}\n.fa-ruble:before,\n.fa-rouble:before,\n.fa-rub:before {\n  content: \"\\f158\";\n}\n.fa-won:before,\n.fa-krw:before {\n  content: \"\\f159\";\n}\n.fa-bitcoin:before,\n.fa-btc:before {\n  content: \"\\f15a\";\n}\n.fa-file:before {\n  content: \"\\f15b\";\n}\n.fa-file-text:before {\n  content: \"\\f15c\";\n}\n.fa-sort-alpha-asc:before {\n  content: \"\\f15d\";\n}\n.fa-sort-alpha-desc:before {\n  content: \"\\f15e\";\n}\n.fa-sort-amount-asc:before {\n  content: \"\\f160\";\n}\n.fa-sort-amount-desc:before {\n  content: \"\\f161\";\n}\n.fa-sort-numeric-asc:before {\n  content: \"\\f162\";\n}\n.fa-sort-numeric-desc:before {\n  content: \"\\f163\";\n}\n.fa-thumbs-up:before {\n  content: \"\\f164\";\n}\n.fa-thumbs-down:before {\n  content: \"\\f165\";\n}\n.fa-youtube-square:before {\n  content: \"\\f166\";\n}\n.fa-youtube:before {\n  content: \"\\f167\";\n}\n.fa-xing:before {\n  content: \"\\f168\";\n}\n.fa-xing-square:before {\n  content: \"\\f169\";\n}\n.fa-youtube-play:before {\n  content: \"\\f16a\";\n}\n.fa-dropbox:before {\n  content: \"\\f16b\";\n}\n.fa-stack-overflow:before {\n  content: \"\\f16c\";\n}\n.fa-instagram:before {\n  content: \"\\f16d\";\n}\n.fa-flickr:before {\n  content: \"\\f16e\";\n}\n.fa-adn:before {\n  content: \"\\f170\";\n}\n.fa-bitbucket:before {\n  content: \"\\f171\";\n}\n.fa-bitbucket-square:before {\n  content: \"\\f172\";\n}\n.fa-tumblr:before {\n  content: \"\\f173\";\n}\n.fa-tumblr-square:before {\n  content: \"\\f174\";\n}\n.fa-long-arrow-down:before {\n  content: \"\\f175\";\n}\n.fa-long-arrow-up:before {\n  content: \"\\f176\";\n}\n.fa-long-arrow-left:before {\n  content: \"\\f177\";\n}\n.fa-long-arrow-right:before {\n  content: \"\\f178\";\n}\n.fa-apple:before {\n  content: \"\\f179\";\n}\n.fa-windows:before {\n  content: \"\\f17a\";\n}\n.fa-android:before {\n  content: \"\\f17b\";\n}\n.fa-linux:before {\n  content: \"\\f17c\";\n}\n.fa-dribbble:before {\n  content: \"\\f17d\";\n}\n.fa-skype:before {\n  content: \"\\f17e\";\n}\n.fa-foursquare:before {\n  content: \"\\f180\";\n}\n.fa-trello:before {\n  content: \"\\f181\";\n}\n.fa-female:before {\n  content: \"\\f182\";\n}\n.fa-male:before {\n  content: \"\\f183\";\n}\n.fa-gittip:before,\n.fa-gratipay:before {\n  content: \"\\f184\";\n}\n.fa-sun-o:before {\n  content: \"\\f185\";\n}\n.fa-moon-o:before {\n  content: \"\\f186\";\n}\n.fa-archive:before {\n  content: \"\\f187\";\n}\n.fa-bug:before {\n  content: \"\\f188\";\n}\n.fa-vk:before {\n  content: \"\\f189\";\n}\n.fa-weibo:before {\n  content: \"\\f18a\";\n}\n.fa-renren:before {\n  content: \"\\f18b\";\n}\n.fa-pagelines:before {\n  content: \"\\f18c\";\n}\n.fa-stack-exchange:before {\n  content: \"\\f18d\";\n}\n.fa-arrow-circle-o-right:before {\n  content: \"\\f18e\";\n}\n.fa-arrow-circle-o-left:before {\n  content: \"\\f190\";\n}\n.fa-toggle-left:before,\n.fa-caret-square-o-left:before {\n  content: \"\\f191\";\n}\n.fa-dot-circle-o:before {\n  content: \"\\f192\";\n}\n.fa-wheelchair:before {\n  content: \"\\f193\";\n}\n.fa-vimeo-square:before {\n  content: \"\\f194\";\n}\n.fa-turkish-lira:before,\n.fa-try:before {\n  content: \"\\f195\";\n}\n.fa-plus-square-o:before {\n  content: \"\\f196\";\n}\n.fa-space-shuttle:before {\n  content: \"\\f197\";\n}\n.fa-slack:before {\n  content: \"\\f198\";\n}\n.fa-envelope-square:before {\n  content: \"\\f199\";\n}\n.fa-wordpress:before {\n  content: \"\\f19a\";\n}\n.fa-openid:before {\n  content: \"\\f19b\";\n}\n.fa-institution:before,\n.fa-bank:before,\n.fa-university:before {\n  content: \"\\f19c\";\n}\n.fa-mortar-board:before,\n.fa-graduation-cap:before {\n  content: \"\\f19d\";\n}\n.fa-yahoo:before {\n  content: \"\\f19e\";\n}\n.fa-google:before {\n  content: \"\\f1a0\";\n}\n.fa-reddit:before {\n  content: \"\\f1a1\";\n}\n.fa-reddit-square:before {\n  content: \"\\f1a2\";\n}\n.fa-stumbleupon-circle:before {\n  content: \"\\f1a3\";\n}\n.fa-stumbleupon:before {\n  content: \"\\f1a4\";\n}\n.fa-delicious:before {\n  content: \"\\f1a5\";\n}\n.fa-digg:before {\n  content: \"\\f1a6\";\n}\n.fa-pied-piper-pp:before {\n  content: \"\\f1a7\";\n}\n.fa-pied-piper-alt:before {\n  content: \"\\f1a8\";\n}\n.fa-drupal:before {\n  content: \"\\f1a9\";\n}\n.fa-joomla:before {\n  content: \"\\f1aa\";\n}\n.fa-language:before {\n  content: \"\\f1ab\";\n}\n.fa-fax:before {\n  content: \"\\f1ac\";\n}\n.fa-building:before {\n  content: \"\\f1ad\";\n}\n.fa-child:before {\n  content: \"\\f1ae\";\n}\n.fa-paw:before {\n  content: \"\\f1b0\";\n}\n.fa-spoon:before {\n  content: \"\\f1b1\";\n}\n.fa-cube:before {\n  content: \"\\f1b2\";\n}\n.fa-cubes:before {\n  content: \"\\f1b3\";\n}\n.fa-behance:before {\n  content: \"\\f1b4\";\n}\n.fa-behance-square:before {\n  content: \"\\f1b5\";\n}\n.fa-steam:before {\n  content: \"\\f1b6\";\n}\n.fa-steam-square:before {\n  content: \"\\f1b7\";\n}\n.fa-recycle:before {\n  content: \"\\f1b8\";\n}\n.fa-automobile:before,\n.fa-car:before {\n  content: \"\\f1b9\";\n}\n.fa-cab:before,\n.fa-taxi:before {\n  content: \"\\f1ba\";\n}\n.fa-tree:before {\n  content: \"\\f1bb\";\n}\n.fa-spotify:before {\n  content: \"\\f1bc\";\n}\n.fa-deviantart:before {\n  content: \"\\f1bd\";\n}\n.fa-soundcloud:before {\n  content: \"\\f1be\";\n}\n.fa-database:before {\n  content: \"\\f1c0\";\n}\n.fa-file-pdf-o:before {\n  content: \"\\f1c1\";\n}\n.fa-file-word-o:before {\n  content: \"\\f1c2\";\n}\n.fa-file-excel-o:before {\n  content: \"\\f1c3\";\n}\n.fa-file-powerpoint-o:before {\n  content: \"\\f1c4\";\n}\n.fa-file-photo-o:before,\n.fa-file-picture-o:before,\n.fa-file-image-o:before {\n  content: \"\\f1c5\";\n}\n.fa-file-zip-o:before,\n.fa-file-archive-o:before {\n  content: \"\\f1c6\";\n}\n.fa-file-sound-o:before,\n.fa-file-audio-o:before {\n  content: \"\\f1c7\";\n}\n.fa-file-movie-o:before,\n.fa-file-video-o:before {\n  content: \"\\f1c8\";\n}\n.fa-file-code-o:before {\n  content: \"\\f1c9\";\n}\n.fa-vine:before {\n  content: \"\\f1ca\";\n}\n.fa-codepen:before {\n  content: \"\\f1cb\";\n}\n.fa-jsfiddle:before {\n  content: \"\\f1cc\";\n}\n.fa-life-bouy:before,\n.fa-life-buoy:before,\n.fa-life-saver:before,\n.fa-support:before,\n.fa-life-ring:before {\n  content: \"\\f1cd\";\n}\n.fa-circle-o-notch:before {\n  content: \"\\f1ce\";\n}\n.fa-ra:before,\n.fa-resistance:before,\n.fa-rebel:before {\n  content: \"\\f1d0\";\n}\n.fa-ge:before,\n.fa-empire:before {\n  content: \"\\f1d1\";\n}\n.fa-git-square:before {\n  content: \"\\f1d2\";\n}\n.fa-git:before {\n  content: \"\\f1d3\";\n}\n.fa-y-combinator-square:before,\n.fa-yc-square:before,\n.fa-hacker-news:before {\n  content: \"\\f1d4\";\n}\n.fa-tencent-weibo:before {\n  content: \"\\f1d5\";\n}\n.fa-qq:before {\n  content: \"\\f1d6\";\n}\n.fa-wechat:before,\n.fa-weixin:before {\n  content: \"\\f1d7\";\n}\n.fa-send:before,\n.fa-paper-plane:before {\n  content: \"\\f1d8\";\n}\n.fa-send-o:before,\n.fa-paper-plane-o:before {\n  content: \"\\f1d9\";\n}\n.fa-history:before {\n  content: \"\\f1da\";\n}\n.fa-circle-thin:before {\n  content: \"\\f1db\";\n}\n.fa-header:before {\n  content: \"\\f1dc\";\n}\n.fa-paragraph:before {\n  content: \"\\f1dd\";\n}\n.fa-sliders:before {\n  content: \"\\f1de\";\n}\n.fa-share-alt:before {\n  content: \"\\f1e0\";\n}\n.fa-share-alt-square:before {\n  content: \"\\f1e1\";\n}\n.fa-bomb:before {\n  content: \"\\f1e2\";\n}\n.fa-soccer-ball-o:before,\n.fa-futbol-o:before {\n  content: \"\\f1e3\";\n}\n.fa-tty:before {\n  content: \"\\f1e4\";\n}\n.fa-binoculars:before {\n  content: \"\\f1e5\";\n}\n.fa-plug:before {\n  content: \"\\f1e6\";\n}\n.fa-slideshare:before {\n  content: \"\\f1e7\";\n}\n.fa-twitch:before {\n  content: \"\\f1e8\";\n}\n.fa-yelp:before {\n  content: \"\\f1e9\";\n}\n.fa-newspaper-o:before {\n  content: \"\\f1ea\";\n}\n.fa-wifi:before {\n  content: \"\\f1eb\";\n}\n.fa-calculator:before {\n  content: \"\\f1ec\";\n}\n.fa-paypal:before {\n  content: \"\\f1ed\";\n}\n.fa-google-wallet:before {\n  content: \"\\f1ee\";\n}\n.fa-cc-visa:before {\n  content: \"\\f1f0\";\n}\n.fa-cc-mastercard:before {\n  content: \"\\f1f1\";\n}\n.fa-cc-discover:before {\n  content: \"\\f1f2\";\n}\n.fa-cc-amex:before {\n  content: \"\\f1f3\";\n}\n.fa-cc-paypal:before {\n  content: \"\\f1f4\";\n}\n.fa-cc-stripe:before {\n  content: \"\\f1f5\";\n}\n.fa-bell-slash:before {\n  content: \"\\f1f6\";\n}\n.fa-bell-slash-o:before {\n  content: \"\\f1f7\";\n}\n.fa-trash:before {\n  content: \"\\f1f8\";\n}\n.fa-copyright:before {\n  content: \"\\f1f9\";\n}\n.fa-at:before {\n  content: \"\\f1fa\";\n}\n.fa-eyedropper:before {\n  content: \"\\f1fb\";\n}\n.fa-paint-brush:before {\n  content: \"\\f1fc\";\n}\n.fa-birthday-cake:before {\n  content: \"\\f1fd\";\n}\n.fa-area-chart:before {\n  content: \"\\f1fe\";\n}\n.fa-pie-chart:before {\n  content: \"\\f200\";\n}\n.fa-line-chart:before {\n  content: \"\\f201\";\n}\n.fa-lastfm:before {\n  content: \"\\f202\";\n}\n.fa-lastfm-square:before {\n  content: \"\\f203\";\n}\n.fa-toggle-off:before {\n  content: \"\\f204\";\n}\n.fa-toggle-on:before {\n  content: \"\\f205\";\n}\n.fa-bicycle:before {\n  content: \"\\f206\";\n}\n.fa-bus:before {\n  content: \"\\f207\";\n}\n.fa-ioxhost:before {\n  content: \"\\f208\";\n}\n.fa-angellist:before {\n  content: \"\\f209\";\n}\n.fa-cc:before {\n  content: \"\\f20a\";\n}\n.fa-shekel:before,\n.fa-sheqel:before,\n.fa-ils:before {\n  content: \"\\f20b\";\n}\n.fa-meanpath:before {\n  content: \"\\f20c\";\n}\n.fa-buysellads:before {\n  content: \"\\f20d\";\n}\n.fa-connectdevelop:before {\n  content: \"\\f20e\";\n}\n.fa-dashcube:before {\n  content: \"\\f210\";\n}\n.fa-forumbee:before {\n  content: \"\\f211\";\n}\n.fa-leanpub:before {\n  content: \"\\f212\";\n}\n.fa-sellsy:before {\n  content: \"\\f213\";\n}\n.fa-shirtsinbulk:before {\n  content: \"\\f214\";\n}\n.fa-simplybuilt:before {\n  content: \"\\f215\";\n}\n.fa-skyatlas:before {\n  content: \"\\f216\";\n}\n.fa-cart-plus:before {\n  content: \"\\f217\";\n}\n.fa-cart-arrow-down:before {\n  content: \"\\f218\";\n}\n.fa-diamond:before {\n  content: \"\\f219\";\n}\n.fa-ship:before {\n  content: \"\\f21a\";\n}\n.fa-user-secret:before {\n  content: \"\\f21b\";\n}\n.fa-motorcycle:before {\n  content: \"\\f21c\";\n}\n.fa-street-view:before {\n  content: \"\\f21d\";\n}\n.fa-heartbeat:before {\n  content: \"\\f21e\";\n}\n.fa-venus:before {\n  content: \"\\f221\";\n}\n.fa-mars:before {\n  content: \"\\f222\";\n}\n.fa-mercury:before {\n  content: \"\\f223\";\n}\n.fa-intersex:before,\n.fa-transgender:before {\n  content: \"\\f224\";\n}\n.fa-transgender-alt:before {\n  content: \"\\f225\";\n}\n.fa-venus-double:before {\n  content: \"\\f226\";\n}\n.fa-mars-double:before {\n  content: \"\\f227\";\n}\n.fa-venus-mars:before {\n  content: \"\\f228\";\n}\n.fa-mars-stroke:before {\n  content: \"\\f229\";\n}\n.fa-mars-stroke-v:before {\n  content: \"\\f22a\";\n}\n.fa-mars-stroke-h:before {\n  content: \"\\f22b\";\n}\n.fa-neuter:before {\n  content: \"\\f22c\";\n}\n.fa-genderless:before {\n  content: \"\\f22d\";\n}\n.fa-facebook-official:before {\n  content: \"\\f230\";\n}\n.fa-pinterest-p:before {\n  content: \"\\f231\";\n}\n.fa-whatsapp:before {\n  content: \"\\f232\";\n}\n.fa-server:before {\n  content: \"\\f233\";\n}\n.fa-user-plus:before {\n  content: \"\\f234\";\n}\n.fa-user-times:before {\n  content: \"\\f235\";\n}\n.fa-hotel:before,\n.fa-bed:before {\n  content: \"\\f236\";\n}\n.fa-viacoin:before {\n  content: \"\\f237\";\n}\n.fa-train:before {\n  content: \"\\f238\";\n}\n.fa-subway:before {\n  content: \"\\f239\";\n}\n.fa-medium:before {\n  content: \"\\f23a\";\n}\n.fa-yc:before,\n.fa-y-combinator:before {\n  content: \"\\f23b\";\n}\n.fa-optin-monster:before {\n  content: \"\\f23c\";\n}\n.fa-opencart:before {\n  content: \"\\f23d\";\n}\n.fa-expeditedssl:before {\n  content: \"\\f23e\";\n}\n.fa-battery-4:before,\n.fa-battery:before,\n.fa-battery-full:before {\n  content: \"\\f240\";\n}\n.fa-battery-3:before,\n.fa-battery-three-quarters:before {\n  content: \"\\f241\";\n}\n.fa-battery-2:before,\n.fa-battery-half:before {\n  content: \"\\f242\";\n}\n.fa-battery-1:before,\n.fa-battery-quarter:before {\n  content: \"\\f243\";\n}\n.fa-battery-0:before,\n.fa-battery-empty:before {\n  content: \"\\f244\";\n}\n.fa-mouse-pointer:before {\n  content: \"\\f245\";\n}\n.fa-i-cursor:before {\n  content: \"\\f246\";\n}\n.fa-object-group:before {\n  content: \"\\f247\";\n}\n.fa-object-ungroup:before {\n  content: \"\\f248\";\n}\n.fa-sticky-note:before {\n  content: \"\\f249\";\n}\n.fa-sticky-note-o:before {\n  content: \"\\f24a\";\n}\n.fa-cc-jcb:before {\n  content: \"\\f24b\";\n}\n.fa-cc-diners-club:before {\n  content: \"\\f24c\";\n}\n.fa-clone:before {\n  content: \"\\f24d\";\n}\n.fa-balance-scale:before {\n  content: \"\\f24e\";\n}\n.fa-hourglass-o:before {\n  content: \"\\f250\";\n}\n.fa-hourglass-1:before,\n.fa-hourglass-start:before {\n  content: \"\\f251\";\n}\n.fa-hourglass-2:before,\n.fa-hourglass-half:before {\n  content: \"\\f252\";\n}\n.fa-hourglass-3:before,\n.fa-hourglass-end:before {\n  content: \"\\f253\";\n}\n.fa-hourglass:before {\n  content: \"\\f254\";\n}\n.fa-hand-grab-o:before,\n.fa-hand-rock-o:before {\n  content: \"\\f255\";\n}\n.fa-hand-stop-o:before,\n.fa-hand-paper-o:before {\n  content: \"\\f256\";\n}\n.fa-hand-scissors-o:before {\n  content: \"\\f257\";\n}\n.fa-hand-lizard-o:before {\n  content: \"\\f258\";\n}\n.fa-hand-spock-o:before {\n  content: \"\\f259\";\n}\n.fa-hand-pointer-o:before {\n  content: \"\\f25a\";\n}\n.fa-hand-peace-o:before {\n  content: \"\\f25b\";\n}\n.fa-trademark:before {\n  content: \"\\f25c\";\n}\n.fa-registered:before {\n  content: \"\\f25d\";\n}\n.fa-creative-commons:before {\n  content: \"\\f25e\";\n}\n.fa-gg:before {\n  content: \"\\f260\";\n}\n.fa-gg-circle:before {\n  content: \"\\f261\";\n}\n.fa-tripadvisor:before {\n  content: \"\\f262\";\n}\n.fa-odnoklassniki:before {\n  content: \"\\f263\";\n}\n.fa-odnoklassniki-square:before {\n  content: \"\\f264\";\n}\n.fa-get-pocket:before {\n  content: \"\\f265\";\n}\n.fa-wikipedia-w:before {\n  content: \"\\f266\";\n}\n.fa-safari:before {\n  content: \"\\f267\";\n}\n.fa-chrome:before {\n  content: \"\\f268\";\n}\n.fa-firefox:before {\n  content: \"\\f269\";\n}\n.fa-opera:before {\n  content: \"\\f26a\";\n}\n.fa-internet-explorer:before {\n  content: \"\\f26b\";\n}\n.fa-tv:before,\n.fa-television:before {\n  content: \"\\f26c\";\n}\n.fa-contao:before {\n  content: \"\\f26d\";\n}\n.fa-500px:before {\n  content: \"\\f26e\";\n}\n.fa-amazon:before {\n  content: \"\\f270\";\n}\n.fa-calendar-plus-o:before {\n  content: \"\\f271\";\n}\n.fa-calendar-minus-o:before {\n  content: \"\\f272\";\n}\n.fa-calendar-times-o:before {\n  content: \"\\f273\";\n}\n.fa-calendar-check-o:before {\n  content: \"\\f274\";\n}\n.fa-industry:before {\n  content: \"\\f275\";\n}\n.fa-map-pin:before {\n  content: \"\\f276\";\n}\n.fa-map-signs:before {\n  content: \"\\f277\";\n}\n.fa-map-o:before {\n  content: \"\\f278\";\n}\n.fa-map:before {\n  content: \"\\f279\";\n}\n.fa-commenting:before {\n  content: \"\\f27a\";\n}\n.fa-commenting-o:before {\n  content: \"\\f27b\";\n}\n.fa-houzz:before {\n  content: \"\\f27c\";\n}\n.fa-vimeo:before {\n  content: \"\\f27d\";\n}\n.fa-black-tie:before {\n  content: \"\\f27e\";\n}\n.fa-fonticons:before {\n  content: \"\\f280\";\n}\n.fa-reddit-alien:before {\n  content: \"\\f281\";\n}\n.fa-edge:before {\n  content: \"\\f282\";\n}\n.fa-credit-card-alt:before {\n  content: \"\\f283\";\n}\n.fa-codiepie:before {\n  content: \"\\f284\";\n}\n.fa-modx:before {\n  content: \"\\f285\";\n}\n.fa-fort-awesome:before {\n  content: \"\\f286\";\n}\n.fa-usb:before {\n  content: \"\\f287\";\n}\n.fa-product-hunt:before {\n  content: \"\\f288\";\n}\n.fa-mixcloud:before {\n  content: \"\\f289\";\n}\n.fa-scribd:before {\n  content: \"\\f28a\";\n}\n.fa-pause-circle:before {\n  content: \"\\f28b\";\n}\n.fa-pause-circle-o:before {\n  content: \"\\f28c\";\n}\n.fa-stop-circle:before {\n  content: \"\\f28d\";\n}\n.fa-stop-circle-o:before {\n  content: \"\\f28e\";\n}\n.fa-shopping-bag:before {\n  content: \"\\f290\";\n}\n.fa-shopping-basket:before {\n  content: \"\\f291\";\n}\n.fa-hashtag:before {\n  content: \"\\f292\";\n}\n.fa-bluetooth:before {\n  content: \"\\f293\";\n}\n.fa-bluetooth-b:before {\n  content: \"\\f294\";\n}\n.fa-percent:before {\n  content: \"\\f295\";\n}\n.fa-gitlab:before {\n  content: \"\\f296\";\n}\n.fa-wpbeginner:before {\n  content: \"\\f297\";\n}\n.fa-wpforms:before {\n  content: \"\\f298\";\n}\n.fa-envira:before {\n  content: \"\\f299\";\n}\n.fa-universal-access:before {\n  content: \"\\f29a\";\n}\n.fa-wheelchair-alt:before {\n  content: \"\\f29b\";\n}\n.fa-question-circle-o:before {\n  content: \"\\f29c\";\n}\n.fa-blind:before {\n  content: \"\\f29d\";\n}\n.fa-audio-description:before {\n  content: \"\\f29e\";\n}\n.fa-volume-control-phone:before {\n  content: \"\\f2a0\";\n}\n.fa-braille:before {\n  content: \"\\f2a1\";\n}\n.fa-assistive-listening-systems:before {\n  content: \"\\f2a2\";\n}\n.fa-asl-interpreting:before,\n.fa-american-sign-language-interpreting:before {\n  content: \"\\f2a3\";\n}\n.fa-deafness:before,\n.fa-hard-of-hearing:before,\n.fa-deaf:before {\n  content: \"\\f2a4\";\n}\n.fa-glide:before {\n  content: \"\\f2a5\";\n}\n.fa-glide-g:before {\n  content: \"\\f2a6\";\n}\n.fa-signing:before,\n.fa-sign-language:before {\n  content: \"\\f2a7\";\n}\n.fa-low-vision:before {\n  content: \"\\f2a8\";\n}\n.fa-viadeo:before {\n  content: \"\\f2a9\";\n}\n.fa-viadeo-square:before {\n  content: \"\\f2aa\";\n}\n.fa-snapchat:before {\n  content: \"\\f2ab\";\n}\n.fa-snapchat-ghost:before {\n  content: \"\\f2ac\";\n}\n.fa-snapchat-square:before {\n  content: \"\\f2ad\";\n}\n.fa-pied-piper:before {\n  content: \"\\f2ae\";\n}\n.fa-first-order:before {\n  content: \"\\f2b0\";\n}\n.fa-yoast:before {\n  content: \"\\f2b1\";\n}\n.fa-themeisle:before {\n  content: \"\\f2b2\";\n}\n.fa-google-plus-circle:before,\n.fa-google-plus-official:before {\n  content: \"\\f2b3\";\n}\n.fa-fa:before,\n.fa-font-awesome:before {\n  content: \"\\f2b4\";\n}\n.fa-handshake-o:before {\n  content: \"\\f2b5\";\n}\n.fa-envelope-open:before {\n  content: \"\\f2b6\";\n}\n.fa-envelope-open-o:before {\n  content: \"\\f2b7\";\n}\n.fa-linode:before {\n  content: \"\\f2b8\";\n}\n.fa-address-book:before {\n  content: \"\\f2b9\";\n}\n.fa-address-book-o:before {\n  content: \"\\f2ba\";\n}\n.fa-vcard:before,\n.fa-address-card:before {\n  content: \"\\f2bb\";\n}\n.fa-vcard-o:before,\n.fa-address-card-o:before {\n  content: \"\\f2bc\";\n}\n.fa-user-circle:before {\n  content: \"\\f2bd\";\n}\n.fa-user-circle-o:before {\n  content: \"\\f2be\";\n}\n.fa-user-o:before {\n  content: \"\\f2c0\";\n}\n.fa-id-badge:before {\n  content: \"\\f2c1\";\n}\n.fa-drivers-license:before,\n.fa-id-card:before {\n  content: \"\\f2c2\";\n}\n.fa-drivers-license-o:before,\n.fa-id-card-o:before {\n  content: \"\\f2c3\";\n}\n.fa-quora:before {\n  content: \"\\f2c4\";\n}\n.fa-free-code-camp:before {\n  content: \"\\f2c5\";\n}\n.fa-telegram:before {\n  content: \"\\f2c6\";\n}\n.fa-thermometer-4:before,\n.fa-thermometer:before,\n.fa-thermometer-full:before {\n  content: \"\\f2c7\";\n}\n.fa-thermometer-3:before,\n.fa-thermometer-three-quarters:before {\n  content: \"\\f2c8\";\n}\n.fa-thermometer-2:before,\n.fa-thermometer-half:before {\n  content: \"\\f2c9\";\n}\n.fa-thermometer-1:before,\n.fa-thermometer-quarter:before {\n  content: \"\\f2ca\";\n}\n.fa-thermometer-0:before,\n.fa-thermometer-empty:before {\n  content: \"\\f2cb\";\n}\n.fa-shower:before {\n  content: \"\\f2cc\";\n}\n.fa-bathtub:before,\n.fa-s15:before,\n.fa-bath:before {\n  content: \"\\f2cd\";\n}\n.fa-podcast:before {\n  content: \"\\f2ce\";\n}\n.fa-window-maximize:before {\n  content: \"\\f2d0\";\n}\n.fa-window-minimize:before {\n  content: \"\\f2d1\";\n}\n.fa-window-restore:before {\n  content: \"\\f2d2\";\n}\n.fa-times-rectangle:before,\n.fa-window-close:before {\n  content: \"\\f2d3\";\n}\n.fa-times-rectangle-o:before,\n.fa-window-close-o:before {\n  content: \"\\f2d4\";\n}\n.fa-bandcamp:before {\n  content: \"\\f2d5\";\n}\n.fa-grav:before {\n  content: \"\\f2d6\";\n}\n.fa-etsy:before {\n  content: \"\\f2d7\";\n}\n.fa-imdb:before {\n  content: \"\\f2d8\";\n}\n.fa-ravelry:before {\n  content: \"\\f2d9\";\n}\n.fa-eercast:before {\n  content: \"\\f2da\";\n}\n.fa-microchip:before {\n  content: \"\\f2db\";\n}\n.fa-snowflake-o:before {\n  content: \"\\f2dc\";\n}\n.fa-superpowers:before {\n  content: \"\\f2dd\";\n}\n.fa-wpexplorer:before {\n  content: \"\\f2de\";\n}\n.fa-meetup:before {\n  content: \"\\f2e0\";\n}\n.sr-only {\n  position: absolute;\n  width: 1px;\n  height: 1px;\n  padding: 0;\n  margin: -1px;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  border: 0;\n}\n.sr-only-focusable:active,\n.sr-only-focusable:focus {\n  position: static;\n  width: auto;\n  height: auto;\n  margin: 0;\n  overflow: visible;\n  clip: auto;\n}\n","\n$shadow-key-umbra-opacity: 0.2 !default;\n$shadow-key-penumbra-opacity: 0.14 !default;\n$shadow-ambient-shadow-opacity: 0.12 !default;\n\n\n@mixin shadow-1dp() {\n  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, $shadow-key-penumbra-opacity),\n              0 2px 1px -1px rgba(0, 0, 0, $shadow-key-umbra-opacity),\n              0 1px 2px 0 rgba(0, 0, 0, $shadow-ambient-shadow-opacity);\n}\n\n@mixin shadow-2dp() {\n  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, $shadow-key-penumbra-opacity),\n              0 3px 1px -2px rgba(0, 0, 0, $shadow-key-umbra-opacity),\n              0 1px 5px 0 rgba(0, 0, 0, $shadow-ambient-shadow-opacity);\n}\n\n@mixin shadow-4dp() {\n  box-shadow: 0 4px 5px 0 rgba(0, 0, 0, $shadow-key-penumbra-opacity),\n              0 1px 10px 0 rgba(0, 0, 0, $shadow-ambient-shadow-opacity),\n              0 2px 4px -1px rgba(0, 0, 0, $shadow-key-umbra-opacity);\n}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),
/* 39 */
/***/ ((module) => {

"use strict";


function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

module.exports = function cssWithMappingToString(item) {
  var _item = _slicedToArray(item, 4),
      content = _item[1],
      cssMapping = _item[3];

  if (typeof btoa === "function") {
    // eslint-disable-next-line no-undef
    var base64 = btoa(unescape(encodeURIComponent(JSON.stringify(cssMapping))));
    var data = "sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(base64);
    var sourceMapping = "/*# ".concat(data, " */");
    var sourceURLs = cssMapping.sources.map(function (source) {
      return "/*# sourceURL=".concat(cssMapping.sourceRoot || "").concat(source, " */");
    });
    return [content].concat(sourceURLs).concat([sourceMapping]).join("\n");
  }

  return [content].join("\n");
};

/***/ }),
/* 40 */
/***/ ((module) => {

"use strict";


/*
  MIT License http://www.opensource.org/licenses/mit-license.php
  Author Tobias Koppers @sokra
*/
// css base code, injected by the css-loader
// eslint-disable-next-line func-names
module.exports = function (cssWithMappingToString) {
  var list = []; // return the list of modules as css string

  list.toString = function toString() {
    return this.map(function (item) {
      var content = cssWithMappingToString(item);

      if (item[2]) {
        return "@media ".concat(item[2], " {").concat(content, "}");
      }

      return content;
    }).join("");
  }; // import a list of modules into the list
  // eslint-disable-next-line func-names


  list.i = function (modules, mediaQuery, dedupe) {
    if (typeof modules === "string") {
      // eslint-disable-next-line no-param-reassign
      modules = [[null, modules, ""]];
    }

    var alreadyImportedModules = {};

    if (dedupe) {
      for (var i = 0; i < this.length; i++) {
        // eslint-disable-next-line prefer-destructuring
        var id = this[i][0];

        if (id != null) {
          alreadyImportedModules[id] = true;
        }
      }
    }

    for (var _i = 0; _i < modules.length; _i++) {
      var item = [].concat(modules[_i]);

      if (dedupe && alreadyImportedModules[item[0]]) {
        // eslint-disable-next-line no-continue
        continue;
      }

      if (mediaQuery) {
        if (!item[2]) {
          item[2] = mediaQuery;
        } else {
          item[2] = "".concat(mediaQuery, " and ").concat(item[2]);
        }
      }

      list.push(item);
    }
  };

  return list;
};

/***/ })
/******/ 	]);
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		if(__webpack_module_cache__[moduleId]) {
/******/ 			return __webpack_module_cache__[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			id: moduleId,
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry need to be wrapped in an IIFE because it need to be in strict mode.
(() => {
"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(1);
/* harmony import */ var _hat_open_util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11);
/* harmony import */ var _hat_open_juggler__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(12);
/* harmony import */ var _vt__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28);
/* harmony import */ var _state__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(31);
/* harmony import */ var _src_scss_main_scss__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(36);











async function main() {
    const root = document.body.appendChild(document.createElement('div'));
    _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default.init(root, _state__WEBPACK_IMPORTED_MODULE_4__.main, _vt__WEBPACK_IMPORTED_MODULE_3__.main);
    new _hat_open_juggler__WEBPACK_IMPORTED_MODULE_2__.Application(['local', 'filter'], 'remote');
}


window.addEventListener('load', main);
window.r = _hat_open_renderer__WEBPACK_IMPORTED_MODULE_0__.default;
window.u = _hat_open_util__WEBPACK_IMPORTED_MODULE_1__;

})();

/******/ })()
;
//# sourceMappingURL=main.js.map